import { ReactLocation, Router } from "@tanstack/react-location";
import React from "react";
import { SDKs } from "~/constants/routes";
// Set up a ReactLocation instance
const location = new ReactLocation();
const LazyLocalContentDeprecated = React.lazy(() => import("~/sdks/LocalContentDeprecated"));
const LazyLocalContent = React.lazy(() => import("~/sdks/LocalContent"));
const LazyLocalDemographics = React.lazy(() => import("~/sdks/LocalDemographics"));
const LazyNeighborhoodHero = React.lazy(() => import("~/sdks/NeighborhoodHero"));
const LazyNeighborhoodMap = React.lazy(() => import("~/sdks/NeighborhoodMap"));
const LazyNeighborhoodCharacteristics = React.lazy(() => import("~/sdks/NeighborhoodCharacteristics"));
const LazyNeighborhoodHighlights = React.lazy(() => import("~/sdks/NeighborhoodHighlights"));
const LazyNeighborhoodDemographics = React.lazy(() => import("../sdks/NeighborhoodDemographics"));
const LazyNeighborhoodPropertyValueDrivers = React.lazy(() => import("~/sdks/NeighborhoodPropertyValueDrivers"));
const LazyNeighborhoodMatch = React.lazy(() => import("~/sdks/NeighborhoodMatch"));
const LazyNeighborhoodMarketTrends = React.lazy(() => import("~/sdks/NeighborhoodMarketTrends"));
const LazyNeighborhoodSchools = React.lazy(() => import("~/sdks/NeighborhoodSchools"));
const LazyNeighborhoodShowcase = React.lazy(() => import("~/sdks/NeighborhoodShowcase"));
const LazyFeaturedNeighborhoods = React.lazy(() => import("~/sdks/NeighborhoodFeatured"));
const RouteTemplates = ({ children }) => {
    const templateRoutes = [
        {
            path: `/sdks-app/${APP_VERSION}/${SDKs.LOCAL_CONTENT}`,
            element: React.createElement(LazyLocalContentDeprecated, null),
        },
        {
            path: `/sdks-app/${APP_VERSION}/${SDKs.LOCAL_CONTENT_GOOGLE_MAPS}`,
            element: React.createElement(LazyLocalContentDeprecated, null),
        },
        {
            path: `/sdks-app/${APP_VERSION}/${SDKs.LOCAL_CONTENT_REFRESH}`,
            element: React.createElement(LazyLocalContent, null),
        },
        {
            path: `/sdks-app/${APP_VERSION}/${SDKs.LOCAL_DEMOGRAPHICS}`,
            element: React.createElement(LazyLocalDemographics, null),
        },
        {
            path: `/sdks-app/${APP_VERSION}/local-${SDKs.NEIGHBORHOOD_MAP}`,
            element: React.createElement(LazyNeighborhoodMap, null),
        },
        {
            path: `/sdks-app/${APP_VERSION}/local-${SDKs.NEIGHBORHOOD_HERO}`,
            element: React.createElement(LazyNeighborhoodHero, null),
        },
        {
            path: `/sdks-app/${APP_VERSION}/local-${SDKs.NEIGHBORHOOD_CHARACTERISTICS}`,
            element: React.createElement(LazyNeighborhoodCharacteristics, null),
        },
        {
            path: `/sdks-app/${APP_VERSION}/local-${SDKs.NEIGHBORHOOD_HIGHLIGHTS}`,
            element: React.createElement(LazyNeighborhoodHighlights, null),
        },
        {
            path: `/sdks-app/${APP_VERSION}/local-${SDKs.NEIGHBORHOOD_DEMOGRAPHICS}`,
            element: React.createElement(LazyNeighborhoodDemographics, null),
        },
        {
            path: `/sdks-app/${APP_VERSION}/local-${SDKs.NEIGHBORHOOD_PROPERTY_VALUE_DRIVERS}`,
            element: React.createElement(LazyNeighborhoodPropertyValueDrivers, null),
        },
        {
            path: `/sdks-app/${APP_VERSION}/local-${SDKs.NEIGHBORHOOD_MATCH}`,
            element: React.createElement(LazyNeighborhoodMatch, null),
        },
        // Legacy compatibility. Do NOT remove. Some clients still use this name.
        {
            path: `/sdks-app/${APP_VERSION}/demographics`,
            element: React.createElement(LazyLocalDemographics, null),
        },
        // TODO: LL22-5170 Remove these once the try site has been updated to use the new names
        {
            path: `/sdks-app/${APP_VERSION}/${SDKs.NEIGHBORHOOD_MAP}`,
            element: React.createElement(LazyNeighborhoodMap, null),
        },
        {
            path: `/sdks-app/${APP_VERSION}/${SDKs.NEIGHBORHOOD_HERO}`,
            element: React.createElement(LazyNeighborhoodHero, null),
        },
        {
            path: `/sdks-app/${APP_VERSION}/${SDKs.NEIGHBORHOOD_CHARACTERISTICS}`,
            element: React.createElement(LazyNeighborhoodCharacteristics, null),
        },
        {
            path: `/sdks-app/${APP_VERSION}/${SDKs.NEIGHBORHOOD_HIGHLIGHTS}`,
            element: React.createElement(LazyNeighborhoodHighlights, null),
        },
        {
            path: `/sdks-app/${APP_VERSION}/${SDKs.NEIGHBORHOOD_DEMOGRAPHICS}`,
            element: React.createElement(LazyNeighborhoodDemographics, null),
        },
        {
            path: `/sdks-app/${APP_VERSION}/${SDKs.NEIGHBORHOOD_PROPERTY_VALUE_DRIVERS}`,
            element: React.createElement(LazyNeighborhoodPropertyValueDrivers, null),
        },
        {
            path: `/sdks-app/${APP_VERSION}/${SDKs.NEIGHBORHOOD_MATCH}`,
            element: React.createElement(LazyNeighborhoodMatch, null),
        },
        {
            path: `/sdks-app/${APP_VERSION}/${SDKs.NEIGHBORHOOD_MARKET_TRENDS}`,
            element: React.createElement(LazyNeighborhoodMarketTrends, null),
        },
        {
            path: `/sdks-app/${APP_VERSION}/${SDKs.NEIGHBORHOOD_SCHOOLS}`,
            element: React.createElement(LazyNeighborhoodSchools, null),
        },
        {
            path: `/sdks-app/${APP_VERSION}/${SDKs.NEIGHBORHOOD_SHOWCASE}`,
            element: React.createElement(LazyNeighborhoodShowcase, null),
        },
        {
            path: `/sdks-app/${APP_VERSION}/${SDKs.NEIGHBORHOOD_FEATURED}`,
            element: React.createElement(LazyFeaturedNeighborhoods, null),
        },
    ];
    return (React.createElement(Router, { location: location, routes: templateRoutes }, children));
};
export default RouteTemplates;
//# sourceMappingURL=index.js.map