var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { useLocalLogic } from "~/context/LocalLogicProvider";
import { useQuery } from "@tanstack/react-query";
import { schoolsKeys } from "~/features/schools";
export function useSchools({ lat, lng, include, radius = 2000, 
// 30 is the default limit and maximum number of schools returned by the API
limit = 30, includeCatchments = false, }) {
    const { client } = useLocalLogic();
    const options = {
        lat,
        lng,
        limit,
        radius,
        include_catchments: includeCatchments,
    };
    return useQuery({
        queryKey: schoolsKeys.list(options),
        queryFn: () => __awaiter(this, void 0, void 0, function* () {
            return client
                .getSchools(options)
                .then((response) => {
                if (typeof include === "undefined" || !Array.isArray(include)) {
                    return response;
                }
                const filteredResponse = {};
                if (include.includes("high_schools")) {
                    filteredResponse.high_schools = (response === null || response === void 0 ? void 0 : response.high_schools) || [];
                }
                if (include.includes("primary_schools")) {
                    filteredResponse.primary_schools = (response === null || response === void 0 ? void 0 : response.primary_schools) || [];
                }
                return filteredResponse;
            });
        }),
        staleTime: Infinity,
        enabled: !!options && !!(include === null || include === void 0 ? void 0 : include.length) && !!options.lat && !!options.lng,
    });
}
//# sourceMappingURL=useSchools.js.map