import { useMemo } from "react";
import { useGeographies } from "~/features/clientLibrary/useGeographies";
import { extractLevelFromGeography } from "~/utils/extractLevelFromGeography";
import { mapUtils } from "@local-logic/core/utils";
/**
 * This hook is used by Neighborhood Wrap SDKs in order to display neighborhood info specific information
 */
export function useGeoLocationInfo({ lat, lng, geographyId, externalId, locale, include, }) {
    const latLng = useMemo(() => {
        if (!geographyId) {
            return { lat, lng };
        }
        return mapUtils.decodeGeogId(geographyId);
    }, [lat, lng, geographyId]);
    const { data: geographies, isFetching } = useGeographies({
        location: latLng,
        externalId,
        include,
    });
    const locationInfo = useMemo(() => {
        var _a, _b;
        if (!geographies || isFetching)
            return undefined;
        const geogKeys = Object.keys(geographies).sort((a, b) => Number(a.substring(1, 3)) - Number(b.substring(1, 3)));
        const level = Number((geographyId &&
            ((_a = geogKeys
                .find((key) => key.substring(1, 3) === geographyId.substring(1, 3))) === null || _a === void 0 ? void 0 : _a.substring(1, 3))) ||
            ((_b = geogKeys[0]) === null || _b === void 0 ? void 0 : _b.substring(1, 3)));
        return {
            coordinates: latLng,
            geogID: geographyId || geogKeys[0],
            microLocation: extractLevelFromGeography(locale, level, geographies, geographyId || "") || "",
            macroLocation: (level < 30 && extractLevelFromGeography(locale, 30, geographies)) ||
                "",
        };
    }, [geographies, isFetching]);
    return {
        isLoading: isFetching,
        geographies,
        locationInfo,
    };
}
//# sourceMappingURL=useGeoLocationInfo.js.map