import React from "react";
import { render, fireEvent } from "@testing-library/react";
import { describe, it, expect, vi } from "vitest";
import { Category } from "./index";
const tMock = vi.fn();
vi.mock("react-i18next", () => ({
    useTranslation: () => ({
        t: tMock,
    }),
}));
// Mock context
const mockUseRootElement = vi.fn();
const onSelectCategoryMock = vi.fn();
vi.mock("../context", () => ({
    useRootElement: () => mockUseRootElement(),
}));
describe("Category", () => {
    beforeEach(() => {
        vi.resetAllMocks();
    });
    it("renders without crashing", () => {
        mockUseRootElement.mockReturnValue({
            activeScore: null,
            isExpanded: true,
        });
        const { getByTestId } = render(React.createElement(Category, { categoryKey: "transport" }));
        expect(getByTestId("categories-toggle-category")).toBeInTheDocument();
    });
    it("renders the CategoryTitle with the correct categoryKey", () => {
        mockUseRootElement.mockReturnValue({
            activeScore: null,
            isExpanded: true,
        });
        const { getByTestId } = render(React.createElement(Category, { categoryKey: "transport" }));
        const categoryElement = getByTestId("categories-toggle-category");
        expect(categoryElement).toBeInTheDocument();
        expect(categoryElement).toHaveAttribute("data-category", "transport");
    });
    it("calls onSelectCategory when the category is clicked", () => {
        mockUseRootElement.mockReturnValue({
            activeScore: null,
            isExpanded: true,
            onSelectCategory: onSelectCategoryMock,
        });
        const { getByTestId } = render(React.createElement(Category, { categoryKey: "transport" }));
        const categoryElement = getByTestId("categories-toggle-category");
        fireEvent.click(categoryElement);
        expect(onSelectCategoryMock).toHaveBeenCalled();
    });
});
//# sourceMappingURL=index.test.js.map