import React from "react";
import { render, screen } from "@testing-library/react";
import { describe, it, expect, vi } from "vitest";
import { Score } from "./index";
vi.mock("./Header", () => ({
    Header: ({ scoreKey, scoreValue, backgroundColor, fillColor,
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
     }) => (React.createElement("div", { "data-testid": "mock-header", "data-score-key": scoreKey, "data-score-value": scoreValue, "data-background-color": backgroundColor, "data-fill-color": fillColor })),
}));
vi.mock("./Content", () => ({
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    Content: ({ activeScoreData }) => (React.createElement("div", { "data-testid": "mock-content" }, JSON.stringify(activeScoreData))),
}));
const mockUseRootElement = vi.fn();
vi.mock("../context", () => ({
    useRootElement: () => mockUseRootElement(),
}));
describe("Score", () => {
    it("renders with correct data attributes and children", () => {
        mockUseRootElement.mockReturnValue({
            scoresData: { pedestrian_friendly: { value: 1, some: "data" } },
            activeScore: "pedestrian_friendly",
            activeScoreData: { some: "data" },
            onSelectScore: vi.fn(),
        });
        render(React.createElement(Score, { scoreKey: "pedestrian_friendly" }));
        const button = screen.getByTestId("categories-toggle-slider-score");
        expect(button).toBeInTheDocument();
        expect(button).toHaveAttribute("data-score", "pedestrian_friendly");
        expect(button).toHaveAttribute("data-is-active", "true");
        const header = screen.getByTestId("mock-header");
        expect(header).toBeInTheDocument();
        expect(header).toHaveAttribute("data-score-key", "pedestrian_friendly");
        expect(header).toHaveAttribute("data-score-value", "1");
        expect(header).not.toHaveAttribute("data-background-color");
        expect(header).not.toHaveAttribute("data-fill-color");
        const content = screen.getByTestId("mock-content");
        expect(content).toBeInTheDocument();
        expect(content).toHaveTextContent(JSON.stringify({ some: "data" }));
    });
    it("calls onSelectScore when clicked", () => { });
    it("renders with custom backgroundColor and fillColor", () => {
        mockUseRootElement.mockReturnValue({
            scoresData: { pedestrian_friendly: { value: 1 } },
            activeScore: "pedestrian_friendly",
            activeScoreData: {},
            onSelectScore: vi.fn(),
        });
        render(React.createElement(Score, { scoreKey: "pedestrian_friendly", backgroundColor: "red", fillColor: "blue" }));
        const button = screen.getByTestId("categories-toggle-slider-score");
        expect(button).toHaveAttribute("data-score", "pedestrian_friendly");
        expect(button).toHaveAttribute("data-is-active", "true");
        const header = screen.getByTestId("mock-header");
        expect(header).toHaveAttribute("data-background-color", "red");
        expect(header).toHaveAttribute("data-fill-color", "blue");
    });
    it("handles missing onSelectScore gracefully", () => {
        mockUseRootElement.mockReturnValue({
            scoresData: { pedestrian_friendly: { value: 1 } },
            activeScore: "pedestrian_friendly",
            activeScoreData: {},
            onSelectScore: undefined,
        });
        render(React.createElement(Score, { scoreKey: "pedestrian_friendly" }));
        const button = screen.getByTestId("categories-toggle-slider-score");
        expect(button).toBeInTheDocument();
        expect(button).toHaveAttribute("data-score", "pedestrian_friendly");
        expect(button).toHaveAttribute("data-is-active", "true");
        expect(button).not.toHaveAttribute("onClick");
    });
});
//# sourceMappingURL=index.test.js.map