var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React from "react";
import { render, fireEvent } from "@testing-library/react";
import { describe, it, expect, vi } from "vitest";
import { CloseButton } from "./index";
// Mock i18next
vi.mock("react-i18next", () => ({
    useTranslation: () => ({
        t: (key) => key,
    }),
}));
// Mock design system Button
vi.mock("@local-logic/design-system", () => ({
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    Button: (_a) => {
        var { children, prefixIcon } = _a, rest = __rest(_a, ["children", "prefixIcon"]);
        return (React.createElement("button", Object.assign({}, rest), children));
    },
}));
const useRootElementMock = vi.fn();
const onSelectCategoryMock = vi.fn();
vi.mock("../../context", () => ({
    useRootElement: () => useRootElementMock(),
}));
describe("CloseButton", () => {
    beforeEach(() => {
        vi.resetAllMocks();
    });
    it("renders button with correct text", () => {
        useRootElementMock.mockReturnValue({
            onSelectCategory: onSelectCategoryMock,
        });
        const { getByTestId, getByText } = render(React.createElement(CloseButton, null));
        expect(getByTestId("categories-toggle-slider-close-button")).toBeInTheDocument();
        expect(getByText("categoriesToggle.backAction")).toBeInTheDocument();
    });
    it("calls onSelectCategory with null when clicked", () => {
        useRootElementMock.mockReturnValue({
            onSelectCategory: onSelectCategoryMock,
        });
        const { getByTestId } = render(React.createElement(CloseButton, null));
        fireEvent.click(getByTestId("categories-toggle-slider-close-button"));
        expect(onSelectCategoryMock).toHaveBeenCalledWith(null);
    });
    it("does not throw if onSelectCategory is undefined", () => {
        useRootElementMock.mockReturnValue({ onSelectCategory: undefined });
        const { getByTestId } = render(React.createElement(CloseButton, null));
        expect(() => {
            fireEvent.click(getByTestId("categories-toggle-slider-close-button"));
        }).not.toThrow();
    });
});
//# sourceMappingURL=index.test.js.map