var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React from "react";
import { render, fireEvent, screen } from "@testing-library/react";
import { describe, it, expect, vi } from "vitest";
import { Toggle } from "./index";
// Mock useTranslation from react-i18next
vi.mock("react-i18next", () => ({
    useTranslation: () => ({
        t: (key) => key,
    }),
}));
// Mock Button
vi.mock("@local-logic/design-system", () => ({
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    Button: (_a) => {
        var { children, prefixIcon } = _a, rest = __rest(_a, ["children", "prefixIcon"]);
        return (React.createElement("button", Object.assign({}, rest), children));
    },
}));
// Mock useRootElement context
const mockUseRootElement = vi.fn();
const mockOnToggleIsExpanded = vi.fn();
vi.mock("../context", () => ({
    useRootElement: () => mockUseRootElement(),
}));
describe("Toggle", () => {
    beforeEach(() => {
        vi.resetAllMocks();
    });
    it("renders the button with correct label", () => {
        mockUseRootElement.mockReturnValue({
            isExpanded: false,
        });
        render(React.createElement(Toggle, null));
        expect(screen.getByTestId("categories-toggle-button")).toHaveTextContent("categoriesToggle.toggleLabel");
    });
    it("calls onToggleIsExpanded when clicked", () => {
        mockUseRootElement.mockReturnValue({
            isExpanded: false,
            onToggleIsExpanded: mockOnToggleIsExpanded,
        });
        render(React.createElement(Toggle, null));
        fireEvent.click(screen.getByTestId("categories-toggle-button"));
        expect(mockOnToggleIsExpanded).toHaveBeenCalledTimes(1);
    });
    it("sets data-is-expanded attribute based on context", () => {
        mockUseRootElement.mockReturnValue({
            isExpanded: true,
            onToggleIsExpanded: mockOnToggleIsExpanded,
        });
        render(React.createElement(Toggle, null));
        expect(screen.getByTestId("categories-toggle-button")).toHaveAttribute("data-is-expanded", "true");
    });
});
//# sourceMappingURL=index.test.js.map