import React, { useMemo } from "react";
import "@local-logic/maps/style.css";
import { useLocalContent } from "~/sdks/LocalContent/context";
import { LocalLogicMap } from "@local-logic/maps";
import * as styles from "./styles";
export function Map({ children }) {
    const { location, map } = useLocalContent();
    const mapProviderConfig = useMemo(() => {
        var _a, _b, _c;
        const mapProvider = {
            name: ((_a = map.mapProvider) === null || _a === void 0 ? void 0 : _a.name) || "maptiler",
            apiKey: ((_b = map.mapProvider) === null || _b === void 0 ? void 0 : _b.key) || import.meta.env.VITE_MAPTILER_KEY,
            theme: (_c = map.mapProvider) === null || _c === void 0 ? void 0 : _c.theme,
        };
        if (typeof map.mapProvider !== "undefined") {
            if (map.mapProvider.name !== "maptiler" &&
                typeof map.mapProvider.key === "undefined") {
                throw new Error(`Map provider key is required. Please provide a valid key for the ${map.mapProvider.name} map provider.`);
            }
            if (map.mapProvider.name === "maptiler" &&
                typeof map.mapProvider.theme === "string" &&
                typeof map.mapProvider.key === "undefined") {
                mapProvider.theme = undefined; // Use default MapTiler theme if no key is provided
                // eslint-disable-next-line no-console
                console.warn("MapTiler theme is set but no API key is provided. Please provide a valid MapTiler API key. Using default LocalLogic MapTiler configuration and theme.");
            }
        }
        return mapProvider;
    }, [map.mapProvider]);
    // If location is not set or invalid, return a message
    // lat and lng values of 0 are considered invalid for this context
    if (!location || !location.lat || !location.lng) {
        return React.createElement("div", { className: styles.container }, "Location not set");
    }
    return (React.createElement("div", { className: styles.container },
        React.createElement(LocalLogicMap.Root, { mapProvider: mapProviderConfig, center: { latitude: location.lat, longitude: location.lng }, zoom: map.zoom, zoomPosition: "bottom-right", pitch: map.pitch, bearing: map.bearing, cooperativeGestures: map.cooperativeGestures },
            React.createElement(LocalLogicMap.BaseMap, null),
            children)));
}
//# sourceMappingURL=index.js.map