import React from "react";
import { render, screen } from "@testing-library/react";
import { describe, it, expect, vi, beforeEach } from "vitest";
import { ScoreMetroComparison } from "./index";
// Mock ValueIndicator
vi.mock("./ValueIndicator", () => ({
    ValueIndicator: ({ comparison }) => (React.createElement("div", { "data-testid": "value-indicator" }, comparison)),
}));
// Mock useTranslation
const tMock = vi.fn();
vi.mock("react-i18next", () => ({
    useTranslation: () => ({
        t: tMock,
    }),
}));
describe("ScoreMetroComparison", () => {
    beforeEach(() => {
        tMock.mockReset();
    });
    it("returns null if locationScoreValue is undefined", () => {
        const { container } = render(React.createElement(ScoreMetroComparison, { metroScoreValue: 50 }));
        expect(container.firstChild).toBeNull();
    });
    it("returns null if metroScoreValue is undefined", () => {
        const { container } = render(React.createElement(ScoreMetroComparison, { locationScoreValue: 50 }));
        expect(container.firstChild).toBeNull();
    });
    it("renders 'higher' comparison when locationScoreValue > metroScoreValue", () => {
        tMock.mockImplementation(() => "Higher than metro");
        render(React.createElement(ScoreMetroComparison, { locationScoreValue: 80, metroScoreValue: 50 }));
        expect(screen.getByTestId("score-metro-comparison")).toBeInTheDocument();
        expect(screen.getByTestId("value-indicator")).toHaveTextContent("higher");
        expect(tMock).toHaveBeenCalledWith("scoreMetroComparison.text", {
            context: "higher",
            metroScoreValue: 50,
        });
        expect(screen.getByText("Higher than metro")).toBeInTheDocument();
    });
    it("renders 'lower' comparison when locationScoreValue < metroScoreValue", () => {
        tMock.mockImplementation(() => "Lower than metro");
        render(React.createElement(ScoreMetroComparison, { locationScoreValue: 30, metroScoreValue: 60 }));
        expect(screen.getByTestId("score-metro-comparison")).toBeInTheDocument();
        expect(screen.getByTestId("value-indicator")).toHaveTextContent("lower");
        expect(tMock).toHaveBeenCalledWith("scoreMetroComparison.text", {
            context: "lower",
            metroScoreValue: 60,
        });
        expect(screen.getByText("Lower than metro")).toBeInTheDocument();
    });
    it("renders 'equal' comparison when locationScoreValue === metroScoreValue", () => {
        tMock.mockImplementation(() => "Equal to metro");
        render(React.createElement(ScoreMetroComparison, { locationScoreValue: 70, metroScoreValue: 70 }));
        expect(screen.getByTestId("score-metro-comparison")).toBeInTheDocument();
        expect(screen.getByTestId("value-indicator")).toHaveTextContent("equal");
        expect(tMock).toHaveBeenCalledWith("scoreMetroComparison.text", {
            context: undefined,
            metroScoreValue: 70,
        });
        expect(screen.getByText("Equal to metro")).toBeInTheDocument();
    });
});
//# sourceMappingURL=index.test.js.map