import React from "react";
import { render, screen } from "@testing-library/react";
import { describe, it, expect } from "vitest";
import { ScoreValue } from "./index";
describe("ScoreValue", () => {
    it("renders the score when value is between 1 and 10", () => {
        render(React.createElement(ScoreValue, { value: 7 }));
        expect(screen.getByTestId("score-value")).toHaveTextContent("7 / 10");
    });
    it("does not render when value is undefined", () => {
        const { container } = render(React.createElement(ScoreValue, null));
        expect(container.firstChild).toBeNull();
    });
    it("does not render when value is 0", () => {
        const { container } = render(React.createElement(ScoreValue, { value: 0 }));
        expect(container.firstChild).toBeNull();
    });
    it("does not render when value is negative", () => {
        const { container } = render(React.createElement(ScoreValue, { value: -3 }));
        expect(container.firstChild).toBeNull();
    });
    it("does not render when value is not a number", () => {
        // @ts-expect-error testing invalid prop
        const { container } = render(React.createElement(ScoreValue, { value: "abc" }));
        expect(container.firstChild).toBeNull();
    });
    it("renders the minimum valid value", () => {
        render(React.createElement(ScoreValue, { value: 1 }));
        expect(screen.getByTestId("score-value")).toHaveTextContent("1 / 10");
    });
    it("renders the maximum valid value", () => {
        render(React.createElement(ScoreValue, { value: 10 }));
        expect(screen.getByTestId("score-value")).toHaveTextContent("10 / 10");
    });
    it("caps the score at 10", () => {
        render(React.createElement(ScoreValue, { value: 15 }));
        expect(screen.getByTestId("score-value")).toHaveTextContent("10 / 10");
    });
});
//# sourceMappingURL=index.test.js.map