import React from "react";
import { render, screen } from "@testing-library/react";
import { describe, it, expect, vi, beforeEach } from "vitest";
import { Header } from "./index";
// Mock dependencies
vi.mock("react-i18next", () => ({
    useTranslation: () => ({
        t: (key) => key,
    }),
}));
const mockScoresMenu = {
    categories: [
        [
            "transport",
            {
                colors: { background: "red", fill: "blue" },
                scores: [["pedestrian_friendly"], ["transit_friendly"]],
            },
        ],
        [
            "amenities",
            {
                colors: { background: "green", fill: "yellow" },
                scores: [["shopping"]],
            },
        ],
    ],
};
vi.mock("~/sdks/LocalContent/context", () => ({
    useLocalContent: () => ({
        scoresMenu: mockScoresMenu,
    }),
}));
vi.mock("~/sdks/LocalContent/components/ScoreValue", () => ({
    ScoreValue: ({ value }) => (React.createElement("span", { "data-testid": "score-value" }, value)),
}));
vi.mock("~/sdks/LocalContent/components/ColorIcon", () => ({
    ColorIcon: ({ element, backgroundColor, fillColor }) => (React.createElement("span", { "data-testid": "color-icon" },
        element,
        backgroundColor,
        fillColor)),
}));
vi.mock("~/components/ScoreIcon", () => ({
    ScoreIcon: ({ score }) => (React.createElement("span", { "data-testid": "score-icon" }, score)),
}));
describe("Header", () => {
    beforeEach(() => {
        vi.resetAllMocks();
    });
    it("renders null if scoreKey is null", () => {
        const { container } = render(React.createElement(Header, { scoreKey: null, scoreValue: 10 }));
        expect(container.firstChild).toBeNull();
    });
    it("renders header with correct scoreKey and value", () => {
        render(React.createElement(Header, { scoreKey: "pedestrian_friendly", scoreValue: 10 }));
        expect(screen.getByTestId("sidebar-score-details-header")).toBeInTheDocument();
        expect(screen.getByTestId("score-value")).toHaveTextContent("10");
        expect(screen.getByTestId("score-icon")).toHaveTextContent("pedestrian_friendly");
        expect(screen.getByText("common:scores.pedestrian_friendly.title")).toBeInTheDocument();
    });
    it("renders ScoreValue with undefined if scoreValue is not provided", () => {
        render(React.createElement(Header, { scoreKey: "pedestrian_friendly" }));
        expect(screen.getByTestId("score-value")).toHaveTextContent("");
    });
});
//# sourceMappingURL=index.test.js.map