import React from "react";
import { render, screen } from "@testing-library/react";
import { describe, it, expect, vi, beforeEach } from "vitest";
import { ScoreDetails } from "./index";
vi.mock("react-i18next", () => ({
    useTranslation: () => ({
        t: (key) => key,
    }),
}));
// Mock Header component
vi.mock("./Header", () => ({
    Header: ({ scoreKey, scoreValue }) => (React.createElement("div", { "data-testid": "mock-header" },
        scoreKey,
        ":",
        scoreValue)),
}));
// Mock context hooks
const mockUseRootElement = vi.fn();
vi.mock("../context", () => ({
    useRootElement: () => mockUseRootElement(),
}));
describe("ScoreDetails", () => {
    beforeEach(() => {
        vi.resetAllMocks();
    });
    it("renders nothing if activeScoreData is undefined", () => {
        mockUseRootElement.mockReturnValue({
            activeScore: "score1",
            activeScoreData: undefined,
        });
        render(React.createElement(ScoreDetails, null));
        expect(screen.getByTestId("sidebar-score-details")).toBeInTheDocument();
        expect(screen.queryByTestId("score-description")).toBeNull();
    });
    it("renders nothing if activeScore is undefined", () => {
        mockUseRootElement.mockReturnValue({
            activeScore: undefined,
            activeScoreData: undefined,
        });
        render(React.createElement(ScoreDetails, null));
        expect(screen.getByTestId("sidebar-score-details")).toBeInTheDocument();
        expect(screen.queryByTestId("score-description")).toBeNull();
    });
    it("renders score details with correct score value", () => {
        mockUseRootElement.mockReturnValue({
            activeScore: "score1",
            activeScoreData: {
                value: "4.56",
            },
        });
        render(React.createElement(ScoreDetails, null));
        expect(screen.getByTestId("sidebar-score-details")).toBeInTheDocument();
        expect(screen.getByTestId("mock-header").textContent).toBe("score1:4.56");
    });
    it("renders score details with correct metro score comparison", () => {
        mockUseRootElement.mockReturnValue({
            activeScore: "score1",
            activeScoreData: {
                value: "4.56",
                metroValue: "5",
            },
        });
        render(React.createElement(ScoreDetails, null));
        expect(screen.getByTestId("sidebar-score-details")).toBeInTheDocument();
        expect(screen.getByTestId("score-metro-comparison")).toBeInTheDocument();
    });
    it("renders score details with correct score description", () => {
        mockUseRootElement.mockReturnValue({
            activeScore: "score1",
            activeScoreData: {
                text: "Score description",
            },
        });
        render(React.createElement(ScoreDetails, null));
        expect(screen.getByTestId("sidebar-score-details")).toBeInTheDocument();
        expect(screen.getByTestId("score-description").textContent).toBe("Score description");
    });
    it("renders empty description if text is undefined", () => {
        mockUseRootElement.mockReturnValue({
            activeScore: "score3",
            activeScoreData: { value: "2.5" },
        });
        render(React.createElement(ScoreDetails, null));
        expect(screen.getByTestId("sidebar-score-details")).toBeInTheDocument();
        expect(screen.queryByTestId("score-description")).toBeNull();
    });
});
//# sourceMappingURL=index.test.js.map