import React, { useContext, useMemo } from "react";
import { useTracking } from "@local-logic/core/tracking";
import { useScoreSelection } from "~/sdks/LocalContent/hooks/useScoreSelection";
import { useMarkers } from "~/sdks/LocalContent/hooks/useMarkers";
import useEffectOnce from "~/hooks/useEffectOnce";
import { useStateManagerContext } from "~/context/stateManager";
import { transformScoresMenuData } from "./utils/transformScoresMenuData";
import { TrackingPipelineEvents, AnalyticsEvents, } from "./types";
const LocalContentContext = React.createContext({});
const useLocalContent = () => useContext(LocalContentContext);
const LocalContentProvider = ({ children, }) => {
    var _a, _b, _c, _d, _e, _f;
    const { sdkState } = useStateManagerContext();
    const tracking = useTracking();
    useEffectOnce(() => {
        tracking.postEvent({
            eventType: TrackingPipelineEvents.SDK_VIEWED,
        });
        tracking.trackAnalyticsEvent({
            eventName: AnalyticsEvents.SDK_VIEWED,
        });
    });
    const sortedScoresMenu = useMemo(() => { var _a; return transformScoresMenuData((_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.scoresMenu); }, [(_b = (_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.scoresMenu) === null || _b === void 0 ? void 0 : _b.categories]);
    const { isLoading: isScoresLoading, scoresData, activeScore, activeScoreData, activeCategory, activeCategoryData, handleSelectScore, handleSelectCategory, } = useScoreSelection({
        scoresMenu: sortedScoresMenu,
        lat: ((_c = sdkState === null || sdkState === void 0 ? void 0 : sdkState.options) === null || _c === void 0 ? void 0 : _c.lat) || 0,
        lng: ((_d = sdkState === null || sdkState === void 0 ? void 0 : sdkState.options) === null || _d === void 0 ? void 0 : _d.lng) || 0,
    });
    const { isLoading: isMarkersLoading, data: markersData } = useMarkers({
        lat: ((_e = sdkState === null || sdkState === void 0 ? void 0 : sdkState.options) === null || _e === void 0 ? void 0 : _e.lat) || 0,
        lng: ((_f = sdkState === null || sdkState === void 0 ? void 0 : sdkState.options) === null || _f === void 0 ? void 0 : _f.lng) || 0,
        category: activeScore || undefined,
    });
    const contextValue = useMemo(() => {
        var _a, _b, _c, _d, _e, _f, _g;
        return ({
            isLoading: isScoresLoading || isMarkersLoading,
            location: {
                lat: ((_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.lat) || 0,
                lng: ((_b = sdkState.options) === null || _b === void 0 ? void 0 : _b.lng) || 0,
            },
            map: {
                mapProvider: (_c = sdkState.options) === null || _c === void 0 ? void 0 : _c.mapProvider,
                zoom: (_d = sdkState.options) === null || _d === void 0 ? void 0 : _d.zoom,
                pitch: (_e = sdkState.options) === null || _e === void 0 ? void 0 : _e.pitch,
                bearing: (_f = sdkState.options) === null || _f === void 0 ? void 0 : _f.bearing,
                cooperativeGestures: (_g = sdkState.options) === null || _g === void 0 ? void 0 : _g.cooperativeGestures,
            },
            scoresMenu: sortedScoresMenu,
            markersData,
            scoresData,
            activeScore,
            activeScoreData,
            activeCategory,
            activeCategoryData,
            handleSelectScore,
            handleSelectCategory,
        });
    }, [
        isScoresLoading,
        isMarkersLoading,
        sdkState.options,
        sortedScoresMenu,
        markersData,
        scoresData,
        activeScore,
        activeScoreData,
        activeCategory,
        activeCategoryData,
        handleSelectScore,
        handleSelectCategory,
    ]);
    return (React.createElement(LocalContentContext.Provider, { value: contextValue }, children));
};
export { useLocalContent, LocalContentProvider };
//# sourceMappingURL=context.js.map