import { useMemo } from "react";
import { usePois } from "~/features/clientLibrary/usePois";
import { useSchools } from "~/features/clientLibrary/useSchools";
import { categories } from "./constants";
const schools = Object.keys(categories).filter((key) => key.includes("schools"));
export const useMarkers = ({ lat, lng, category, radius = 2000 }) => {
    const { isLoading: isPoisLoading, data: poisData } = usePois({
        lat,
        lng,
        include: category && !schools.includes(category)
            ? categories[category]
            : undefined,
        limit: 20,
        radius,
    });
    const { isLoading: isSchoolsLoading, data: schoolsData } = useSchools({
        lat,
        lng,
        include: category && schools.includes(category)
            ? categories[category]
            : undefined,
        limit: 20,
        radius,
        includeCatchments: true,
    });
    const markers = useMemo(() => {
        if (typeof category === "string" && schools.includes(category)) {
            return schoolsData;
        }
        return poisData;
    }, [poisData, schoolsData]);
    return {
        isLoading: isPoisLoading || isSchoolsLoading,
        data: markers,
    };
};
//# sourceMappingURL=index.js.map