import React, { useMemo, useCallback } from "react";
import { useScores } from "~/features/clientLibrary/useScores";
import { transformScoresAPIResponse } from "./utils/transformScoresAPIResponse";
export function useScoreSelection({ scoresMenu, lat, lng, }) {
    const [activeScore, setActiveScore] = React.useState(null);
    const [activeCategory, setActiveCategory] = React.useState(null);
    const { data, isFetching: isScoresFetching } = useScores({
        location: {
            lat,
            lng,
        },
    });
    const scoresData = useMemo(() => transformScoresAPIResponse(data, scoresMenu), [data, scoresMenu]);
    const activeCategoryData = useMemo(() => {
        if (!activeCategory || !scoresMenu)
            return null;
        const category = scoresMenu.categories.find(([key]) => key === activeCategory);
        if (!category)
            return null;
        return category[1];
    }, [activeCategory, scoresMenu]);
    const handleSelectScore = useCallback((scoreKey) => () => {
        setActiveScore((prev) => (prev === scoreKey ? null : scoreKey));
    }, [setActiveScore]);
    const handleSelectCategory = useCallback((categoryKey) => () => {
        setActiveCategory((prev) => (prev === categoryKey ? null : categoryKey));
    }, [setActiveCategory]);
    return {
        isLoading: isScoresFetching,
        scoresData,
        activeScore,
        activeScoreData: activeScore === null ? undefined : scoresData[activeScore],
        activeCategory,
        activeCategoryData,
        handleSelectScore,
        handleSelectCategory,
    };
}
//# sourceMappingURL=index.js.map