import type { SDKOptions } from "~/types/options";
export type MapProviderNames = "maptiler" | "mapbox" | "google";
export type MapProvider = {
    name: MapProviderNames;
    key?: string;
    theme?: string;
};
export type CategoryKey = "transport" | "education" | "amenities" | "character" | "nature" | "wellness";
export type TransportScoreKey = "pedestrian_friendly" | "transit_friendly" | "cycling_friendly" | "car_friendly";
export type EducationScoreKey = "daycares" | "primary_schools" | "high_schools";
export type AmenitiesScoreKey = "shopping" | "groceries" | "restaurants" | "cafes";
export type CharacterScoreKey = "nightlife" | "vibrant" | "historic" | "quiet";
export type NatureScoreKey = "parks" | "greenery";
export type WellnessScoreKey = "wellness";
export type ScoreKey = TransportScoreKey | EducationScoreKey | AmenitiesScoreKey | CharacterScoreKey | NatureScoreKey | WellnessScoreKey;
export type ScoreOptions = {
    hide?: boolean;
    hideScore?: boolean;
    order?: number;
};
export type CategoryOptions = {
    hide?: boolean;
    order?: number;
    colors?: {
        background: string;
        fill: string;
    };
    scores?: {
        [key in ScoreKey]?: ScoreOptions;
    };
};
export type Options = {
    lat?: number;
    lng?: number;
    zoom?: number;
    pitch?: number;
    bearing?: number;
    distanceUnit?: "metric" | "imperial";
    marker?: {
        lat: number;
        lng: number;
        icon?: "house" | "pin";
        addressLabel?: string;
    };
    cooperativeGestures?: boolean;
    mapProvider?: MapProvider;
    hideScores?: boolean;
    collapseScores?: boolean;
    scoresMenu?: {
        defaultOpen?: boolean;
        title?: boolean | string;
        categories?: {
            [key in CategoryKey]?: CategoryOptions;
        };
    };
};
export type LocalContentProps = SDKOptions<Options, {
    options: Options | undefined;
}>;
export declare enum TrackingPipelineEvents {
    SDK_VIEWED = "LC-Viewed",
    CATEGORY_CLICKED = "LC-Category-Clicked",
    SCORE_CLICKED = "LC-Score-Clicked",
    TRANSPORT_METHOD_CLICKED = "LC-Transportation-Method-Clicked",
    LONG_DESCRIPTION_CLICKED = "LC-Long-Description-Clicked",
    POI_CLICKED = "LC-POI-Clicked",
    COMMUTE_CALCULATOR_CLICKED = "LC-Commute-Comute-Calc-Clicked",
    COMMUTE_CALCULATE_ROUTE = "LC-Commute-Calculate-Route",
    ATTRIBUTION_CLICKED = "LC-Attribution-Clicked"
}
export declare enum AnalyticsEvents {
    SDK_VIEWED = "sdk_viewed",
    CATEGORY_SELECTED = "category_selected",
    SCORE_EXPANDED = "score_expanded",
    SCORE_POI_SELECTED = "score_poi_selected",
    POI_CALCULATE_ROUTE = "poi_calculate_route",
    MAP_POI_SELECTED = "map_poi_selected",
    SEARCH_CALCULATE_ROUTE = "search_calculate_route"
}
//# sourceMappingURL=types.d.ts.map