import { Input } from "@local-logic/core/ui";
import { browserUtils } from "@local-logic/core/utils";
import React, { useState, useEffect, useMemo } from "react";
import useDebounce from "~/hooks/useDebounce";
import { useStateManagerContext } from "~/context/stateManager";
import { useLocation } from "~/hooks/useLocation";
import { useSuggestions } from "~/sdks/LocalContentDeprecated/hooks/useSuggestions";
import { useLocalContent } from "~/sdks/LocalContentDeprecated/context";
import Search from "../Search";
const MapGLSearch = ({ label, onSearch, onSelect, placeholder, renderListAbove = true, }) => {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j;
    const { isInputAutoFocused, country, setCountry } = useLocalContent();
    const { sdkState } = useStateManagerContext();
    const [query, setQuery] = useState("");
    const { data: location } = useLocation({
        lat: (_b = (_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.marker) === null || _b === void 0 ? void 0 : _b.lat,
        lng: (_d = (_c = sdkState.options) === null || _c === void 0 ? void 0 : _c.marker) === null || _d === void 0 ? void 0 : _d.lng,
    });
    const debouncedQuery = useDebounce(query, 1250);
    const [showResults, setShowResults] = useState(false);
    const suggestionInputs = ((_e = sdkState.options) === null || _e === void 0 ? void 0 : _e.marker)
        ? {
            query: debouncedQuery,
            proximity: `${(_g = (_f = sdkState.options) === null || _f === void 0 ? void 0 : _f.marker) === null || _g === void 0 ? void 0 : _g.lng},${(_j = (_h = sdkState.options) === null || _h === void 0 ? void 0 : _h.marker) === null || _j === void 0 ? void 0 : _j.lat}`,
            country,
        }
        : {
            query: debouncedQuery,
            country,
        };
    const { data } = useSuggestions(suggestionInputs);
    const suggestionResults = useMemo(() => !query
        ? browserUtils.commuteHistory.getSuggestionHistory()
        : (data === null || data === void 0 ? void 0 : data.suggestions) || [], [query, data === null || data === void 0 ? void 0 : data.suggestions]);
    useEffect(() => {
        if (!location) {
            return;
        }
        if (location.country !== country) {
            setCountry(location.country);
        }
    }, [location, country]);
    const handleItemClick = ({ address }) => {
        if (!address) {
            return;
        }
        const addressDescription = address.description || "";
        setQuery(addressDescription);
        if (address.coordinates) {
            onSearch({
                address: addressDescription,
                longitude: address.coordinates.longitude,
                latitude: address.coordinates.latitude,
            });
        }
        browserUtils.commuteHistory.push({ address });
    };
    return (React.createElement(Search, { onSelect: onSelect, renderListAbove: renderListAbove, query: query, showResults: showResults, suggestionResults: suggestionResults, onClick: handleItemClick },
        React.createElement(Input, { autofocus: isInputAutoFocused, value: query, label: label, placeholder: placeholder, onFocus: () => setShowResults(true), onBlur: () => setShowResults(false), onChange: (e) => {
                setQuery(e.currentTarget.value);
                setShowResults(true);
            } })));
};
export default MapGLSearch;
//# sourceMappingURL=index.js.map