import { primitiveUtils } from "@local-logic/core/utils";
import { motion } from "framer-motion";
import React from "react";
import AnimateHeight from "~/components/AnimateHeight";
import { textWithHighlighting } from "~/utils/formatters/textWithHighlighting";
import * as styles from "./styles";
const Search = ({ onClick, onSelect, renderListAbove = true, children, query, showResults, suggestionResults, }) => {
    const handleClick = (suggestion) => {
        if (!suggestion || !onClick)
            return;
        onClick(suggestion);
    };
    return (React.createElement("div", { className: styles.search, onSelect: onSelect },
        children,
        React.createElement("div", { className: styles.searchPosition(renderListAbove) },
            React.createElement(AnimateHeight, { open: showResults && !!suggestionResults.length },
                React.createElement("ul", { className: styles.searchList }, suggestionResults.map((suggestion, i) => (React.createElement("li", { className: styles.listItem, key: suggestion.locationId || `address-${i}` },
                    React.createElement("button", { className: styles.button, onClick: () => handleClick(suggestion) },
                        React.createElement(motion.div, { animate: { y: [10, 0], opacity: [0, 1] }, transition: {
                                delay: (i + 1) * 0.03,
                                type: "spring",
                                duration: 0.4,
                            } }, suggestion.address && suggestion.address.description
                            ? textWithHighlighting(suggestion.address.description, query)
                            : textWithHighlighting(primitiveUtils.string.formatAddress(suggestion.address), query)))))))))));
};
export default Search;
//# sourceMappingURL=index.js.map