import React from "react";
import { useTracking } from "@local-logic/core/tracking";
import { useTranslation } from "react-i18next";
import { Select } from "@local-logic/core/ui";
import useIsMobile from "~/hooks/useIsMobile";
import { useStateManagerContext } from "~/context/stateManager";
import { TrackingPipelineEvents, } from "~/sdks/LocalContentDeprecated/types";
import errorTracker from "~/utils/errorTracker";
import { TransportIcon } from "~/components/TransportIcon";
import MapGLSearch from "./SearchContainer/MapGLSearch";
import GoogleSearch from "./SearchContainer/GoogleSearch";
import * as styles from "./styles";
export default function AddressSearch({ transportMode, placeholder, onTransportModeChanged, onDestinationSelected, }) {
    var _a, _b;
    const { t } = useTranslation("localContent");
    const { sdkState } = useStateManagerContext();
    const tracking = useTracking();
    const isGoogleMapProvider = ((_b = (_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.mapProvider) === null || _b === void 0 ? void 0 : _b.name) === "google";
    const isMobile = useIsMobile();
    const handleUpdateTransportMode = (mode) => {
        errorTracker.addBreadCrumb("AddressSearch", "handleUpdateTransportMode", {
            mode,
        });
        onTransportModeChanged(mode);
        tracking.postEvent({
            eventType: TrackingPipelineEvents.TRANSPORT_METHOD_CLICKED,
            eventAttributes: [
                {
                    label: "commute-select-mode",
                    data: mode,
                },
            ],
        });
    };
    const handleOnDestinationSelected = (destination) => {
        errorTracker.addBreadCrumb("AddressSearch", "handleOnDestinationSelected", {
            destination,
        });
        onDestinationSelected(destination);
    };
    return (React.createElement("div", { className: styles.container },
        isGoogleMapProvider ? (React.createElement(GoogleSearch, { label: t("commuteCalculator.cta"), placeholder: placeholder || t("commuteCalculator.placeholder"), renderListAbove: isMobile, onSearch: (e) => {
                handleOnDestinationSelected({
                    label: e.address,
                    lat: e.latitude,
                    lng: e.longitude,
                });
            } })) : (React.createElement(MapGLSearch, { label: t("commuteCalculator.cta"), placeholder: placeholder || t("commuteCalculator.placeholder"), renderListAbove: isMobile, onSearch: (e) => {
                handleOnDestinationSelected({
                    label: e.address,
                    lat: e.latitude,
                    lng: e.longitude,
                });
            } })),
        React.createElement("div", { className: styles.selectContainer },
            React.createElement(Select.Root, { value: transportMode, onValueChange: handleUpdateTransportMode },
                React.createElement(Select.Trigger, { size: "large" },
                    React.createElement(TransportIcon, { transport: transportMode, className: styles.icon }),
                    t(`commuteCalculator.type.${transportMode}`),
                    React.createElement(Select.Content, null,
                        React.createElement(Select.Item, { value: "car" }, t("commuteCalculator.type.car")),
                        React.createElement(Select.Item, { value: "pedestrian" }, t("commuteCalculator.type.pedestrian"))))))));
}
//# sourceMappingURL=index.js.map