import React, { useEffect, useMemo, useState } from "react";
import { useStateManagerContext } from "~/context/stateManager";
import { useLocalContent } from "~/sdks/LocalContentDeprecated/context";
import { formatDestination, formatOrigin, useGoogleComputeRoute, } from "~/sdks/LocalContentDeprecated/features/useGoogleComputeRoute";
import { useTracking } from "@local-logic/core/tracking";
import { AnalyticsEvents, } from "~/sdks/LocalContentDeprecated/types";
import * as styles from "../styles";
import CloseButton from "../CloseButton";
import AddressSearch from "../AddressSearch";
import CommuteInfo from "../CommuteInfo";
const googleTransportModeMap = {
    pedestrian: "walk",
    car: "drive",
};
const GoogleCommuteCalculator = ({ onClose }) => {
    var _a, _b, _c;
    const { sdkState } = useStateManagerContext();
    const { destination, setDestination, setCommuteGeojson } = useLocalContent();
    const [transportMode, setTransportMode] = useState("pedestrian");
    const tracking = useTracking();
    if (!((_b = (_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.mapProvider) === null || _b === void 0 ? void 0 : _b.key))
        return React.createElement(React.Fragment, null);
    const { data, isFetching, isFetched } = useGoogleComputeRoute({
        travelMode: googleTransportModeMap[transportMode].toUpperCase(),
        origin: formatOrigin(sdkState),
        destination: formatDestination(destination),
        units: "METRIC",
        polylineEncoding: "ENCODED_POLYLINE",
        googleApiKey: sdkState.options.mapProvider.key,
        locale: ((_c = sdkState.globalOptions) === null || _c === void 0 ? void 0 : _c.locale) || "en",
    });
    useEffect(() => {
        var _a;
        if (!((_a = data === null || data === void 0 ? void 0 : data.routes) === null || _a === void 0 ? void 0 : _a.length)) {
            return;
        }
        const decodedPolyline = data &&
            google.maps.geometry.encoding.decodePath(data === null || data === void 0 ? void 0 : data.routes[0].polyline.encodedPolyline);
        setCommuteGeojson(decodedPolyline);
    }, [data]);
    const duration = useMemo(() => {
        var _a, _b, _c, _d;
        if ((_a = data === null || data === void 0 ? void 0 : data.routes) === null || _a === void 0 ? void 0 : _a.length) {
            return (_d = (_c = (_b = data.routes[0].localizedValues) === null || _b === void 0 ? void 0 : _b.duration) === null || _c === void 0 ? void 0 : _c.text) !== null && _d !== void 0 ? _d : "";
        }
        return "";
    }, [data]);
    const distance = useMemo(() => {
        var _a, _b, _c, _d;
        if ((_a = data === null || data === void 0 ? void 0 : data.routes) === null || _a === void 0 ? void 0 : _a.length) {
            return (_d = (_c = (_b = data.routes[0].localizedValues) === null || _b === void 0 ? void 0 : _b.distance) === null || _c === void 0 ? void 0 : _c.text) !== null && _d !== void 0 ? _d : "";
        }
        return "";
    }, [data]);
    const handleDestinationSelected = (selectedDestination) => {
        setDestination(selectedDestination);
        tracking.trackAnalyticsEvent({
            eventName: AnalyticsEvents.SEARCH_CALCULATE_ROUTE,
        });
    };
    return (React.createElement("div", { className: styles.container },
        React.createElement(CloseButton, { onClick: onClose }),
        React.createElement(AddressSearch, { transportMode: transportMode, placeholder: destination === null || destination === void 0 ? void 0 : destination.label, onTransportModeChanged: setTransportMode, onDestinationSelected: handleDestinationSelected }),
        React.createElement(CommuteInfo, { isFetching: isFetching, isFetched: isFetched, data: {
                duration,
                distance,
            } })));
};
export default GoogleCommuteCalculator;
//# sourceMappingURL=index.js.map