import React, { useEffect, useMemo, useState } from "react";
import { mapUtils } from "@local-logic/core/utils";
import { useTranslation } from "react-i18next";
import { useStateManagerContext } from "~/context/stateManager";
import { useCalculateRouteProxy } from "~/features/calculateRoute/useCommute";
import { useLocalContent } from "~/sdks/LocalContentDeprecated/context";
import { AnalyticsEvents, } from "~/sdks/LocalContentDeprecated/types";
import { useTracking } from "@local-logic/core/tracking";
import * as styles from "../styles";
import CloseButton from "../CloseButton";
import AddressSearch from "../AddressSearch";
import CommuteInfo from "../CommuteInfo";
const MapGLCommuteCalculator = ({ className, onClose, }) => {
    var _a, _b, _c, _d;
    const { t } = useTranslation(["common"]);
    const { sdkState } = useStateManagerContext();
    const { setCommuteGeojson, destination, setDestination } = useLocalContent();
    const [transportMode, setTransportMode] = useState("pedestrian");
    const tracking = useTracking();
    const { data, isFetching, isFetched } = useCalculateRouteProxy({
        destination: `${destination === null || destination === void 0 ? void 0 : destination.lng},${destination === null || destination === void 0 ? void 0 : destination.lat}`,
        transportMode,
        origin: `${(_b = (_a = sdkState === null || sdkState === void 0 ? void 0 : sdkState.options) === null || _a === void 0 ? void 0 : _a.marker) === null || _b === void 0 ? void 0 : _b.lng},${(_d = (_c = sdkState === null || sdkState === void 0 ? void 0 : sdkState.options) === null || _c === void 0 ? void 0 : _c.marker) === null || _d === void 0 ? void 0 : _d.lat}`,
        isOpen: true,
    });
    useEffect(() => {
        if (!(data === null || data === void 0 ? void 0 : data.geometry)) {
            return;
        }
        setCommuteGeojson(mapUtils.formatMapBoxGeoJson(data.geometry));
    }, [data]);
    const duration = useMemo(() => {
        if (!(data === null || data === void 0 ? void 0 : data.duration)) {
            return null;
        }
        const hours = Math.floor(data.duration / 60 / 60);
        const minutes = Math.floor((data.duration / 60) % 60);
        const minutesString = `${minutes} ${t("common:time.minute", { count: minutes })}`;
        if (hours === 0) {
            return minutesString;
        }
        return `${hours} ${t("common:time.hour", { count: hours })} ${minutesString}`;
    }, [data]);
    const distance = useMemo(() => {
        var _a;
        if (!(data === null || data === void 0 ? void 0 : data.distance)) {
            return null;
        }
        // HereApi returns the length in metric
        let distanceInUnit = data.distance;
        const isImperialSystem = ((_a = sdkState === null || sdkState === void 0 ? void 0 : sdkState.options) === null || _a === void 0 ? void 0 : _a.distanceUnit) === "imperial";
        if (isImperialSystem) {
            distanceInUnit *= 1.0936132983;
        }
        const kilometersOrMiles = distanceInUnit / (isImperialSystem ? 1760 : 1000);
        if (kilometersOrMiles === 0) {
            return `${Math.floor(distanceInUnit)} ${t(`common:distance.${isImperialSystem ? "yard" : "meter"}`)}`;
        }
        return `${Math.floor(kilometersOrMiles * 100) / 100} ${t(`common:distance.${isImperialSystem ? "mile" : "kilometer"}`)}`;
    }, [data]);
    const handleDestinationSelected = (selectedDestination) => {
        setDestination(selectedDestination);
        tracking.trackAnalyticsEvent({
            eventName: AnalyticsEvents.SEARCH_CALCULATE_ROUTE,
        });
    };
    return (React.createElement("div", { className: styles.container },
        React.createElement(CloseButton, { onClick: onClose }),
        React.createElement(AddressSearch, { transportMode: transportMode, placeholder: destination === null || destination === void 0 ? void 0 : destination.label, onTransportModeChanged: setTransportMode, onDestinationSelected: handleDestinationSelected }),
        React.createElement(CommuteInfo, { isFetching: isFetching, isFetched: isFetched, data: {
                duration,
                distance,
            } })));
};
export default MapGLCommuteCalculator;
//# sourceMappingURL=index.js.map