import React, { useEffect } from "react";
import { useTranslation } from "react-i18next";
import { useTracking } from "@local-logic/core/tracking";
import { useStateManagerContext } from "~/context/stateManager";
import { Button } from "@local-logic/core/ui";
import { IconButton } from "~/sdks/LocalContentDeprecated/components/IconButton";
import { TrafficSign as TrafficSignIcon } from "@phosphor-icons/react";
import useIsMobile from "~/hooks/useIsMobile";
import { useLocalContent } from "~/sdks/LocalContentDeprecated/context";
import { TrackingPipelineEvents, } from "~/sdks/LocalContentDeprecated/types";
import errorTracker from "~/utils/errorTracker";
import CommuteCalculator from "./CommuteCalculator";
import * as styles from "./styles";
const CommuteContainer = () => {
    var _a;
    const { t } = useTranslation("localContent");
    const { setCommuteGeojson, setDestination, showCommuteCalculator, setShowCommuteCalculator, setIsInputAutoFocused, } = useLocalContent();
    const { sdkState } = useStateManagerContext();
    const isMobile = useIsMobile();
    const tracking = useTracking();
    useEffect(() => {
        if (showCommuteCalculator) {
            tracking.postEvent({
                eventType: TrackingPipelineEvents.COMMUTE_CALCULATOR_CLICKED,
            });
        }
    }, [showCommuteCalculator]);
    const closeCommute = () => {
        errorTracker.addBreadCrumb("CommuteContainer", "closeCommute");
        setDestination(undefined);
        setCommuteGeojson(undefined);
        setShowCommuteCalculator(false);
    };
    const openCommute = () => {
        errorTracker.addBreadCrumb("CommuteContainer", "openCommute");
        // clear destination before a new search
        setDestination(undefined);
        setShowCommuteCalculator(true);
        setIsInputAutoFocused(true);
    };
    if (typeof ((_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.marker) === "undefined") {
        return null;
    }
    return (React.createElement("div", { className: styles.container }, showCommuteCalculator ? (React.createElement(CommuteCalculator, { className: styles.container, onClose: closeCommute })) : (React.createElement(React.Fragment, null,
        React.createElement("div", { className: styles.buttonContainer },
            React.createElement(Button, { onClick: openCommute, startAdornment: (React.createElement(TrafficSignIcon, { className: styles.icon })) }, t("commuteCalculator.cta"))),
        isMobile && (
        /* Because of some styles in the IconButton, this condition is necessary */
        /* The flex display is forced otherwise */
        React.createElement(IconButton, { className: styles.commuteTogglePill, size: "large", icon: TrafficSignIcon, onClick: openCommute }))))));
};
export default CommuteContainer;
//# sourceMappingURL=index.js.map