import { useTracking } from "@local-logic/core/tracking";
import { scorePois } from "~/sdks/LocalContentDeprecated/constants/score-categories";
import * as ScoreE from "~/sdks/LocalContentDeprecated/components/Score";
import * as Accordion from "@radix-ui/react-accordion";
import React, { useEffect, useState } from "react";
import { CaretRight as CaretRightIcon, MapPin as MapPinIcon, House as HouseIcon, } from "@phosphor-icons/react";
import { useStateManagerContext } from "~/context/stateManager";
import { useLocalContent } from "~/sdks/LocalContentDeprecated/context";
import { TrackingPipelineEvents, } from "~/sdks/LocalContentDeprecated/types";
import POIs from "./POIs";
import Schools from "./Schools";
import * as styles from "./styles";
const Score = React.memo(({ score, scoresData }) => {
    var _a, _b;
    const { sdkState } = useStateManagerContext();
    const { activeScore, hideScores } = useLocalContent();
    const tracking = useTracking();
    const isActive = score === activeScore;
    const [isCtaClicked, setIsCtaClicked] = useState(false);
    const ctaClicked = () => {
        setIsCtaClicked(true);
    };
    useEffect(() => {
        if (isCtaClicked) {
            tracking.postEvent({
                eventType: TrackingPipelineEvents.LONG_DESCRIPTION_CLICKED,
                eventAttributes: [
                    {
                        label: "activeScore",
                        data: activeScore.toString(),
                    },
                ],
            });
        }
        return () => {
            setIsCtaClicked(false);
        };
    }, [isCtaClicked]);
    if (!(scoresData === null || scoresData === void 0 ? void 0 : scoresData.location[score])) {
        return null;
    }
    return (React.createElement(Accordion.Item, { value: score, key: score },
        React.createElement(ScoreE.Root, { options: {
                score,
                scoresData,
            } },
            React.createElement(Accordion.Header, { className: styles.header },
                React.createElement(Accordion.Trigger, { className: styles.trigger },
                    React.createElement("div", { className: styles.chevronContainer },
                        React.createElement(CaretRightIcon, { weight: "bold", width: 16, height: 16 })),
                    React.createElement("div", { className: styles.spacerHorizontal }),
                    React.createElement(ScoreE.Icon, null),
                    React.createElement("div", { className: styles.spacerHorizontal }),
                    React.createElement(ScoreE.Title, null),
                    React.createElement("div", { className: styles.spacerHorizontalAuto }),
                    !hideScores && React.createElement(ScoreE.Badge, { options: { isPrimary: isActive } }))),
            React.createElement(Accordion.Content, { className: styles.contentContainer },
                React.createElement("div", { className: styles.content },
                    !hideScores && (React.createElement("div", { className: styles.scoreContent },
                        React.createElement(ScoreE.Description, { ctaClicked: ctaClicked }),
                        React.createElement("div", { className: styles.spacerVertical }),
                        React.createElement(ScoreE.BarChart, { options: {
                                locationIcon: ((_b = (_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.marker) === null || _b === void 0 ? void 0 : _b.icon) === "pin"
                                    ? MapPinIcon
                                    : HouseIcon,
                            } }))),
                    React.createElement("div", { className: styles.poiContainer }, score === "high_schools" || score === "primary_schools" ? (React.createElement(Schools, { score: score })) : (React.createElement(POIs, { include: scorePois[score] }))))))));
});
Score.displayName = "Score";
export default Score;
//# sourceMappingURL=index.js.map