import React, { useEffect, useState } from "react";
import { useTracking } from "@local-logic/core/tracking";
import * as Accordion from "@radix-ui/react-accordion";
import { useLocalContent } from "~/sdks/LocalContentDeprecated/context";
import { TrackingPipelineEvents, AnalyticsEvents, } from "~/sdks/LocalContentDeprecated/types";
import ScoreCategory from "./ScoreCategory";
const ScoreCategoryAccordion = React.memo(({ tabContent }) => {
    const { activeScore, setActiveScore } = useLocalContent();
    const tracking = useTracking();
    const [isScoreClicked, setIsScoreClicked] = useState(false);
    useEffect(() => {
        if (isScoreClicked) {
            tracking.postEvent({
                eventType: TrackingPipelineEvents.SCORE_CLICKED,
                eventAttributes: [
                    {
                        label: "activeScore",
                        data: activeScore.toString(),
                    },
                ],
            });
        }
        return () => {
            setIsScoreClicked(false);
        };
    }, [isScoreClicked]);
    const handleOnScoreExpanded = (value) => {
        setActiveScore(value);
        setIsScoreClicked(true);
        if (value) {
            tracking.trackAnalyticsEvent({
                eventName: AnalyticsEvents.SCORE_EXPANDED,
                eventAttributes: {
                    ll_selected_score: value,
                },
            });
        }
    };
    return (React.createElement(Accordion.Root, { value: activeScore, onValueChange: handleOnScoreExpanded, type: "single", collapsible: true },
        React.createElement(ScoreCategory, { tabContent: tabContent })));
});
ScoreCategoryAccordion.displayName = "ScoreCategoryAccordion";
export default ScoreCategoryAccordion;
//# sourceMappingURL=index.js.map