import React, { useEffect, useState } from "react";
import { useTracking } from "@local-logic/core/tracking";
import { useFlags } from "launchdarkly-react-client-sdk";
import { Attribution } from "~/components/Attribution";
import { useLocalContent } from "~/sdks/LocalContentDeprecated/context";
import useRankedCategories from "~/sdks/LocalContentDeprecated/features/useRankedCategories";
import { TrackingPipelineEvents, AnalyticsEvents, } from "~/sdks/LocalContentDeprecated/types";
import * as ScoreCategoryTabs from "~/sdks/LocalContentDeprecated/components/ScoreCategoryTabs";
import * as styles from "./styles";
import ScoreCategoryAccordion from "./ScoreCategoryAccordion";
const DesktopScores = React.forwardRef((_, forwardedRef) => {
    const { activeCategory, setActiveCategory } = useLocalContent();
    const flags = useFlags();
    const tracking = useTracking();
    const { data } = useRankedCategories();
    const [rankedCategories, setRankedCategories] = useState(data);
    useEffect(() => {
        // The reason we're setting our own state is to trigger a re-render
        // If we're just using the "data" directly, setting the new active
        // category is completed but no re-render is done, showing the old
        // active category instead
        setRankedCategories(data);
        if (data.length > 0) {
            setActiveCategory(data[0].value);
        }
    }, [data]);
    const handleCategoryClicked = (category) => {
        setActiveCategory(category);
        tracking.postEvent({
            eventType: TrackingPipelineEvents.CATEGORY_CLICKED,
            eventAttributes: [
                {
                    label: "activeCategory",
                    data: category,
                },
            ],
        });
        tracking.trackAnalyticsEvent({
            eventName: AnalyticsEvents.CATEGORY_SELECTED,
            eventAttributes: {
                ll_selected_category: category,
            },
        });
    };
    const handleAttributionClicked = () => {
        tracking.postEvent({
            eventType: TrackingPipelineEvents.ATTRIBUTION_CLICKED,
        });
    };
    return (React.createElement(ScoreCategoryTabs.Root, { options: { currentTab: activeCategory }, onChange: (e) => handleCategoryClicked(e.data) },
        React.createElement("div", { className: styles.scoresContainer(flags.lcWellnessTab), ref: forwardedRef },
            React.createElement("div", { className: styles.tabsContainer },
                React.createElement(ScoreCategoryTabs.Tabs, { category: rankedCategories })),
            React.createElement("div", { className: styles.scrollContainer }, rankedCategories.map((tabContent) => (React.createElement(ScoreCategoryTabs.Content, { key: tabContent.value, options: { value: tabContent.value } },
                React.createElement(ScoreCategoryAccordion, { tabContent: tabContent, key: tabContent.value }))))),
            React.createElement("div", { className: styles.attribution },
                React.createElement(Attribution, { onClick: handleAttributionClicked })))));
});
DesktopScores.displayName = "DesktopScores";
export default DesktopScores;
//# sourceMappingURL=index.js.map