import * as styles from "~/sdks/LocalContentDeprecated/components/MapGL/styles";
import { PinMarker } from "@local-logic/core/ui";
import React, { useContext, useEffect, useRef } from "react";
import ReactDOMServer from "react-dom/server";
import { useStateManagerContext } from "~/context/stateManager";
import { base64SVGString } from "~/utils/formatters/base64SVGString";
import useIsMobile from "~/hooks/useIsMobile";
import errorTracker from "~/utils/errorTracker";
import { GoogleMapContext } from "../context";
const createHomeMarker = (map, center) => {
    const homeIconStr = ReactDOMServer.renderToString(React.createElement(PinMarker.GoogleRoot, { options: {
            style: "house",
        } }));
    const homeIconUrl = base64SVGString(homeIconStr);
    const homeMarker = new window.google.maps.Marker({
        map,
        position: {
            lat: center.lat,
            lng: center.lng,
        },
        icon: {
            url: homeIconUrl,
            scaledSize: new google.maps.Size(50, 50),
        },
        zIndex: Number(google.maps.Marker.MAX_ZINDEX),
    });
};
const GoogleBaseMap = ({ boundCoords, padding, }) => {
    var _a;
    const ref = useRef(null);
    const { sdkState } = useStateManagerContext();
    const { googleMapRef, setGoogleMapRef } = useContext(GoogleMapContext);
    const isMobile = useIsMobile();
    useEffect(() => {
        if (!googleMapRef) {
            return;
        }
        googleMapRef.setOptions({
            zoomControlOptions: {
                position: isMobile
                    ? google.maps.ControlPosition.LEFT_BOTTOM
                    : google.maps.ControlPosition.RIGHT_BOTTOM,
            },
        });
    }, [isMobile, googleMapRef]);
    useEffect(() => {
        var _a;
        if (ref.current &&
            !googleMapRef &&
            sdkState.options &&
            sdkState.options.lat &&
            sdkState.options.lng) {
            const center = {
                lat: sdkState.options.lat,
                lng: sdkState.options.lng,
            };
            errorTracker.addBreadCrumb("GoogleBaseMap", "useEffect: Loading google map");
            const newMap = new google.maps.Map(ref.current, {
                center,
                zoom: sdkState.options.zoom,
                maxZoom: 20,
                minZoom: 3,
                restriction: {
                    latLngBounds: {
                        north: 85,
                        south: -85,
                        east: 180,
                        west: -180,
                    },
                    strictBounds: true,
                },
                mapTypeControl: false,
                zoomControl: true,
                streetViewControl: false,
                fullscreenControl: false,
                styles: [
                    {
                        featureType: "poi",
                        stylers: [{ visibility: "off" }],
                    },
                    {
                        featureType: "transit.station",
                        stylers: [{ visibility: "off" }],
                    },
                    {
                        featureType: "administrative",
                        stylers: [{ visibility: "off" }],
                    },
                    {
                        featureType: "road",
                        stylers: [{ visibility: "simplified" }],
                    },
                    {
                        featureType: "road",
                        elementType: "labels",
                        stylers: [
                            {
                                lightness: 20,
                            },
                        ],
                    },
                    {
                        featureType: "transit.station.airport",
                        stylers: [{ visibility: "on" }],
                    },
                    {
                        featureType: "poi.park",
                        stylers: [{ visibility: "on" }],
                    },
                    {
                        featureType: "poi.park",
                        elementType: "labels",
                        stylers: [{ visibility: "off" }],
                    },
                ],
                clickableIcons: false,
                gestureHandling: sdkState.options.cooperativeGestures === false
                    ? "greedy"
                    : "cooperative",
            });
            setGoogleMapRef(newMap);
            errorTracker.addBreadCrumb("GoogleBaseMap", "useEffect: Google map loaded and ref set");
            if (typeof ((_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.marker) !== "undefined") {
                createHomeMarker(newMap, center);
            }
        }
    }, [ref, googleMapRef, (_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.marker]);
    useEffect(() => {
        if (googleMapRef && boundCoords) {
            googleMapRef.fitBounds(boundCoords, padding);
        }
    }, [boundCoords, padding, googleMapRef]);
    return React.createElement("div", { className: styles.mapContainer, ref: ref, id: "map" });
};
export default GoogleBaseMap;
//# sourceMappingURL=index.js.map