import { MarkerClusterer } from "@googlemaps/markerclusterer";
import * as POIMarker from "~/sdks/LocalContentDeprecated/components/POIMarker";
import React from "react";
import ReactDOMServer from "react-dom/server";
import { base64SVGString } from "~/utils/formatters/base64SVGString";
import { customInfoKey, } from "./types";
export const createMarkerCluster = (markerList, map, setActivePOI, setActiveCluster, setActiveMarker) => {
    let newMarker;
    const renderer = {
        render({ count, position, }) {
            const iconSize = Math.min(100, 30 + 5 * count);
            const clusterIconStr = ReactDOMServer.renderToString(React.createElement(POIMarker.GoogleClusterMarker, { markerSize: iconSize }));
            const shape = {
                coords: [iconSize / 2, iconSize / 2, iconSize / 2.5],
                type: "circle",
            };
            newMarker = new google.maps.Marker({
                label: { text: String(count), color: "white", fontSize: "0.75rem" },
                title: "cluster",
                position,
                icon: {
                    url: base64SVGString(clusterIconStr),
                    scaledSize: new google.maps.Size(iconSize, iconSize),
                    anchor: new window.google.maps.Point(12, 12),
                },
                shape,
                // adjust zIndex to be above other markers
                zIndex: Number(google.maps.Marker.MAX_ZINDEX) + count,
            });
            // A barebones recreation of customLlInfo to be used in infoWindow
            // the name value is not displayed
            const poi = {
                poi: {
                    name: "cluster",
                    lat: position.lat(),
                    lng: position.lng(),
                },
            };
            newMarker.set(customInfoKey, { properties: poi });
            return newMarker;
        },
    };
    const markerCluster = new MarkerClusterer({
        map,
        markers: markerList,
        renderer,
        algorithmOptions: { maxZoom: 20 },
        onClusterClick: (_, cluster) => {
            if (cluster.marker) {
                const { poi } = cluster.marker.customLLInfo
                    .properties;
                setActivePOI(poi);
                setActiveCluster(cluster);
                setActiveMarker(undefined);
            }
        },
    });
    return markerCluster;
};
//# sourceMappingURL=cluster.js.map