import React, { useContext, useEffect, useMemo, useState } from "react";
import { useTranslation } from "react-i18next";
import { useTracking } from "@local-logic/core/tracking";
import { useStateManagerContext } from "~/context/stateManager";
import { useLocalContent } from "~/sdks/LocalContentDeprecated/context";
import { formatDestination, formatOrigin, useGoogleComputeRoute, } from "~/sdks/LocalContentDeprecated/features/useGoogleComputeRoute";
import { TrackingPipelineEvents, AnalyticsEvents, } from "~/sdks/LocalContentDeprecated/types";
import { updateMarkers } from "./marker";
import { createClusterInfoWindow, createInfoWindow } from "./infoWindow";
import { createMarkerCluster } from "./cluster";
import { GoogleMapContext } from "../context";
const GoogleMarkers = ({ points }) => {
    const { t } = useTranslation(["common"]);
    const [markers, setMarkers] = useState([]);
    const [activeMarker, setActiveMarker] = useState();
    const [infoWindow, setInfoWindow] = useState();
    const [markerCluster, setMarkerCluster] = useState();
    const [activeCluster, setActiveCluster] = useState();
    const { googleMapRef } = useContext(GoogleMapContext);
    const { activePOI, setActivePOI, setShowCommuteCalculator, setDestination } = useLocalContent();
    const { sdkState } = useStateManagerContext();
    const tracking = useTracking();
    useEffect(() => {
        if (googleMapRef) {
            markers.map((m) => google.maps.event.clearListeners(m, "click"));
            markers.map((m) => m === null || m === void 0 ? void 0 : m.setMap(null));
            setMarkers(updateMarkers(points, googleMapRef, setActiveMarker, setActivePOI, setActiveCluster));
        }
    }, [points, googleMapRef]);
    const getCommuteData = (travelMode) => {
        var _a, _b, _c;
        if (!((_b = (_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.mapProvider) === null || _b === void 0 ? void 0 : _b.key))
            return { data: undefined };
        return useGoogleComputeRoute({
            travelMode,
            origin: formatOrigin(sdkState),
            destination: formatDestination({
                lat: activeMarker === null || activeMarker === void 0 ? void 0 : activeMarker.customLLInfo.properties.poi.lat,
                lng: activeMarker === null || activeMarker === void 0 ? void 0 : activeMarker.customLLInfo.properties.poi.lng,
            }),
            units: "METRIC",
            polylineEncoding: "ENCODED_POLYLINE",
            googleApiKey: sdkState.options.mapProvider.key,
            locale: ((_c = sdkState.globalOptions) === null || _c === void 0 ? void 0 : _c.locale) || "en",
        });
    };
    const { data: walkingData } = getCommuteData("WALK");
    const { data: drivingData } = getCommuteData("DRIVE");
    const walkingTime = useMemo(() => {
        var _a, _b, _c, _d;
        if ((_a = walkingData === null || walkingData === void 0 ? void 0 : walkingData.routes) === null || _a === void 0 ? void 0 : _a.length) {
            return (_d = (_c = (_b = walkingData.routes[0].localizedValues) === null || _b === void 0 ? void 0 : _b.duration) === null || _c === void 0 ? void 0 : _c.text) !== null && _d !== void 0 ? _d : "";
        }
        return "";
    }, [walkingData]);
    const drivingTime = useMemo(() => {
        var _a, _b, _c, _d;
        if ((_a = drivingData === null || drivingData === void 0 ? void 0 : drivingData.routes) === null || _a === void 0 ? void 0 : _a.length) {
            return (_d = (_c = (_b = drivingData.routes[0].localizedValues) === null || _b === void 0 ? void 0 : _b.duration) === null || _c === void 0 ? void 0 : _c.text) !== null && _d !== void 0 ? _d : "";
        }
        return "";
    }, [drivingData]);
    const displayCommuteCalcResults = (infowindow) => {
        setShowCommuteCalculator(true);
        infowindow.close();
        tracking.postEvent({
            eventType: TrackingPipelineEvents.COMMUTE_CALCULATE_ROUTE,
        });
        tracking.trackAnalyticsEvent({
            eventName: AnalyticsEvents.POI_CALCULATE_ROUTE,
        });
    };
    const showDriveTime = () => !!(walkingTime && walkingTime.includes(t("common:time.hour_one")));
    const handleInfoWindowClose = () => {
        setInfoWindow(undefined);
        setActiveMarker(undefined);
        setActivePOI(undefined);
        setActiveCluster(undefined);
    };
    useEffect(() => {
        var _a;
        infoWindow === null || infoWindow === void 0 ? void 0 : infoWindow.close();
        if (!googleMapRef)
            return;
        // If clicking on a cluster
        if (activeCluster) {
            const currentZoom = googleMapRef.getZoom();
            if (typeof currentZoom === "number" && currentZoom < 20) {
                googleMapRef.setCenter(activeCluster.position);
                googleMapRef.setZoom(currentZoom + 2);
            }
            else {
                setInfoWindow(createClusterInfoWindow(googleMapRef, activeCluster, handleInfoWindowClose, setActivePOI, setActiveMarker, setActiveCluster));
            }
            return;
        }
        if (activeMarker) {
            // Not clicking another marker, so no need to create and display infoWindow
            if ((activePOI === null || activePOI === void 0 ? void 0 : activePOI.name) !== activeMarker.getTitle())
                return;
            setInfoWindow(createInfoWindow(activeMarker, googleMapRef, walkingTime, drivingTime, showDriveTime, handleInfoWindowClose, setDestination, displayCommuteCalcResults, 
            // showCalculateCommute
            typeof ((_a = sdkState === null || sdkState === void 0 ? void 0 : sdkState.options) === null || _a === void 0 ? void 0 : _a.marker) !== "undefined"));
        }
    }, [activePOI, walkingTime]);
    const handleTrackPOISelected = () => {
        tracking.trackAnalyticsEvent({
            eventName: AnalyticsEvents.MAP_POI_SELECTED,
        });
    };
    const handleSelectPOI = (poi) => {
        setActivePOI(poi);
        handleTrackPOISelected();
    };
    const handleSelectMarker = (marker) => {
        setActiveMarker(marker);
        handleTrackPOISelected();
    };
    useEffect(() => {
        markerCluster === null || markerCluster === void 0 ? void 0 : markerCluster.clearMarkers();
        if (googleMapRef) {
            setMarkerCluster(createMarkerCluster(markers, googleMapRef, handleSelectPOI, setActiveCluster, handleSelectMarker));
        }
    }, [markers, googleMapRef]);
    return React.createElement(React.Fragment, null);
};
export default GoogleMarkers;
//# sourceMappingURL=index.js.map