import * as POIMarker from "~/sdks/LocalContentDeprecated/components/POIMarker";
import React from "react";
import { createRoot } from "react-dom/client";
import * as styles from "./styles";
import "./styles.css";
const createBaseInfoWindow = (contentComponent, ariaLabel) => new google.maps.InfoWindow({
    content: contentComponent,
    ariaLabel,
    maxWidth: 280,
    minWidth: 240,
    zIndex: google.maps.Marker.MAX_ZINDEX,
});
export const createInfoWindow = (marker, map, walkingTime, drivingTime, showDriveTime, handleInfoWindowClose, setDestination, displayCommuteCalcResults, showCalculateCommute = true) => {
    const markerTitle = marker.getTitle();
    const rootNode = document.createElement("div");
    document.body.appendChild(rootNode);
    createRoot(rootNode).render(React.createElement(POIMarker.GoogleRoot, { options: {
            poi: marker.customLLInfo.properties.poi,
            type: marker.customLLInfo.properties.type,
            walkingTime,
            drivingTime,
            showDriveTime: showDriveTime(),
            calculateRoute: () => true,
        } },
        React.createElement(POIMarker.GoogleContent, { showCalculateCommute: showCalculateCommute })));
    const infowindow = createBaseInfoWindow(rootNode, markerTitle);
    google.maps.event.addListener(infowindow, "domready", () => {
        var _a;
        const selector = document.querySelectorAll('[google-selector="infoWindow-calc-btn"]');
        // There should be [0,1] infoWindow button at any given time
        if (selector.length > 1)
            return;
        (_a = selector[0]) === null || _a === void 0 ? void 0 : _a.addEventListener("click", () => {
            setDestination({
                label: marker.customLLInfo.properties.poi.name,
                lat: marker.customLLInfo.properties.poi.lat,
                lng: marker.customLLInfo.properties.poi.lng,
            });
            displayCommuteCalcResults(infowindow);
        });
        google.maps.event.addListenerOnce(map, "click", () => {
            infowindow.close();
            handleInfoWindowClose();
        });
    });
    google.maps.event.addListenerOnce(infowindow, "closeclick", () => handleInfoWindowClose());
    infowindow.open({ anchor: marker, map });
    return infowindow;
};
export const createClusterInfoWindow = (map, cluster, handleInfoWindowClose, setActivePOI, setActiveMarker, setActiveCluster) => {
    var _a;
    const rootNode = document.createElement("div");
    document.body.appendChild(rootNode);
    createRoot(rootNode).render(React.createElement("ul", { className: styles.clusterList, id: "cluster-infoWindow-list-parent" }, (_a = cluster.markers) === null || _a === void 0 ? void 0 : _a.map((m, i) => (React.createElement("li", { className: styles.clusterListItem, key: `cluster-infoWindow-list-item-${i}`, id: m.customLLInfo.properties.poi.name }, m.customLLInfo.properties.poi.name)))));
    const infowindow = createBaseInfoWindow(rootNode, "cluster");
    google.maps.event.addListener(infowindow, "domready", () => {
        const parentSelector = document.querySelector('[google-selector="cluster-infoWindow-list-parent"]');
        // There should be exactly 1 active cluster selected, so 1 parentSelector
        if (!parentSelector)
            return;
        const parentSelectorListener = (event) => {
            var _a;
            const googleSelectorNameKey = "google-selector-name";
            const target = event.target;
            const googleSelectorName = target.attributes.getNamedItem(googleSelectorNameKey);
            if (googleSelectorName) {
                const selectedMarkerArr = (_a = cluster.markers) === null || _a === void 0 ? void 0 : _a.filter((m) => m.getTitle() ===
                    googleSelectorName.textContent);
                if (selectedMarkerArr && (selectedMarkerArr === null || selectedMarkerArr === void 0 ? void 0 : selectedMarkerArr.length) > 0) {
                    infowindow.close();
                    const marker = selectedMarkerArr[0];
                    setActivePOI(marker.customLLInfo.properties.poi);
                    setActiveMarker(marker);
                    setActiveCluster(undefined);
                }
            }
        };
        parentSelector.addEventListener("click", parentSelectorListener);
        google.maps.event.addListenerOnce(map, "click", () => {
            parentSelector.removeEventListener("click", parentSelectorListener);
            infowindow.close();
            handleInfoWindowClose();
        });
        google.maps.event.addListenerOnce(infowindow, "closeclick", () => {
            parentSelector.removeEventListener("click", parentSelectorListener);
            handleInfoWindowClose();
        });
    });
    infowindow.open({ anchor: cluster.marker, map });
    return infowindow;
};
//# sourceMappingURL=infoWindow.js.map