import { baseStyles, PinMarker } from "@local-logic/core/ui";
import React, { useContext, useEffect, useState } from "react";
import ReactDOMServer from "react-dom/server";
import { useLocalContent } from "~/sdks/LocalContentDeprecated/context";
import { base64SVGString } from "~/utils/formatters/base64SVGString";
import errorTracker from "~/utils/errorTracker";
import { GoogleMapContext } from "../context";
const GoogleRoute = () => {
    const { googleMapRef } = useContext(GoogleMapContext);
    const { destination, commuteGeojson } = useLocalContent();
    const [polyline, setPolyline] = useState();
    const [destinationMarker, setDestinationMarker] = useState();
    const addRoute = () => {
        errorTracker.addBreadCrumb("GoogleRoute", "addRoute");
        const newPolyline = new google.maps.Polyline({
            path: commuteGeojson,
            geodesic: true,
            strokeColor: baseStyles.colors.blueColors.colorBlue70,
            strokeOpacity: 1.0,
            strokeWeight: 6,
        });
        setPolyline(newPolyline);
        if (googleMapRef) {
            newPolyline.setMap(googleMapRef);
        }
        if (destination) {
            const placeIconStr = ReactDOMServer.renderToString(React.createElement(PinMarker.GoogleRoot, { options: {
                    style: "pin",
                } }));
            const placeIconUrl = base64SVGString(placeIconStr);
            const destMarkerIconProps = {
                url: placeIconUrl,
                scaledSize: new google.maps.Size(50, 50),
            };
            const destMarker = new google.maps.Marker({
                map: googleMapRef,
                position: {
                    lat: destination.lat,
                    lng: destination.lng,
                },
                icon: destMarkerIconProps,
                zIndex: Number(google.maps.Marker.MAX_ZINDEX),
            });
            if (googleMapRef) {
                destMarker.setMap(googleMapRef);
            }
            setDestinationMarker(destMarker);
        }
    };
    const removeRoute = () => {
        errorTracker.addBreadCrumb("GoogleRoute", "removeRoute");
        polyline === null || polyline === void 0 ? void 0 : polyline.setMap(null);
        setPolyline(undefined);
        destinationMarker === null || destinationMarker === void 0 ? void 0 : destinationMarker.setMap(null);
        setDestinationMarker(undefined);
    };
    useEffect(() => {
        removeRoute();
        if (commuteGeojson) {
            addRoute();
        }
    }, [commuteGeojson]);
    return React.createElement(React.Fragment, null);
};
export default GoogleRoute;
//# sourceMappingURL=index.js.map