import { scorePois } from "~/sdks/LocalContentDeprecated/constants/score-categories";
import { multiPoint, point, bbox } from "@turf/turf";
import React, { useEffect, useMemo, useState } from "react";
import CommuteContainer from "~/sdks/LocalContentDeprecated/components/CommuteContainer";
import DesktopScores from "~/sdks/LocalContentDeprecated/components/DesktopScores";
import { useStateManagerContext } from "~/context/stateManager";
import useIsMobile from "~/hooks/useIsMobile";
import useMeasure from "~/hooks/useMeasure";
import { useLocalContent } from "~/sdks/LocalContentDeprecated/context";
import { usePois } from "~/sdks/LocalContentDeprecated/hooks/usePois";
import { useSchools } from "~/sdks/LocalContentDeprecated/hooks/useSchools";
import MobileScores from "~/sdks/LocalContentDeprecated/components/MobileScores";
import errorTracker from "~/utils/errorTracker";
import { GoogleMapProvider } from "./context";
import GoogleRoute from "./GoogleRoute";
import GoogleMarkers from "./GoogleMarkers";
import GoogleBaseMap from "./GoogleBaseMap";
const GoogleMap = () => {
    var _a;
    const { sdkState } = useStateManagerContext();
    const { activeScore, destination, initialLocation } = useLocalContent();
    const isMobile = useIsMobile();
    const poisResult = usePois(activeScore);
    const schoolsResult = useSchools({ activeScore });
    const [bounds, setBounds] = useState();
    const [ref, rect] = useMeasure();
    const mobileMapPadding = useMemo(() => {
        const padding = 75;
        errorTracker.addBreadCrumb("GoogleMap", "mobileMapPadding changed");
        return {
            top: padding + rect.height,
            bottom: padding,
            left: padding,
            right: padding,
        };
    }, [rect.height]);
    const desktopMapPadding = useMemo(() => {
        const padding = 80;
        errorTracker.addBreadCrumb("GoogleMap", "desktopMapPadding changed");
        return {
            top: padding,
            bottom: padding,
            left: rect.width + 32 + padding,
            right: padding,
        };
    }, [rect.width]);
    const [mapPadding, setMapPadding] = useState(isMobile ? mobileMapPadding : desktopMapPadding);
    useEffect(() => {
        setMapPadding(isMobile ? mobileMapPadding : desktopMapPadding);
    }, [isMobile, rect]);
    const activePOIs = useMemo(() => {
        var _a, _b;
        if ((activeScore === "high_schools" || activeScore === "primary_schools") &&
            !schoolsResult.isFetching) {
            return { [activeScore]: ((_a = schoolsResult === null || schoolsResult === void 0 ? void 0 : schoolsResult.data) === null || _a === void 0 ? void 0 : _a[activeScore]) || [] };
        }
        if (!(scorePois &&
            activeScore &&
            scorePois[activeScore] &&
            ((_b = scorePois[activeScore]) === null || _b === void 0 ? void 0 : _b.length)) &&
            !poisResult.isFetching) {
            return { [activeScore]: [] };
        }
        if (!poisResult.data || poisResult.isFetching || poisResult.isLoading) {
            return [];
        }
        return poisResult.data ? poisResult.data : [];
    }, [poisResult.data, schoolsResult.data, activeScore]);
    /**
     * POIs to render on the map
     */
    const points = useMemo(() => {
        if (!activePOIs) {
            return [];
        }
        const arr = Object.entries(activePOIs)
            .map(([key, pois]) => pois.map((poi) => point([poi.lng, poi.lat], { poi, type: key })))
            .flat();
        return arr.filter((v, i, a) => a.findIndex((v2) => ["lat", "lng", "name"].every(
        // eslint-disable-next-line @typescript-eslint/ban-ts-comment
        // @ts-ignore
        (k) => v2.properties.poi[k] === v.properties.poi[k])) === i);
    }, [activePOIs]);
    /**
     * The POIs to render on the map (including the Pin)
     */
    const pointsWithPin = useMemo(() => {
        var _a, _b, _c;
        const markerPoint = ((_a = sdkState === null || sdkState === void 0 ? void 0 : sdkState.options) === null || _a === void 0 ? void 0 : _a.marker) &&
            point([(_b = sdkState === null || sdkState === void 0 ? void 0 : sdkState.options) === null || _b === void 0 ? void 0 : _b.marker.lng, (_c = sdkState === null || sdkState === void 0 ? void 0 : sdkState.options) === null || _c === void 0 ? void 0 : _c.marker.lat]);
        return [
            ...points,
            ...(markerPoint ? [markerPoint] : []),
            ...(destination ? [point([destination === null || destination === void 0 ? void 0 : destination.lng, destination === null || destination === void 0 ? void 0 : destination.lat])] : []),
        ];
    }, [points, (_a = sdkState === null || sdkState === void 0 ? void 0 : sdkState.options) === null || _a === void 0 ? void 0 : _a.marker, destination]);
    /**
     * Reposition map when points change
     */
    useEffect(() => {
        var _a;
        if (!activeScore || poisResult.isFetching || schoolsResult.isFetching) {
            return;
        }
        let multiPt;
        if (pointsWithPin.length > 0) {
            multiPt = multiPoint(pointsWithPin.map(({ geometry }) => [
                geometry.coordinates[1],
                geometry.coordinates[0],
            ]));
        }
        else if (typeof ((_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.marker) === "undefined" &&
            typeof initialLocation.lat !== "undefined" &&
            typeof initialLocation.lng !== "undefined") {
            multiPt = multiPoint([[initialLocation.lat, initialLocation.lng]]);
        }
        else {
            return;
        }
        errorTracker.addBreadCrumb("GoogleMap", "useEffect: Repositioning map because points changed");
        const [minLat, minLng, maxLat, maxLng] = bbox(multiPt);
        setBounds({ north: minLat, south: maxLat, east: maxLng, west: minLng });
    }, [
        pointsWithPin,
        mapPadding,
        activeScore,
        schoolsResult.isFetching,
        poisResult.isFetching,
        initialLocation,
    ]);
    return (React.createElement(GoogleMapProvider, null,
        React.createElement(GoogleBaseMap, { boundCoords: bounds, padding: mapPadding }),
        React.createElement(GoogleMarkers, { points: points }),
        isMobile ? React.createElement(MobileScores, { ref: ref }) : React.createElement(DesktopScores, { ref: ref }),
        React.createElement(CommuteContainer, null),
        React.createElement(GoogleRoute, null)));
};
export default GoogleMap;
//# sourceMappingURL=index.js.map