import { baseStyles, Popover } from "@local-logic/core/ui";
import React, { useMemo, useState } from "react";
import { motion } from "framer-motion";
import { useLocalContent } from "~/sdks/LocalContentDeprecated/context";
import { AnalyticsEvents } from "~/sdks/LocalContentDeprecated/types";
import { useTracking } from "@local-logic/core/tracking";
import * as styles from "./styles";
import Marker from "../Marker";
const hoverVariants = {
    default: {
        scale: 1.0,
    },
    hovered: {
        scale: 1.2,
    },
};
const clusterListThreshold = 17;
const Cluster = ({ cluster, supercluster, pointsCount, onClick, zoom, activePOI, hoveredPOI, rect, isMobile, isMapMoving, }) => {
    const [showClusterDialog, setShowClusterDialog] = useState(false);
    const { setActivePOI, setCommuteGeojson, setShowCommuteCalculator } = useLocalContent();
    const tracking = useTracking();
    const clusterPointCount = cluster.properties.point_count;
    const diameter = 20 + (clusterPointCount / pointsCount) * 25;
    if (showClusterDialog && isMapMoving) {
        setShowClusterDialog(false);
    }
    const onClickHandler = () => {
        setCommuteGeojson(undefined);
        setShowCommuteCalculator(false);
        if (zoom > clusterListThreshold) {
            setShowClusterDialog(true);
            return;
        }
        if (onClick) {
            onClick(cluster);
        }
    };
    const onOpenChangeHandler = (e) => {
        if (zoom <= clusterListThreshold) {
            return;
        }
        setShowClusterDialog(e);
    };
    const clusterChildren = useMemo(() => {
        if (!supercluster || !cluster.id) {
            return [];
        }
        let children;
        try {
            children = supercluster.getChildren(cluster.id);
        }
        catch (error) {
            // Catch error for "No cluster with the specified id."
            return [];
        }
        if (!children) {
            return [];
        }
        return children.map((c) => c.properties).filter((c) => !!c);
    }, [supercluster, cluster]);
    const clusterChild = clusterChildren === null || clusterChildren === void 0 ? void 0 : clusterChildren.find((c) => !!activePOI && c.poi === activePOI);
    const handleTrackPoiClick = () => {
        tracking.trackAnalyticsEvent({
            eventName: AnalyticsEvents.MAP_POI_SELECTED,
        });
    };
    if (clusterChild) {
        return (React.createElement(Marker, { rect: rect, poi: clusterChild.poi, poiType: clusterChild.type, isMobile: isMobile, activePOI: activePOI, hoveredPOI: hoveredPOI, isMapMoving: isMapMoving }));
    }
    return (React.createElement(Popover.Root, { open: isMapMoving ? false : showClusterDialog, onOpenChange: onOpenChangeHandler },
        React.createElement(Popover.Trigger, null,
            React.createElement(motion.div, { className: styles.cluster, onClick: onClickHandler, variants: hoverVariants, animate: showClusterDialog ? "hovered" : "default", whileHover: {
                    scale: 1.2,
                }, transition: baseStyles.transitions.default, style: {
                    height: `${diameter}px`,
                    width: `${diameter}px`,
                    fontSize: `${diameter / 2.5}px`,
                } }, cluster.properties.point_count)),
        React.createElement(Popover.Content, { side: "top" },
            React.createElement("ul", { className: styles.clusterList }, clusterChildren === null || clusterChildren === void 0 ? void 0 : clusterChildren.map((c, i) => {
                var _a;
                return (React.createElement("li", { className: styles.clusterListItem, key: i, onClick: () => {
                        setActivePOI(c.poi);
                        handleTrackPoiClick();
                    } }, (_a = c.poi) === null || _a === void 0 ? void 0 : _a.name));
            })))));
};
export default Cluster;
//# sourceMappingURL=index.js.map