import { useTranslation } from "react-i18next";
import { useTracking } from "@local-logic/core/tracking";
import { mapUtils, typeguardUtils } from "@local-logic/core/utils";
import React, { useEffect, useMemo, useState } from "react";
import { Marker as M } from "react-map-gl/maplibre";
import { useStateManagerContext } from "~/context/stateManager";
import { useCalculateRouteProxy } from "~/features/calculateRoute/useCommute";
import { TrackingPipelineEvents, AnalyticsEvents, } from "~/sdks/LocalContentDeprecated/types";
import * as POIMarker from "~/sdks/LocalContentDeprecated/components/POIMarker";
import { useLocalContent } from "~/sdks/LocalContentDeprecated/context";
import SchoolCatchment from "./SchoolCatchment";
const Marker = ({ poi, poiType, activePOI, hoveredPOI, isMapMoving, isMobile, }) => {
    const { t } = useTranslation(["common"]);
    const [isOpen, setIsOpen] = useState(false);
    const [schoolCatchment, setSchoolCatchment] = useState();
    const isHovered = hoveredPOI === poi;
    const mediumSizedPois = [
        "rapid_transit_stations",
    ];
    const { sdkState } = useStateManagerContext();
    const { setCommuteGeojson, setDestination, setShowCommuteCalculator, setIsInputAutoFocused, setActivePOI, } = useLocalContent();
    const tracking = useTracking();
    const getCommuteData = (commuteMode) => {
        var _a, _b, _c, _d;
        return useCalculateRouteProxy({
            destination: `${poi.lng},${poi.lat}`,
            transportMode: commuteMode,
            origin: `${(_b = (_a = sdkState === null || sdkState === void 0 ? void 0 : sdkState.options) === null || _a === void 0 ? void 0 : _a.marker) === null || _b === void 0 ? void 0 : _b.lng},${(_d = (_c = sdkState === null || sdkState === void 0 ? void 0 : sdkState.options) === null || _c === void 0 ? void 0 : _c.marker) === null || _d === void 0 ? void 0 : _d.lat}`,
            isOpen,
        });
    };
    const { data: walkingData } = getCommuteData("pedestrian");
    const { data: drivingData } = getCommuteData("car");
    const [isPoiCalCommute, setIsPoiCalcCommute] = useState(false);
    useEffect(() => {
        setIsOpen(activePOI === poi);
        if (activePOI === poi) {
            const activePoiType = poiType === "high_schools" || poiType === "primary_schools"
                ? "school"
                : "poi";
            if (typeguardUtils.poi.isSchool(poi, activePoiType) &&
                (poi === null || poi === void 0 ? void 0 : poi.catchments) &&
                Object.keys((poi === null || poi === void 0 ? void 0 : poi.catchments) || []).length > 0) {
                setSchoolCatchment(mapUtils.formatGeometry(poi.catchments[0].geometry));
            }
        }
    }, [activePOI, poi]);
    useEffect(() => {
        if (isMapMoving) {
            setSchoolCatchment(undefined);
        }
    }, [isMapMoving]);
    const calculateRoute = () => {
        if (!walkingData || !isOpen) {
            return;
        }
        setDestination({ label: poi.name, lat: poi.lat, lng: poi.lng });
        setCommuteGeojson(mapUtils.formatMapBoxGeoJson(walkingData.geometry));
        setShowCommuteCalculator(true);
        setIsOpen(false);
        setSchoolCatchment(undefined);
        setIsInputAutoFocused(false);
        setIsPoiCalcCommute(true);
        tracking.trackAnalyticsEvent({
            eventName: AnalyticsEvents.POI_CALCULATE_ROUTE,
        });
    };
    useEffect(() => {
        if (isPoiCalCommute) {
            tracking.postEvent({
                eventType: TrackingPipelineEvents.COMMUTE_CALCULATE_ROUTE,
            });
        }
        return () => {
            setIsPoiCalcCommute(false);
        };
    }, [isPoiCalCommute]);
    const commuteTimeInMinutes = (commuteData) => Math.floor((commuteData.duration / 60) % 60);
    const calculateCommuteTime = (commuteData) => {
        if (!(commuteData === null || commuteData === void 0 ? void 0 : commuteData.duration) || !isOpen) {
            return null;
        }
        const minutes = commuteTimeInMinutes(commuteData);
        return `${minutes} ${t("common:time.minute", { count: minutes })}`;
    };
    const walkingTime = useMemo(() => calculateCommuteTime(walkingData), [walkingData, isOpen]);
    const drivingTime = useMemo(() => calculateCommuteTime(drivingData), [drivingData, isOpen]);
    const handleTrackPoiClick = () => {
        tracking.trackAnalyticsEvent({
            eventName: AnalyticsEvents.MAP_POI_SELECTED,
        });
    };
    return (React.createElement(M, { latitude: poi.lat, longitude: poi.lng, style: { zIndex: isOpen ? 1 : 0 } },
        React.createElement(POIMarker.Root, { options: {
                type: poiType,
                poi,
                isOpen: isMapMoving ? false : isOpen,
                isHovered,
                side: isMobile ? "bottom" : "right",
                size: mediumSizedPois.includes(poiType)
                    ? "medium"
                    : "small",
                walkingTime,
                drivingTime,
                showDriveTime: walkingData && commuteTimeInMinutes(walkingData) > 15,
                calculateRoute,
            }, 
            // eslint-disable-next-line
            onChange: (e) => {
                if (e.type === "open-change") {
                    if (e.data) {
                        handleTrackPoiClick();
                        // setTimeout used to solve issue where switching between
                        // POIs would cause the new POI dialog to immediately
                        // close.
                        setTimeout(() => {
                            setActivePOI(poi);
                            setCommuteGeojson(undefined);
                            setShowCommuteCalculator(false);
                        }, 0);
                    }
                    else if (isOpen) {
                        setActivePOI(undefined);
                        setSchoolCatchment(undefined);
                    }
                }
            } },
            React.createElement(POIMarker.Marker, null),
            React.createElement(POIMarker.Content, null)),
        schoolCatchment && React.createElement(SchoolCatchment, { schoolCatchment: schoolCatchment })));
};
export default Marker;
//# sourceMappingURL=index.js.map