import React from "react";
import { Marker as M } from "react-map-gl/maplibre";
import useSupercluster from "use-supercluster";
import Marker from "./Marker";
import Cluster from "./Cluster";
function isCluster(cluster) {
    return cluster.properties.cluster !== undefined;
}
const Markers = React.memo(({ rect, zoom, mapRef, points, isMobile, activePOI, hoveredPOI, isMapMoving, }) => {
    var _a;
    const bounds = (_a = mapRef === null || mapRef === void 0 ? void 0 : mapRef.current) === null || _a === void 0 ? void 0 : _a.getMap().getBounds().toArray().flat();
    const { clusters, supercluster } = useSupercluster({
        points,
        bounds,
        zoom,
        options: { radius: 50, maxZoom: 30 },
    });
    return (React.createElement(React.Fragment, null, clusters.map((cluster, i) => {
        const [longitude, latitude] = cluster.geometry.coordinates;
        if (isCluster(cluster)) {
            return (React.createElement(M, { key: `cluster-${cluster.id}`, latitude: latitude, longitude: longitude },
                React.createElement(Cluster, { rect: rect, zoom: zoom, cluster: cluster, supercluster: supercluster, pointsCount: points.length, activePOI: activePOI, isMobile: isMobile, isMapMoving: isMapMoving, hoveredPOI: hoveredPOI, onClick: () => {
                        var _a;
                        const expansionZoom = Math.min(supercluster.getClusterExpansionZoom(cluster.id), 20);
                        (_a = mapRef.current) === null || _a === void 0 ? void 0 : _a.flyTo({
                            zoom: expansionZoom,
                            center: [longitude, latitude],
                            duration: 1000,
                            // Without this, some operating systems will prevent this from
                            // working. See comment:
                            // https://docs.mapbox.com/mapbox-gl-js/example/flyto-options/
                            essential: true,
                        });
                    } })));
        }
        return (React.createElement(Marker, { key: i, rect: rect, poi: cluster.properties.poi, poiType: cluster.properties.type, isMobile: isMobile, activePOI: activePOI, hoveredPOI: hoveredPOI, isMapMoving: isMapMoving }));
    })));
});
Markers.displayName = "Markers";
export default Markers;
//# sourceMappingURL=index.js.map