import { useTracking } from "@local-logic/core/tracking";
import { scorePois } from "~/sdks/LocalContentDeprecated/constants/score-categories";
import { multiPoint, point, bbox, } from "@turf/turf";
import React, { useRef, useMemo, useEffect, useState } from "react";
import { Layer, Source, } from "react-map-gl/maplibre";
import Map from "~/sdks/LocalContentDeprecated/components/MapGL";
import { Attribution } from "~/components/Attribution";
import CommuteContainer from "~/sdks/LocalContentDeprecated/components/CommuteContainer";
import DesktopScores from "~/sdks/LocalContentDeprecated/components/DesktopScores";
import Pin from "~/components/Pin";
import { useStateManagerContext } from "~/context/stateManager";
import useIsMobile from "~/hooks/useIsMobile";
import useMeasure from "~/hooks/useMeasure";
import errorTracker from "~/utils/errorTracker";
import { TrackingPipelineEvents, } from "~/sdks/LocalContentDeprecated/types";
import { useLocalContent } from "~/sdks/LocalContentDeprecated/context";
import MobileScores from "~/sdks/LocalContentDeprecated/components/MobileScores";
import { usePois } from "~/sdks/LocalContentDeprecated/hooks/usePois";
import { useSchools } from "~/sdks/LocalContentDeprecated/hooks/useSchools";
import Markers from "./Markers";
const MapGLMap = () => {
    var _a;
    const { sdkState, setSdkState } = useStateManagerContext();
    const { activeScore, activePOI, setActivePOI, hoveredPOI, commuteGeojson, destination, showCommuteCalculator, initialLocation, } = useLocalContent();
    const isMobile = useIsMobile();
    const poisResult = usePois(activeScore);
    const schoolsResult = useSchools({ activeScore });
    const tracking = useTracking();
    const [isMapMoving, setIsMapMoving] = useState(false);
    const commuteLineColor = getComputedStyle(document.documentElement).getPropertyValue("--ll-color-link");
    const roteLayerStyle = {
        id: "point",
        type: "line",
        paint: {
            "line-width": 6,
            "line-color": commuteLineColor,
        },
    };
    useEffect(() => {
        if (activePOI) {
            tracking.postEvent({
                eventType: TrackingPipelineEvents.POI_CLICKED,
                eventAttributes: [
                    {
                        label: "activePOI",
                        data: activePOI === null || activePOI === void 0 ? void 0 : activePOI.name,
                    },
                ],
            });
            errorTracker.addBreadCrumb("MapGLMap", "POI clicked", {
                POI: activePOI,
            });
        }
    }, [activePOI]);
    useEffect(() => {
        if (typeof activePOI !== "undefined" && isMapMoving) {
            setActivePOI(undefined);
        }
    }, [activePOI, isMapMoving, setActivePOI]);
    const activePOIs = useMemo(() => {
        var _a, _b;
        if ((activeScore === "high_schools" || activeScore === "primary_schools") &&
            !schoolsResult.isFetching) {
            return { [activeScore]: ((_a = schoolsResult === null || schoolsResult === void 0 ? void 0 : schoolsResult.data) === null || _a === void 0 ? void 0 : _a[activeScore]) || [] };
        }
        if (!(scorePois &&
            activeScore &&
            scorePois[activeScore] &&
            ((_b = scorePois[activeScore]) === null || _b === void 0 ? void 0 : _b.length)) &&
            !poisResult.isFetching) {
            return { [activeScore]: [] };
        }
        return poisResult.data ? poisResult.data : [];
    }, [poisResult.data, schoolsResult.data, activeScore]);
    /**
     * POIs to render on the map
     */
    const points = useMemo(() => {
        if (!activePOIs) {
            return [];
        }
        const arr = Object.entries(activePOIs)
            .map(([key, pois]) => pois.map((poi) => point([poi.lng, poi.lat], { poi, type: key })))
            .flat();
        return arr.filter((v, i, a) => a.findIndex((v2) => ["lat", "lng", "name"].every(
        // eslint-disable-next-line @typescript-eslint/ban-ts-comment
        // @ts-ignore
        (k) => v2.properties.poi[k] === v.properties.poi[k])) === i);
    }, [activePOIs]);
    /**
     * The POIs to render on the map (including the Pin)
     */
    const pointsWithPin = useMemo(() => {
        var _a, _b, _c;
        const markerPoint = ((_a = sdkState === null || sdkState === void 0 ? void 0 : sdkState.options) === null || _a === void 0 ? void 0 : _a.marker) &&
            point([(_b = sdkState === null || sdkState === void 0 ? void 0 : sdkState.options) === null || _b === void 0 ? void 0 : _b.marker.lng, (_c = sdkState === null || sdkState === void 0 ? void 0 : sdkState.options) === null || _c === void 0 ? void 0 : _c.marker.lat]);
        return [
            ...points,
            ...(markerPoint ? [markerPoint] : []),
            ...(destination ? [point([destination === null || destination === void 0 ? void 0 : destination.lng, destination === null || destination === void 0 ? void 0 : destination.lat])] : []),
        ];
    }, [points, (_a = sdkState === null || sdkState === void 0 ? void 0 : sdkState.options) === null || _a === void 0 ? void 0 : _a.marker, destination]);
    const mapRef = useRef();
    const [ref, rect] = useMeasure();
    const mobileMapPadding = useMemo(() => {
        const padding = 75;
        errorTracker.addBreadCrumb("MapGLMap", "mobileMapPadding changed");
        return {
            top: padding + rect.height,
            bottom: padding,
            left: padding,
            right: padding,
        };
    }, [rect.height]);
    const desktopMapPadding = useMemo(() => {
        const padding = 80;
        errorTracker.addBreadCrumb("MapGLMap", "desktopMapPadding changed");
        return {
            top: padding,
            bottom: padding,
            left: rect.width + 32 + padding,
            right: padding,
        };
    }, [rect.width]);
    const mapPadding = isMobile ? mobileMapPadding : desktopMapPadding;
    const handleOnMove = (e) => {
        setSdkState(Object.assign(Object.assign({}, sdkState), { options: Object.assign(Object.assign({}, sdkState.options), { lat: e.viewState.latitude, lng: e.viewState.longitude, zoom: e.viewState.zoom, bearing: e.viewState.bearing, pitch: e.viewState.pitch }) }));
    };
    /**
     * Reposition map when points change
     */
    useEffect(() => {
        var _a, _b;
        if (!activeScore || poisResult.isFetching || schoolsResult.isFetching) {
            return;
        }
        let multiPt;
        if (pointsWithPin.length > 0) {
            multiPt = multiPoint(pointsWithPin.map(({ geometry }) => [
                geometry.coordinates[1],
                geometry.coordinates[0],
            ]));
        }
        else if (typeof ((_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.marker) === "undefined" &&
            typeof initialLocation.lat !== "undefined" &&
            typeof initialLocation.lng !== "undefined") {
            multiPt = multiPoint([[initialLocation.lat, initialLocation.lng]]);
        }
        else {
            return;
        }
        errorTracker.addBreadCrumb("MapGLMap", "useEffect: Repositioning map because points changed");
        const [minLat, minLng, maxLat, maxLng] = bbox(multiPt);
        (_b = mapRef === null || mapRef === void 0 ? void 0 : mapRef.current) === null || _b === void 0 ? void 0 : _b.fitBounds([
            [minLng, minLat],
            [maxLng, maxLat],
        ], {
            maxZoom: 17,
            padding: mapPadding,
            duration: 1000,
        });
    }, [
        pointsWithPin,
        mapPadding,
        activeScore,
        schoolsResult.isFetching,
        poisResult.isFetching,
        initialLocation,
    ]);
    const handleAttributionClicked = () => {
        tracking.postEvent({
            eventType: TrackingPipelineEvents.ATTRIBUTION_CLICKED,
        });
    };
    if (!sdkState.options) {
        return React.createElement("div", null, "No options provided.");
    }
    return (React.createElement(React.Fragment, null,
        React.createElement(Map, { mapRef: mapRef, mapPadding: mapPadding, distanceUnit: sdkState.options.distanceUnit, handleOnMove: handleOnMove, setIsMapMoving: setIsMapMoving, style: {
                flex: 1,
                width: "100vw",
            }, position: isMobile ? "top-right" : "bottom-right", navigationStyle: {
                marginTop: isMobile ? 16 + rect.height : 16,
                marginRight: 16,
            } },
            React.createElement(React.Fragment, null,
                sdkState.options.marker && React.createElement(Pin, { marker: sdkState.options.marker }),
                React.createElement(Markers, { rect: rect, zoom: sdkState.options.zoom, 
                    // eslint-disable-next-line @typescript-eslint/ban-ts-comment
                    // @ts-ignore
                    mapRef: mapRef, points: points, isMobile: isMobile, activePOI: activePOI, hoveredPOI: hoveredPOI, isMapMoving: isMapMoving }),
                isMobile ? React.createElement(MobileScores, { ref: ref }) : React.createElement(DesktopScores, { ref: ref }),
                React.createElement(CommuteContainer, null),
                destination && showCommuteCalculator && (React.createElement(Pin, { marker: Object.assign({ icon: "pin" }, destination) })),
                commuteGeojson && (React.createElement(Source, { type: "geojson", data: commuteGeojson },
                    React.createElement(Layer, Object.assign({}, roteLayerStyle)))))),
        isMobile && React.createElement(Attribution, { onClick: handleAttributionClicked })));
};
export default MapGLMap;
//# sourceMappingURL=index.js.map