import React, { useMemo } from "react";
import MapGL, { AttributionControl, NavigationControl, } from "react-map-gl/maplibre";
import { useStateManagerContext } from "~/context/stateManager";
import useIsMobile from "~/hooks/useIsMobile";
import errorTracker from "~/utils/errorTracker";
import * as styles from "./styles";
import { MapProvider } from "./context";
const Map = ({ minZoom, mapRef, mapPadding, children, style, position = "top-left", navigationStyle, distanceUnit, handleOnMove, setIsMapMoving, }) => {
    var _a, _b;
    const { sdkState } = useStateManagerContext();
    const isMobile = useIsMobile();
    const mapTilerTheme = ((_b = (_a = sdkState === null || sdkState === void 0 ? void 0 : sdkState.globalOptions) === null || _a === void 0 ? void 0 : _a.appearance) === null || _b === void 0 ? void 0 : _b.theme) === "night"
        ? // SDKs Streets Dark
            "a6156f3f-46f3-4143-b90a-3f80eed1b2c8"
        : // SDKs Basic
            "d140f7e5-abd5-4020-b713-f281d7b1f57d";
    const currentViewPort = useMemo(() => (isMobile ? "mobile" : "desktop"), [isMobile]);
    const handleOnLoad = () => {
        errorTracker.addBreadCrumb("MapGL", "Map loaded");
    };
    const handleOnError = (e) => {
        errorTracker.addBreadCrumb("MapGL", "Map error", {
            error: e,
        });
    };
    if (!sdkState.options) {
        return React.createElement("div", null, "No options provided.");
    }
    return (
    // eslint-disable-next-line @typescript-eslint/ban-ts-comment
    // @ts-ignore
    React.createElement(MapProvider, { mapRef: mapRef, mapPadding: mapPadding },
        React.createElement("div", { className: styles.mapContainer },
            React.createElement(MapGL
            // eslint-disable-next-line @typescript-eslint/ban-ts-comment
            // @ts-ignore
            , { 
                // eslint-disable-next-line @typescript-eslint/ban-ts-comment
                // @ts-ignore
                ref: mapRef, key: currentViewPort, latitude: sdkState.options.lat, longitude: sdkState.options.lng, zoom: sdkState.options.zoom, minZoom: minZoom, pitch: sdkState.options.pitch, bearing: sdkState.options.bearing, unit: distanceUnit, style: style, mapStyle: `https://api.maptiler.com/maps/${mapTilerTheme}/style.json?key=${import.meta.env.VITE_MAPTILER_KEY}`, onMove: handleOnMove, cooperativeGestures: sdkState.options.cooperativeGestures, onMoveStart: () => setIsMapMoving(true), onMoveEnd: () => setIsMapMoving(false), onLoad: handleOnLoad, onError: handleOnError, attributionControl: false },
                React.createElement(AttributionControl, { compact: true, position: isMobile ? "bottom-left" : "bottom-right" }),
                React.createElement(NavigationControl, { position: position, showCompass: true, style: navigationStyle }),
                children))));
};
export default Map;
//# sourceMappingURL=index.js.map