import React, { useEffect } from "react";
import { LoadingItem } from "@local-logic/core/ui";
import { useLocalContent } from "~/sdks/LocalContentDeprecated/context";
import { AnalyticsEvents } from "~/sdks/LocalContentDeprecated/types";
import useFilterSortScores from "~/sdks/LocalContentDeprecated/features/useFilterSortScores";
import { useTracking } from "@local-logic/core/tracking";
import * as Score from "~/sdks/LocalContentDeprecated/components/Score";
import * as styles from "./styles";
const CategoryScores = ({ category }) => {
    const { activeScore, setActiveScore, setActiveCategory, hideScores } = useLocalContent();
    const { cleanScores, data, isLoading, isFetching } = useFilterSortScores(category.scores);
    const tracking = useTracking();
    useEffect(() => {
        if (cleanScores.length > 0) {
            setActiveScore(cleanScores[0]);
        }
    }, [cleanScores]);
    const handleTrackScoreSelected = (value) => {
        if (value) {
            tracking.trackAnalyticsEvent({
                eventName: AnalyticsEvents.SCORE_EXPANDED,
                eventAttributes: {
                    ll_selected_score: value,
                },
            });
        }
    };
    return (React.createElement("div", { className: styles.categoryScores }, cleanScores.length > 0 &&
        cleanScores.map((score) => {
            const isActive = score === activeScore;
            const color = isActive ? "--ll-color-primary" : "--ll-color-disabled";
            if (isLoading || isFetching) {
                return (React.createElement("div", { className: styles.loadingItemContainer, key: score },
                    React.createElement(LoadingItem, { height: "44px", width: "60px" })));
            }
            return (React.createElement(Score.Root, { key: score, options: { score, scoresData: data } },
                React.createElement("div", { className: styles.scoreItem, onClick: () => {
                        setActiveCategory(category.value);
                        setActiveScore(score);
                        handleTrackScoreSelected(score);
                    } },
                    React.createElement(Score.Icon, { isActive: activeScore === score }),
                    React.createElement("div", { className: styles.textContainer },
                        React.createElement(Score.Title, { options: {
                                variant: "caption1",
                                color,
                                lineClamp: 1,
                                noMargin: true,
                                weight: "--ll-font-weight-bold",
                            } })),
                    !hideScores && (React.createElement("div", { className: styles.badgeContainer },
                        React.createElement(Score.Badge, { options: { variant: "small", isPrimary: isActive } }))))));
        })));
};
export default CategoryScores;
//# sourceMappingURL=index.js.map