import { useTracking } from "@local-logic/core/tracking";
import React, { useState, useEffect } from "react";
import { scoreCategories } from "~/sdks/LocalContentDeprecated/constants/score-categories";
import { useStateManagerContext } from "~/context/stateManager";
import { useLocalContent } from "~/sdks/LocalContentDeprecated/context";
import { TrackingPipelineEvents, } from "~/sdks/LocalContentDeprecated/types";
import { MapPin as MapPinIcon, House as HouseIcon, } from "@phosphor-icons/react";
import { useScores } from "~/features/clientLibrary/useScores";
import * as Score from "../../Score";
import * as styles from "./styles";
const ScoreInfo = () => {
    var _a, _b;
    const { sdkState } = useStateManagerContext();
    const { activeCategory, activeScore, location, hideScores } = useLocalContent();
    const tracking = useTracking();
    const currentScoreCategory = scoreCategories.find((c) => c.value === activeCategory);
    const { data, isLoading } = useScores({
        include: currentScoreCategory.scores,
        location,
    });
    const [isCtaClicked, setIsCtaClicked] = useState(false);
    const ctaClicked = () => {
        setIsCtaClicked(!isCtaClicked);
    };
    useEffect(() => {
        if (isCtaClicked) {
            tracking.postEvent({
                eventType: TrackingPipelineEvents.LONG_DESCRIPTION_CLICKED,
                eventAttributes: [
                    {
                        label: "activeScore",
                        data: activeScore.toString(),
                    },
                ],
            });
        }
        return () => {
            setIsCtaClicked(false);
        };
    }, [isCtaClicked]);
    if (!(activeScore && (data === null || data === void 0 ? void 0 : data.location[activeScore]))) {
        return null;
    }
    if (isLoading) {
        return React.createElement("div", null, "Loading");
    }
    if (hideScores) {
        return null;
    }
    return (React.createElement(Score.Root, { options: {
            score: activeScore,
            scoresData: data,
        } },
        React.createElement("div", { className: styles.scoreInfo },
            React.createElement("div", { className: styles.scoreContainer },
                React.createElement(Score.Badge, null),
                React.createElement(Score.BarChart, { options: {
                        locationIcon: ((_b = (_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.marker) === null || _b === void 0 ? void 0 : _b.icon) === "pin"
                            ? MapPinIcon
                            : HouseIcon,
                    } })),
            React.createElement(Score.Description, { ctaClicked: ctaClicked }))));
};
export default ScoreInfo;
//# sourceMappingURL=index.js.map