import { useTracking } from "@local-logic/core/tracking";
import { Select } from "@local-logic/core/ui";
import * as SC from "~/sdks/LocalContentDeprecated/components/ScoreCategory";
import React, { useState, useEffect } from "react";
import { useLocalContent } from "~/sdks/LocalContentDeprecated/context";
import useRankedCategories from "~/sdks/LocalContentDeprecated/features/useRankedCategories";
import { TrackingPipelineEvents, AnalyticsEvents, } from "~/sdks/LocalContentDeprecated/types";
import * as styles from "./styles";
import ScoreInfo from "./ScoreInfo";
import CategoryScores from "./CategoryScores";
const MobileScores = React.forwardRef((props, forwardedRef) => {
    const { activeCategory, setActiveCategory } = useLocalContent();
    const tracking = useTracking();
    const { data } = useRankedCategories();
    const [rankedCategories, setRankedCategories] = useState(data);
    useEffect(() => {
        // The reason we're setting our own state is to trigger a re-render
        // If we're just using the "data" directly, setting the new active
        // category is completed but no re-render is done, showing the old
        // active category instead
        setRankedCategories(data);
        if (data.length > 0) {
            setActiveCategory(data[0].value);
        }
    }, [data]);
    const handleCategoryChanged = (category) => {
        setActiveCategory(category);
        tracking.postEvent({
            eventType: TrackingPipelineEvents.CATEGORY_CLICKED,
            eventAttributes: [
                {
                    label: "activeCategory",
                    data: category,
                },
            ],
        });
        tracking.trackAnalyticsEvent({
            eventName: AnalyticsEvents.CATEGORY_SELECTED,
            eventAttributes: {
                ll_selected_category: category,
            },
        });
    };
    return (React.createElement("div", { className: styles.scoresContainer, ref: forwardedRef },
        React.createElement("div", { className: styles.selectContainer },
            React.createElement(Select.Root, { value: activeCategory, onValueChange: (category) => handleCategoryChanged(category) },
                React.createElement(Select.Trigger, { size: "large" },
                    React.createElement(SC.Root, { key: activeCategory, options: { scoreCategory: activeCategory } },
                        React.createElement(SC.Title, { options: {
                                color: "inherit",
                                noMargin: true,
                                variant: "h6",
                                lineHeight: 1,
                            } }))),
                React.createElement(Select.Content, null, rankedCategories.map((category) => (React.createElement(SC.Root, { key: category.value, options: { scoreCategory: category.value } },
                    React.createElement(Select.Item, { value: category.value },
                        React.createElement(SC.Title, { options: {
                                color: "inherit",
                                noMargin: true,
                                variant: "h6",
                            } })))))))),
        rankedCategories.length > 0 && (React.createElement(CategoryScores, { category: rankedCategories.find((s) => s.value === activeCategory) })),
        React.createElement(ScoreInfo, null)));
});
MobileScores.displayName = "MobileScores";
export default MobileScores;
//# sourceMappingURL=index.js.map