import React from "react";
import { useTranslation } from "react-i18next";
import { useStateManagerContext } from "~/context/stateManager";
import { Text, Tag, Link, theme, Spacer, Button, Popover, } from "@local-logic/core/ui";
import { primitiveUtils, typeguardUtils } from "@local-logic/core/utils";
import { PoiIcon } from "~/components/PoiIcon";
import { TransportIcon } from "~/components/TransportIcon";
import { useRootElement } from "../context";
import * as styles from "./styles";
export const Content = () => {
    var _a, _b, _c, _d, _e, _f, _g;
    const { t } = useTranslation(["localContent", "common"]);
    const { options: { poi, side, collisionPadding, type, walkingTime, drivingTime, showDriveTime, calculateRoute, }, } = useRootElement();
    const { sdkState } = useStateManagerContext();
    const poiType = type === "high_schools" || type === "primary_schools" ? "school" : "poi";
    const mapLanguages = (languages) => languages.map((language) => {
        switch (language) {
            case "en":
                return t("common:language.english");
            case "fr":
                return t("common:language.french");
            case "es":
                return t("common:language.spanish");
            default:
                return language;
        }
    });
    return (React.createElement(Popover.Content, { className: styles.content, side: side, collisionPadding: collisionPadding },
        React.createElement(Text, { variant: "h5", noMargin: true, weight: "--ll-font-weight-bold" }, poi.name),
        React.createElement(Spacer, { vertical: true, spacing: "--ll-spacing-xx-small" }),
        poi.address && (React.createElement(Text, { variant: "p", noMargin: true }, poi.address)),
        React.createElement(Spacer, { vertical: true, spacing: "--ll-spacing-xx-small" }),
        poi.url && (React.createElement(React.Fragment, null,
            React.createElement(Link, { lineClamp: 2, href: poi.url }, poi.url),
            React.createElement(Spacer, { vertical: true, spacing: "--ll-spacing-xx-small" }))),
        typeguardUtils.poi.isSchool(poi, poiType) ? (React.createElement("div", { className: styles.schoolTextContainer },
            ((_a = poi.school_attributes) === null || _a === void 0 ? void 0 : _a.grades) && (React.createElement(React.Fragment, null,
                React.createElement(Text, null,
                    t("common:map.marker.schoolAttributes.levels"),
                    ": "),
                React.createElement(Text, { color: theme["--ll-color-on-background-variant1"] }, primitiveUtils.string.capitalize(poi.school_attributes.grades)))),
            ((_b = poi.school_attributes) === null || _b === void 0 ? void 0 : _b.languages) && (React.createElement(React.Fragment, null,
                React.createElement(Text, null,
                    t("common:map.marker.schoolAttributes.languages"),
                    ": "),
                React.createElement(Text, { color: theme["--ll-color-on-background-variant1"] }, primitiveUtils.string.capitalize(mapLanguages(poi.school_attributes.languages).join(", "))))),
            ((_c = poi.school_attributes) === null || _c === void 0 ? void 0 : _c.types) && (React.createElement(React.Fragment, null,
                React.createElement(Text, null,
                    t("common:map.marker.schoolAttributes.types"),
                    ": "),
                React.createElement(Text, { color: theme["--ll-color-on-background-variant1"] }, primitiveUtils.string.capitalize(poi.school_attributes.types.join(", "))))),
            ((_d = poi.school_board_attributes) === null || _d === void 0 ? void 0 : _d.name) &&
                ((_e = poi.school_board_attributes) === null || _e === void 0 ? void 0 : _e.url) && (React.createElement(React.Fragment, null,
                React.createElement(Text, null,
                    t("common:map.marker.schoolAttributes.board"),
                    ": "),
                React.createElement(Link, { href: poi.school_board_attributes.url }, primitiveUtils.string.capitalize(poi.school_board_attributes.name)))))) : (poi.routes && (React.createElement("div", { className: styles.routeContainer },
            React.createElement(PoiIcon, { poi: type, className: styles.icon }), (_f = poi.routes) === null || _f === void 0 ? void 0 :
            _f.map((route, i2) => (React.createElement(Tag, { className: styles.tag, key: route.short_name + i2, text: route.short_name, backgroundColor: route.route_color, textColor: route.text_color })))))),
        React.createElement(Tag, { text: t(`common:pois.${type}`), size: "medium", backgroundColor: theme["--ll-color-primary"], textColor: theme["--ll-color-on-primary"] }),
        typeof ((_g = sdkState.options) === null || _g === void 0 ? void 0 : _g.marker) !== "undefined" && calculateRoute && (React.createElement(React.Fragment, null,
            React.createElement(Spacer, { vertical: true, spacing: "--ll-spacing-small" }),
            React.createElement("div", { className: styles.routeContainer, "data-justify": walkingTime ? "space-between" : "end" },
                walkingTime && (React.createElement("div", { className: styles.routeResultContainer },
                    React.createElement(TransportIcon, { transport: showDriveTime ? "car" : "pedestrian", className: styles.icon }),
                    React.createElement(Text, { variant: "p", noMargin: true }, showDriveTime ? drivingTime : walkingTime))),
                React.createElement(Button, { size: "small", variant: "contained", onClick: calculateRoute }, t("commuteCalculator.ctaShort")))))));
};
//# sourceMappingURL=index.js.map