import React, { useMemo } from "react";
import { useTranslation } from "react-i18next";
import { Text } from "@local-logic/core/ui";
import { MapPin as MapPinIcon } from "@phosphor-icons/react";
import useMeasure from "~/hooks/useMeasure";
import useHelpers from "../../useHelpers";
import { useRootElement } from "../context";
import * as styles from "./styles";
export const BarChart = ({ options: { locationIcon, renderCityAvg } = {}, }) => {
    const { t } = useTranslation("localContent");
    const { options: { scoresData, score, renderForPrint }, } = useRootElement();
    const [ref, rect] = useMeasure();
    const { scoreVal, cityName, cityScoreVal } = useHelpers({
        score,
        scoresData,
    });
    const LocationIcon = useMemo(() => (typeof locationIcon !== "undefined" ? locationIcon : MapPinIcon), [locationIcon]);
    if (scoreVal === null) {
        return null;
    }
    return (React.createElement(React.Fragment, null,
        React.createElement("div", { className: styles.barChartContainer, "data-is-using-icons": !!locationIcon, ref: ref },
            React.createElement(React.Fragment, null,
                React.createElement(LocationIcon, { className: styles.icon }),
                React.createElement(Text, { variant: "p", weight: "--ll-font-weight-bold", noMargin: true, color: "--ll-color-on-background-variant1" }, t("scores.location")),
                React.createElement("div", { className: styles.barChartBackground },
                    React.createElement("div", { className: styles.barChartLine, "data-render-for-print": renderForPrint, style: { width: `${(scoreVal / 10) * 100}%` } })),
                React.createElement(Text, { variant: "p", weight: "--ll-font-weight-bold", noMargin: true, align: "right", color: "--ll-color-on-background-variant1" }, scoreVal)),
            cityScoreVal !== null && renderCityAvg !== false && (React.createElement(React.Fragment, null,
                React.createElement("div", null),
                React.createElement("div", { className: styles.districtTextContainer, style: { maxWidth: `${rect.width / 2}px` } },
                    React.createElement(Text, { variant: "p", noMargin: true, color: "--ll-color-on-background-variant1" }, t("scores.average", {
                        type: cityName || t("scores.neighborhood"),
                    }))),
                React.createElement("div", { className: styles.barChartBackground },
                    React.createElement("div", { className: styles.barChartLine, style: { width: `${(cityScoreVal / 10) * 100}%` } })),
                React.createElement(Text, { variant: "p", noMargin: true, align: "right", color: "--ll-color-on-background-variant1" }, cityScoreVal))))));
};
//# sourceMappingURL=index.js.map