import React from "react";
import { useTranslation } from "react-i18next";
import { Text } from "@local-logic/core/ui";
import { Bus as BusIcon, HouseLine as HouseLineIcon, Star as StarIcon, Mountains as MountainsIcon, GraduationCap as GraduationCapIcon, FlowerLotus as FlowerLotusIcon, } from "@phosphor-icons/react";
import { scoreCategories, } from "~/sdks/LocalContentDeprecated/constants/score-categories";
import { TabsList, TabsTrigger } from "@radix-ui/react-tabs";
import * as styles from "./styles";
import { useRootElement } from "../context";
const icons = {
    commute: BusIcon,
    amenities: HouseLineIcon,
    character: StarIcon,
    nature: MountainsIcon,
    education: GraduationCapIcon,
    wellness: FlowerLotusIcon,
};
export const Tabs = ({ category }) => {
    const { t } = useTranslation("localContent");
    const { currentTab } = useRootElement();
    const scores = category || scoreCategories;
    return (React.createElement(TabsList, { className: styles.tabsList, "aria-label": "Score Category tabs", role: "none" }, scores.map((tab) => {
        const isActive = tab.value === currentTab;
        const triggerColor = isActive
            ? "--ll-color-primary"
            : "--ll-color-disabled";
        const IconElement = icons[tab.value];
        return (React.createElement(React.Fragment, { key: tab.value },
            React.createElement(TabsTrigger, { className: styles.trigger, value: tab.value, "data-is-active": isActive, "data-cy": "score-category-tab", "data-testid": tab.value, role: "none" },
                React.createElement(IconElement, { className: styles.icon }),
                React.createElement(Text, { noMargin: true, variant: "caption1", color: triggerColor, weight: "--ll-font-weight-semibold" }, t(`tabs.${tab.value}`)))));
    })));
};
//# sourceMappingURL=index.js.map