var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { baseStyles } from "@local-logic/core/ui";
import { scoreCategories } from "~/sdks/LocalContentDeprecated/constants/score-categories";
import React, { useContext, useState, useMemo, useReducer, } from "react";
import errorTracker from "~/utils/errorTracker";
import useEffectOnce from "~/hooks/useEffectOnce";
import { useStateManagerContext } from "~/context/stateManager";
import useDebounce from "~/hooks/useDebounce";
import { useTracking } from "@local-logic/core/tracking";
import { validateOptions } from "./schema";
import { AnalyticsEvents, TrackingPipelineEvents, } from "./types";
const LocalContentContext = React.createContext({});
const useLocalContent = () => useContext(LocalContentContext);
const scoreCategoryReducer = (state, action
// eslint-disable-next-line consistent-return
) => {
    switch (action.type) {
        case "CATEGORY": {
            return Object.assign(Object.assign({}, state), { activeCategory: action.value });
        }
        case "SCORE": {
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            const newActiveCategory = scoreCategories.find((c) => {
                if (action.value === "") {
                    return c.value === state.activeCategory;
                }
                return c.scores.includes(action.value);
            }).value;
            return {
                activeCategory: newActiveCategory,
                activeScoreByCategory: Object.assign(Object.assign({}, state.activeScoreByCategory), { [newActiveCategory]: action.value }),
            };
        }
    }
};
const LocalContentProvider = ({ children }) => {
    var _a, _b;
    const { sdkState } = useStateManagerContext();
    const [initialLocation, _] = useState({
        lat: (_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.lat,
        lng: (_b = sdkState.options) === null || _b === void 0 ? void 0 : _b.lng,
    });
    const tracking = useTracking();
    const debouncedOptions = useDebounce(sdkState.options, 250);
    const scoreCategoryDefault = window.innerWidth < baseStyles.screenSizes.tablet
        ? {
            activeCategory: "commute",
            activeScoreByCategory: {
                commute: "transit_friendly",
                amenities: "groceries",
                character: "quiet",
                nature: "parks",
                education: "primary_schools",
                wellness: "wellness",
            },
        }
        : {
            activeCategory: "commute",
            activeScoreByCategory: {
                commute: "",
                amenities: "",
                character: "",
                nature: "",
                education: "",
                wellness: "",
            },
        };
    const [scoreCategory, setScoreCategory] = useReducer(scoreCategoryReducer, scoreCategoryDefault);
    const [activePOI, setActivePOI] = useState();
    const [hoveredPOI, setHoveredPOI] = useState();
    const [commuteGeojson, setCommuteGeojson] = useState();
    const [destination, setDestination] = useState();
    const [showCommuteCalculator, setShowCommuteCalculator] = useState(false);
    const [isInputAutoFocused, setIsInputAutoFocused] = useState(false);
    const [country, setCountry] = useState("CAN,USA");
    const [validated, setValidated] = useState(false);
    const [validationErrors, setValidationErrors] = useState([]);
    const location = useMemo(() => {
        var _a, _b;
        return ({
            lat: ((_a = debouncedOptions === null || debouncedOptions === void 0 ? void 0 : debouncedOptions.marker) === null || _a === void 0 ? void 0 : _a.lat) || (initialLocation === null || initialLocation === void 0 ? void 0 : initialLocation.lat),
            lng: ((_b = debouncedOptions === null || debouncedOptions === void 0 ? void 0 : debouncedOptions.marker) === null || _b === void 0 ? void 0 : _b.lng) || (initialLocation === null || initialLocation === void 0 ? void 0 : initialLocation.lng),
        });
    }, [debouncedOptions, initialLocation]);
    const hideScores = useMemo(() => { var _a, _b; return (((_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.hideScores) ? (_b = sdkState.options) === null || _b === void 0 ? void 0 : _b.hideScores : false); }, [sdkState.options]);
    const collapseScores = useMemo(() => {
        var _a, _b;
        return ((_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.collapseScores)
            ? (_b = sdkState.options) === null || _b === void 0 ? void 0 : _b.collapseScores
            : false;
    }, [sdkState.options]);
    useEffectOnce(() => {
        const validate = () => __awaiter(void 0, void 0, void 0, function* () {
            try {
                errorTracker.addBreadCrumb("LocalContentProvider", "Validating state options", {
                    options: sdkState.options,
                });
                // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
                yield validateOptions(sdkState.options);
                setValidated(true);
            }
            catch (error) {
                const validationError = error;
                setValidationErrors(validationError.errors);
                errorTracker.addBreadCrumb("LocalContentProvider", "State option validation failed", {
                    errors: validationError.errors,
                });
            }
        });
        if (!validated) {
            validate();
        }
        tracking.postEvent({
            eventType: TrackingPipelineEvents.SDK_VIEWED,
        });
        tracking.trackAnalyticsEvent({
            eventName: AnalyticsEvents.SDK_VIEWED,
        });
    });
    const { activeCategory } = scoreCategory;
    const activeScore = scoreCategory.activeScoreByCategory[activeCategory];
    const setActiveScore = (value) => {
        setScoreCategory({ type: "SCORE", value });
        errorTracker.addBreadCrumb("LocalContentProvider", `Active score changed to: ${String(value)}`);
    };
    const setActiveCategory = (value) => {
        setScoreCategory({ type: "CATEGORY", value });
        errorTracker.addBreadCrumb("LocalContentProvider", `Active category changed to: ${value}`);
    };
    const contextValue = useMemo(() => ({
        country,
        setCountry,
        activeScore,
        setActiveScore,
        activeCategory,
        setActiveCategory,
        activePOI,
        setActivePOI,
        hoveredPOI,
        setHoveredPOI,
        commuteGeojson,
        setCommuteGeojson,
        destination,
        setDestination,
        showCommuteCalculator,
        isInputAutoFocused,
        setIsInputAutoFocused,
        setShowCommuteCalculator,
        location,
        initialLocation,
        hideScores,
        collapseScores,
    }), [
        country,
        setCountry,
        activeScore,
        setActiveScore,
        activeCategory,
        setActiveCategory,
        activePOI,
        setActivePOI,
        hoveredPOI,
        setHoveredPOI,
        commuteGeojson,
        setCommuteGeojson,
        destination,
        setDestination,
        showCommuteCalculator,
        isInputAutoFocused,
        setIsInputAutoFocused,
        setShowCommuteCalculator,
        location,
        initialLocation,
        hideScores,
        collapseScores,
    ]);
    if (!validated) {
        if (validationErrors.length) {
            const error = "Could not load Local Content";
            // eslint-disable-next-line no-console
            console.error(`${error}: ${validationErrors.join(", ")}`);
            return React.createElement("p", null, error);
        }
        return React.createElement(React.Fragment, null);
    }
    return (React.createElement(LocalContentContext.Provider, { value: contextValue }, children));
};
export { useLocalContent, LocalContentProvider };
//# sourceMappingURL=context.js.map