import { useMemo } from "react";
import { useScores } from "~/features/clientLibrary/useScores";
import { useLocalContent } from "../context";
const useFilterSortScores = (category) => {
    const { location, hideScores } = useLocalContent();
    const { data, isLoading, isFetching } = useScores({
        include: category,
        location,
    });
    const ifHideScores = [
        "cycling_friendly",
        "pedestrian_friendly",
        "quiet",
        "historic",
        "greenery",
    ];
    const cleanScores = useMemo(() => {
        if (isLoading || isFetching || typeof (data === null || data === void 0 ? void 0 : data.location) === "undefined") {
            return [];
        }
        let dataKeys = Object.keys(data.location);
        if (hideScores) {
            dataKeys = dataKeys.filter((score) => !ifHideScores.includes(score));
        }
        const filteredLocationKeys = dataKeys
            .filter((score) => {
            var _a, _b;
            return Number.parseFloat((_b = (_a = data.location[score]) === null || _a === void 0 ? void 0 : _a.value) !== null && _b !== void 0 ? _b : "0.0").toFixed(1) !== "0.0";
        })
            .map((score) => {
            var _a, _b;
            return ({
                score,
                value: Number.parseFloat((_b = (_a = data.location[score]) === null || _a === void 0 ? void 0 : _a.value) !== null && _b !== void 0 ? _b : "0.0").toFixed(1),
            });
        })
            .sort((a, b) => (a.value < b.value ? 1 : -1));
        if (filteredLocationKeys.length > 0) {
            const foundScores = filteredLocationKeys.map((score) => score.score);
            return foundScores;
        }
        return [];
    }, [data, isLoading, isFetching]);
    return { cleanScores, data, isLoading, isFetching };
};
export default useFilterSortScores;
//# sourceMappingURL=useFilterSortScores.js.map