import { useQuery } from "@tanstack/react-query";
import errorTracker from "~/utils/errorTracker";
const GOOGLE_ROUTES_ENDPOINT = import.meta.env
    .VITE_GOOGLE_MAPS_API_ENDPOINT;
export const formatOrigin = (sdkState) => {
    var _a, _b, _c;
    if ((_a = sdkState === null || sdkState === void 0 ? void 0 : sdkState.options) === null || _a === void 0 ? void 0 : _a.lat) {
        return {
            location: {
                latLng: {
                    latitude: (_b = sdkState === null || sdkState === void 0 ? void 0 : sdkState.options) === null || _b === void 0 ? void 0 : _b.lat,
                    longitude: (_c = sdkState === null || sdkState === void 0 ? void 0 : sdkState.options) === null || _c === void 0 ? void 0 : _c.lng,
                },
            },
        };
    }
    return null;
};
export const formatDestination = (dest) => {
    if ((dest === null || dest === void 0 ? void 0 : dest.lat) && (dest === null || dest === void 0 ? void 0 : dest.lng)) {
        return {
            location: {
                latLng: {
                    latitude: dest.lat,
                    longitude: dest.lng,
                },
            },
        };
    }
    return null;
};
export function useGoogleComputeRoute({ travelMode, origin, destination, units, polylineEncoding, googleApiKey, locale, }) {
    const options = {
        method: "POST",
        headers: {
            "Content-Type": "application/json",
            "X-Goog-Api-Key": googleApiKey,
            "X-Goog-FieldMask": "*",
        },
        body: JSON.stringify({
            languageCode: locale,
            travelMode,
            origin,
            destination,
            units,
            polylineEncoding,
        }),
    };
    const fetchRoutes = () => fetch(GOOGLE_ROUTES_ENDPOINT, options)
        .then((response) => response.json())
        .catch((error) => {
        errorTracker.captureException(error);
    });
    return useQuery({
        queryKey: ["useGoogleComputeRoute", options],
        queryFn: fetchRoutes,
        enabled: !!options && !!destination && !!origin,
    });
}
//# sourceMappingURL=useGoogleComputeRoute.js.map