import { useState, useMemo } from "react";
import { scoreCategories } from "~/sdks/LocalContentDeprecated/constants/score-categories";
import { useFlags } from "launchdarkly-react-client-sdk";
import { useScores } from "~/features/clientLibrary/useScores";
import { useLocalContent } from "../context";
const useRankedCategories = () => {
    const { location } = useLocalContent();
    const flags = useFlags();
    const [filteredScores] = useState(flags.lcWellnessTab
        ? scoreCategories
        : scoreCategories.filter((score) => score.value !== "wellness"));
    const { data, isLoading, isFetching } = useScores({
        location,
    });
    const sortedCategories = useMemo(() => {
        if (isLoading || isFetching || typeof (data === null || data === void 0 ? void 0 : data.location) === "undefined") {
            return filteredScores;
        }
        const isScoreEmpty = (value) => !value || Number.parseFloat(value).toFixed(1) === "0.0";
        const dataKeys = Object.keys(data === null || data === void 0 ? void 0 : data.location);
        const rankedTabs = [];
        filteredScores.forEach((category) => {
            let rank = 0;
            category.scores.forEach((score) => {
                var _a, _b, _c;
                const scoreValue = Number(Number.parseFloat((_b = (_a = data.location[score]) === null || _a === void 0 ? void 0 : _a.value) !== null && _b !== void 0 ? _b : "0.0").toFixed(1));
                // #1 For each presented/visible score, +1 to category score
                //  #1a Exclude from count scores with zero value or not-available value
                if (dataKeys.includes(score) &&
                    !isScoreEmpty((_c = data.location[score]) === null || _c === void 0 ? void 0 : _c.value)) {
                    rank += 1;
                }
                // #2 For each presented/visible score with a value above 5, +1 OR
                // #3 Anything above 8, +2 to the category score
                // NOTE: Scores are out of 5. Not out of 10 (we just display out of 10)
                if (scoreValue >= 4) {
                    rank += 2;
                }
                else if (scoreValue >= 2.5) {
                    rank += 1;
                }
            });
            rankedTabs.push(rank);
        });
        const sorted = filteredScores
            .map((category, index) => (Object.assign(Object.assign({}, category), { rank: rankedTabs[index] })))
            .sort((a, b) => b.rank - a.rank)
            .map((category) => ({
            value: category.value,
            scores: category.scores,
        }));
        return sorted;
    }, [data, isLoading, isFetching]);
    return { data: sortedCategories, isLoading, isFetching };
};
export default useRankedCategories;
//# sourceMappingURL=useRankedCategories.js.map