var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { useLocalLogic } from "~/context/LocalLogicProvider";
import { useQuery } from "@tanstack/react-query";
import { useFlags } from "launchdarkly-react-client-sdk";
import { useMemo } from "react";
import { useStateManagerContext } from "~/context/stateManager";
import { poisKeys } from "~/features/pois";
import useDebounce from "~/hooks/useDebounce";
import { scorePois } from "~/sdks/LocalContentDeprecated/constants/score-categories";
import { useLocalContent } from "~/sdks/LocalContentDeprecated/context";
export function usePois(activeScore) {
    var _a;
    const flags = useFlags();
    const { client } = useLocalLogic();
    const { initialLocation } = useLocalContent();
    const { sdkState } = useStateManagerContext();
    const debouncedOptions = useDebounce(sdkState.options, 250);
    const include = activeScore ? scorePois[activeScore] : scorePois.cafes;
    const limit = useMemo(() => {
        if (activeScore === "wellness") {
            return 5;
        }
        return 10;
    }, [include]);
    const location = useMemo(() => {
        const hasMarker = !!(debouncedOptions === null || debouncedOptions === void 0 ? void 0 : debouncedOptions.marker);
        if (hasMarker) {
            return debouncedOptions.marker;
        }
        return {
            lat: initialLocation === null || initialLocation === void 0 ? void 0 : initialLocation.lat,
            lng: initialLocation === null || initialLocation === void 0 ? void 0 : initialLocation.lng,
        };
    }, [debouncedOptions, initialLocation]);
    const options = Object.assign(Object.assign({}, location), { limit, attemptMinimum: flags.lcMinimumPoi ? 3 : undefined, radius: 2000, include });
    return useQuery({
        queryKey: poisKeys.list(options),
        queryFn: () => __awaiter(this, void 0, void 0, function* () { return client.getPois(options); }),
        enabled: !!options && !!((_a = options.include) === null || _a === void 0 ? void 0 : _a.length) && !!options.lat && !!options.lng,
    });
}
//# sourceMappingURL=usePois.js.map