var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { useLocalLogic } from "~/context/LocalLogicProvider";
import { useQuery } from "@tanstack/react-query";
import { useFlags } from "launchdarkly-react-client-sdk";
import { useMemo } from "react";
import { useStateManagerContext } from "~/context/stateManager";
import { schoolsKeys } from "~/features/schools";
import useDebounce from "~/hooks/useDebounce";
import { useLocalContent } from "~/sdks/LocalContentDeprecated/context";
export function useSchools({ radius = 2000, activeScore, }) {
    const flags = useFlags();
    const { client } = useLocalLogic();
    const { initialLocation } = useLocalContent();
    const { sdkState } = useStateManagerContext();
    const debouncedOptions = useDebounce(sdkState.options, 250);
    const isActive = activeScore === "high_schools" || activeScore === "primary_schools";
    const location = useMemo(() => {
        const hasMarker = !!(debouncedOptions === null || debouncedOptions === void 0 ? void 0 : debouncedOptions.marker);
        if (hasMarker) {
            return debouncedOptions.marker;
        }
        return {
            lat: initialLocation === null || initialLocation === void 0 ? void 0 : initialLocation.lat,
            lng: initialLocation === null || initialLocation === void 0 ? void 0 : initialLocation.lng,
        };
    }, [debouncedOptions, initialLocation]);
    const options = Object.assign(Object.assign({}, location), { limit: 10, attemptMinimum: flags.lcMinimumPoi ? 3 : undefined, radius, include_catchments: true });
    return useQuery({
        queryKey: schoolsKeys.list(options),
        queryFn: () => __awaiter(this, void 0, void 0, function* () { return client.getSchools(options); }),
        enabled: !!options && !!options.lat && !!options.lng && isActive,
    });
}
//# sourceMappingURL=useSchools.js.map