var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { useQuery } from "@tanstack/react-query";
import { suggestionKeys, } from "~/features/suggestions";
const MAPBOX_ENDPOINT = "https://api.mapbox.com/search/searchbox/v1/forward?";
const formatSuggestion = (suggestion) => {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r;
    const { properties } = suggestion;
    const { context } = suggestion.properties;
    return {
        label: properties.name,
        language: properties.language,
        countryCode: (_b = (_a = context.country) === null || _a === void 0 ? void 0 : _a.country_code_alpha_3) !== null && _b !== void 0 ? _b : "",
        locationId: properties.mapbox_id,
        address: {
            description: `${properties.name}, ${properties.place_formatted}`,
            country: (_d = (_c = context.country) === null || _c === void 0 ? void 0 : _c.name) !== null && _d !== void 0 ? _d : "",
            state: (_f = (_e = context.region) === null || _e === void 0 ? void 0 : _e.region_code) !== null && _f !== void 0 ? _f : "",
            city: (_h = (_g = context.place) === null || _g === void 0 ? void 0 : _g.name) !== null && _h !== void 0 ? _h : "",
            postalCode: (_k = (_j = context.postcode) === null || _j === void 0 ? void 0 : _j.name) !== null && _k !== void 0 ? _k : "",
            county: (_m = (_l = context.district) === null || _l === void 0 ? void 0 : _l.name) !== null && _m !== void 0 ? _m : "",
            street: (_p = (_o = context.address) === null || _o === void 0 ? void 0 : _o.street_name) !== null && _p !== void 0 ? _p : "",
            houseNumber: (_r = (_q = context.address) === null || _q === void 0 ? void 0 : _q.address_number) !== null && _r !== void 0 ? _r : "",
            coordinates: {
                latitude: properties.coordinates.latitude,
                longitude: properties.coordinates.longitude,
            },
        },
    };
};
const transformSuggestionsResponse = (response) => ({
    suggestions: response.features.map((s) => formatSuggestion(s)),
});
export function useSuggestions({ query, proximity = "", country, }) {
    const options = {
        q: query,
        proximity,
        country,
        access_token: import.meta.env.VITE_MAPBOX_API_KEY,
    };
    const fetchSuggestions = () => __awaiter(this, void 0, void 0, function* () {
        const response = yield fetch(MAPBOX_ENDPOINT + new URLSearchParams(options));
        return transformSuggestionsResponse(yield response.json());
    });
    return useQuery({
        queryKey: suggestionKeys.list(options),
        queryFn: fetchSuggestions,
        enabled: !!query.length && query.length >= 4,
    });
}
//# sourceMappingURL=useSuggestions.js.map