import { number, object, string, mixed, boolean } from "yup";
export const schema = object({
    lat: number()
        .min(-90, "Must be a valid latitude.")
        .max(90, "Must be a valid latitude.")
        .required(),
    lng: number()
        .min(-180, "Must be a valid longitude.")
        .max(180, "Must be a valid longitude.")
        .required(),
    zoom: number().optional(),
    pitch: number().optional(),
    bearing: number().optional(),
    distanceUnit: mixed().oneOf(["metric", "imperial"]).optional(),
    marker: object({
        lat: number()
            .min(-90, "Must be a valid latitude.")
            .max(90, "Must be a valid latitude.")
            .required(),
        lng: number()
            .min(-180, "Must be a valid longitude.")
            .max(180, "Must be a valid longitude.")
            .required(),
        icon: mixed().oneOf(["house", "pin"]).optional(),
        addressLabel: string().optional(),
    }).default(undefined),
    cooperativeGestures: boolean().optional(),
    mapProvider: mixed().optional(),
    hideScores: boolean().optional(),
    collapseScores: boolean().optional(),
}).noUnknown(true);
export const validateOptions = (options) => schema.validate(options, { abortEarly: false });
//# sourceMappingURL=schema.js.map