import React, { useMemo } from "react";
import { useTranslation } from "react-i18next";
import { useDemographics } from "~/sdks/LocalDemographics/context";
import { DemographicsTextCard } from "~/components/DemographicsTextCard";
import * as styles from "../../styles";
export const HomeOwnershipType = () => {
    const { t } = useTranslation("localDemographics");
    const { demographicsState: { property_tenure: propertyTenure, housing_tenancy: housingTenancy, }, } = useDemographics();
    // For the US, the name of the property changes
    const housingInfo = useMemo(() => housingTenancy || propertyTenure, [housingTenancy, propertyTenure]);
    const dataset = useMemo(() => (housingInfo === null || housingInfo === void 0 ? void 0 : housingInfo.variables.map((variable) => ({
        label: variable.label,
        data: Number((variable.value * 100).toFixed(1)),
    }))) || [], [housingInfo === null || housingInfo === void 0 ? void 0 : housingInfo.variables]);
    const chartOptions = useMemo(() => ({
        options: {
            title: t("data.housing.graphs.homeOwnershipType.title"),
            values: dataset.map((item) => ({
                variable: item.label.replace(" ", "_"),
                label: item.label,
                value: `${item.data}%`,
            })),
        },
    }), [dataset]);
    return (React.createElement("div", { className: styles.cardContainer },
        React.createElement(DemographicsTextCard, Object.assign({}, chartOptions))));
};
//# sourceMappingURL=index.js.map