import { useTracking } from "@local-logic/core/tracking";
import React, { useContext, useMemo } from "react";
import useEffectOnce from "~/hooks/useEffectOnce";
import { useStateManagerContext } from "~/context/stateManager";
import { useGeoLocationInfo } from "~/hooks/useGeoLocationInfo";
import { useProfiles } from "~/features/clientLibrary/useProfiles";
import { useScores } from "~/features/clientLibrary/useScores";
import { TrackingPipelineEvents, AnalyticsEvents, } from "./types";
import { includeScores } from "./constants";
const NeighborhoodCharacteristicsContext = React.createContext({});
const useNeighborhoodCharacteristics = () => useContext(NeighborhoodCharacteristicsContext);
const NeighborhoodCharacteristicsProvider = ({ children, }) => {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j;
    const tracking = useTracking();
    const { sdkState } = useStateManagerContext();
    const locale = ((_a = sdkState.globalOptions) === null || _a === void 0 ? void 0 : _a.locale) || "en";
    useEffectOnce(() => {
        tracking.postEvent({
            eventType: TrackingPipelineEvents.SDK_VIEWED,
        });
        tracking.trackAnalyticsEvent({
            eventName: AnalyticsEvents.SDK_VIEWED,
        });
    });
    const { isLoading: isGeoLocationInfoLoading, locationInfo } = useGeoLocationInfo({
        lat: (_b = sdkState.options) === null || _b === void 0 ? void 0 : _b.lat,
        lng: (_c = sdkState.options) === null || _c === void 0 ? void 0 : _c.lng,
        geographyId: (_d = sdkState.options) === null || _d === void 0 ? void 0 : _d.geographyId,
        locale,
    });
    const { data: profilesData, isFetching: isProfilesFetching } = useProfiles({
        location: {
            lat: (_e = locationInfo === null || locationInfo === void 0 ? void 0 : locationInfo.coordinates) === null || _e === void 0 ? void 0 : _e.lat,
            lng: (_f = locationInfo === null || locationInfo === void 0 ? void 0 : locationInfo.coordinates) === null || _f === void 0 ? void 0 : _f.lng,
        },
        geogID: locationInfo === null || locationInfo === void 0 ? void 0 : locationInfo.geogID,
        externalId: (_g = sdkState.globalOptions) === null || _g === void 0 ? void 0 : _g.externalId,
    });
    const { data: scoresData, isFetching: isScoresFetching } = useScores({
        location: {
            lat: (_h = locationInfo === null || locationInfo === void 0 ? void 0 : locationInfo.coordinates) === null || _h === void 0 ? void 0 : _h.lat,
            lng: (_j = locationInfo === null || locationInfo === void 0 ? void 0 : locationInfo.coordinates) === null || _j === void 0 ? void 0 : _j.lng,
        },
        geographyId: locationInfo === null || locationInfo === void 0 ? void 0 : locationInfo.geogID,
        include: includeScores,
    });
    const isLoading = useMemo(() => isGeoLocationInfoLoading || isProfilesFetching || isScoresFetching, [isGeoLocationInfoLoading, isProfilesFetching, isScoresFetching]);
    const contextValue = useMemo(() => {
        var _a;
        return ({
            isLoading,
            locationInfo,
            profilesData,
            scores: (_a = scoresData === null || scoresData === void 0 ? void 0 : scoresData.geographies[0]) === null || _a === void 0 ? void 0 : _a.scores,
        });
    }, [isLoading, locationInfo, profilesData, scoresData]);
    return (React.createElement(NeighborhoodCharacteristicsContext.Provider, { value: contextValue }, children));
};
export { useNeighborhoodCharacteristics, NeighborhoodCharacteristicsProvider };
//# sourceMappingURL=context.js.map