import React, { useMemo } from "react";
import { useTranslation } from "react-i18next";
import { useNeighborhoodDemographics } from "~/sdks/NeighborhoodDemographics/context";
import { DonutChart } from "@local-logic/core/ui";
import { Path as PathIcon } from "@phosphor-icons/react";
import * as styles from "../../styles";
export const CommuteMode = () => {
    const { t } = useTranslation("neighborhoodDemographics");
    const { demographicsData: { commute_mode: commuteMode }, } = useNeighborhoodDemographics();
    const commuteFormatted = useMemo(() => commuteMode === null || commuteMode === void 0 ? void 0 : commuteMode.variables.map((variable) => (Object.assign(Object.assign({}, variable), { value: Number((variable.value * 100).toFixed(1)) }))).filter((variable) => (!variable.type || variable.type === "percent") &&
        Number((variable.value * 100).toFixed(1)) > 0), [commuteMode === null || commuteMode === void 0 ? void 0 : commuteMode.variables]);
    const dataset = useMemo(() => ({
        labels: (commuteFormatted === null || commuteFormatted === void 0 ? void 0 : commuteFormatted.map((variable) => `${variable.value}% ${variable.label}`)) || [],
        data: (commuteFormatted === null || commuteFormatted === void 0 ? void 0 : commuteFormatted.map((variable) => variable.value)) || [],
    }), [commuteFormatted]);
    const chartOptions = useMemo(() => ({
        title: t("data.commute.graphs.commuteMode.title"),
        labels: dataset.labels,
        data: dataset.data,
        icon: React.createElement(PathIcon, { className: styles.donutChartIcon }),
    }), [dataset]);
    return React.createElement(DonutChart, Object.assign({}, chartOptions));
};
//# sourceMappingURL=index.js.map