import React, { useMemo } from "react";
import { useTranslation } from "react-i18next";
import { useNeighborhoodDemographics } from "~/sdks/NeighborhoodDemographics/context";
import { Chart } from "@local-logic/core/ui";
export const TypeOfHousing = () => {
    const { t } = useTranslation("neighborhoodDemographics");
    const { demographicsData: { housing_type: housingType }, } = useNeighborhoodDemographics();
    const dataset = useMemo(() => {
        const variables = housingType === null || housingType === void 0 ? void 0 : housingType.variables.filter((variable) => !variable.type || variable.type === "percent");
        return {
            labels: (variables === null || variables === void 0 ? void 0 : variables.map((variable) => variable.label)) || [],
            data: (variables === null || variables === void 0 ? void 0 : variables.map((variable) => Number((variable.value * 100).toFixed(1)))) || [],
        };
    }, [housingType === null || housingType === void 0 ? void 0 : housingType.variables]);
    const chartOptions = useMemo(() => ({
        title: t("data.housing.graphs.typeOfHousing.title"),
        labels: dataset.labels,
        data: dataset.data,
        unit: "%",
    }), [dataset]);
    return (React.createElement(Chart.Root, Object.assign({}, chartOptions),
        React.createElement(Chart.BarChart, null)));
};
//# sourceMappingURL=index.js.map