import React, { useMemo } from "react";
import { useTranslation } from "react-i18next";
import { useNeighborhoodDemographics } from "~/sdks/NeighborhoodDemographics/context";
import { DonutChart } from "@local-logic/core/ui";
import { Translate as TranslateIcon } from "@phosphor-icons/react";
import * as styles from "../../styles";
export const SpokenLanguages = () => {
    const { t } = useTranslation("neighborhoodDemographics");
    const { demographicsData: { official_language_knowledge: oficialLanguages }, } = useNeighborhoodDemographics();
    const oficialLanguagesFormatted = useMemo(() => oficialLanguages === null || oficialLanguages === void 0 ? void 0 : oficialLanguages.variables.map((variable) => (Object.assign(Object.assign({}, variable), { value: Number((variable.value * 100).toFixed(1)) }))).filter((variable) => (!variable.type || variable.type === "percent") &&
        Number((variable.value * 100).toFixed(1)) > 0), [oficialLanguages === null || oficialLanguages === void 0 ? void 0 : oficialLanguages.variables]);
    const dataset = useMemo(() => ({
        labels: (oficialLanguagesFormatted === null || oficialLanguagesFormatted === void 0 ? void 0 : oficialLanguagesFormatted.map((variable) => `${variable.value}% ${variable.label}`)) || [],
        data: (oficialLanguagesFormatted === null || oficialLanguagesFormatted === void 0 ? void 0 : oficialLanguagesFormatted.map((variable) => variable.value)) || [],
    }), [oficialLanguagesFormatted]);
    const chartOptions = useMemo(() => ({
        title: t("data.languages.graphs.spokenLanguages.title"),
        labels: dataset.labels,
        data: dataset.data,
        icon: React.createElement(TranslateIcon, { className: styles.donutChartIcon }),
    }), [dataset]);
    return React.createElement(DonutChart, Object.assign({}, chartOptions));
};
//# sourceMappingURL=index.js.map