import React, { useContext } from "react";
import { useTracking } from "@local-logic/core/tracking";
import useEffectOnce from "~/hooks/useEffectOnce";
import { useGeoLocationInfo } from "~/hooks/useGeoLocationInfo";
import { useLocation } from "~/hooks/useLocation";
import { useStateManagerContext } from "~/context/stateManager";
import { useDemographicsData } from "~/hooks/useDemographicsData";
import { TrackingPipelineEvents, AnalyticsEvents, } from "./types";
const NeighborhoodDemographicsContext = React.createContext({});
const useNeighborhoodDemographics = () => useContext(NeighborhoodDemographicsContext);
const NeighborhoodDemographicsProvider = ({ children, }) => {
    var _a, _b, _c, _d, _e, _f, _g, _h;
    const { sdkState } = useStateManagerContext();
    const locale = ((_a = sdkState.globalOptions) === null || _a === void 0 ? void 0 : _a.locale) || "en";
    const tracking = useTracking();
    useEffectOnce(() => {
        tracking.postEvent({
            eventType: TrackingPipelineEvents.SDK_VIEWED,
        });
        tracking.trackAnalyticsEvent({
            eventName: AnalyticsEvents.SDK_VIEWED,
        });
    });
    const { isLoading: isGeoLocationInfoLoading, locationInfo } = useGeoLocationInfo({
        lat: (_b = sdkState.options) === null || _b === void 0 ? void 0 : _b.lat,
        lng: (_c = sdkState.options) === null || _c === void 0 ? void 0 : _c.lng,
        geographyId: (_d = sdkState.options) === null || _d === void 0 ? void 0 : _d.geographyId,
        locale,
    });
    const { data: { country }, } = useLocation({
        lat: (_e = locationInfo === null || locationInfo === void 0 ? void 0 : locationInfo.coordinates) === null || _e === void 0 ? void 0 : _e.lat,
        lng: (_f = locationInfo === null || locationInfo === void 0 ? void 0 : locationInfo.coordinates) === null || _f === void 0 ? void 0 : _f.lng,
    });
    const { data: demographicsData, isFetching: isDemographicsFetching } = useDemographicsData({
        // If geogID is defined, the lat/lng will be ignored
        geographyId: locationInfo === null || locationInfo === void 0 ? void 0 : locationInfo.geogID,
        lat: (_g = locationInfo === null || locationInfo === void 0 ? void 0 : locationInfo.coordinates) === null || _g === void 0 ? void 0 : _g.lat,
        lng: (_h = locationInfo === null || locationInfo === void 0 ? void 0 : locationInfo.coordinates) === null || _h === void 0 ? void 0 : _h.lng,
    });
    return (React.createElement(NeighborhoodDemographicsContext.Provider, { value: {
            isLoading: isGeoLocationInfoLoading || isDemographicsFetching,
            demographicsData: demographicsData || {},
            country: country || "CA",
        } }, children));
};
export { useNeighborhoodDemographics, NeighborhoodDemographicsProvider };
//# sourceMappingURL=context.js.map