import React, { useMemo } from "react";
import { useNeighborhoodHighlights } from "~/sdks/NeighborhoodHighlights/context";
import { useTranslation } from "react-i18next";
import { LoadingSpinner } from "@local-logic/core/ui";
import { includeScores } from "~/sdks/NeighborhoodHighlights/constants";
import { NoDataContent } from "~/components/NoDataContent";
import * as Highlights from "../Highlights";
import * as styles from "./styles";
export function Content() {
    const { t } = useTranslation("neighborhoodHighlights");
    const { isLoading, scores } = useNeighborhoodHighlights();
    const highlights = useMemo(() => {
        if (isLoading) {
            return [];
        }
        const highlightKeys = [];
        if (scores) {
            const filteredScores = includeScores
                .map((scoreName) => {
                var _a;
                return ({
                    scoreName,
                    value: (Math.round(Number((_a = scores[scoreName]) === null || _a === void 0 ? void 0 : _a.value) * 10) / 10) * 2,
                });
            })
                .filter((score) => score.value > 7)
                .sort((a, b) => (a.value < b.value ? 1 : -1))
                .slice(0, 3);
            filteredScores.map((item) => highlightKeys.push(item.scoreName));
        }
        return highlightKeys;
    }, [scores, isLoading]);
    if (isLoading) {
        return (React.createElement("div", { className: styles.loadingContent },
            React.createElement(LoadingSpinner, { image: true })));
    }
    return (React.createElement(React.Fragment, null, highlights.length > 0 ? (React.createElement(Highlights.Root, null, highlights.map((highlight) => (React.createElement("div", { key: `highlight-${highlight}`, className: styles.highlight },
        React.createElement(Highlights.Item, { score: highlight })))))) : (React.createElement(NoDataContent, { text: t("noData") }))));
}
//# sourceMappingURL=index.js.map