import React, { useContext, useMemo } from "react";
import { useTracking } from "@local-logic/core/tracking";
import { useStateManagerContext } from "~/context/stateManager";
import { useScores } from "~/features/clientLibrary/useScores";
import useEffectOnce from "~/hooks/useEffectOnce";
import { TrackingPipelineEvents, AnalyticsEvents, } from "./types";
import { includeScores } from "./constants";
const NeighborhoodHighlightsContext = React.createContext({});
const useNeighborhoodHighlights = () => useContext(NeighborhoodHighlightsContext);
const NeighborhoodHighlightsProvider = ({ children, }) => {
    var _a, _b, _c;
    const { sdkState } = useStateManagerContext();
    const tracking = useTracking();
    useEffectOnce(() => {
        tracking.postEvent({
            eventType: TrackingPipelineEvents.SDK_VIEWED,
        });
        tracking.trackAnalyticsEvent({
            eventName: AnalyticsEvents.SDK_VIEWED,
        });
    });
    const { data: scoresData, isFetching: isScoresFetching } = useScores({
        location: {
            lat: (_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.lat,
            lng: (_b = sdkState.options) === null || _b === void 0 ? void 0 : _b.lng,
        },
        geographyId: (_c = sdkState.options) === null || _c === void 0 ? void 0 : _c.geographyId,
        include: includeScores,
    });
    const isLoading = useMemo(() => isScoresFetching, [isScoresFetching]);
    const contextValue = useMemo(() => {
        var _a, _b;
        return ({
            isLoading,
            scores: ((_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.geographyId)
                ? (_b = scoresData === null || scoresData === void 0 ? void 0 : scoresData.geographies[0]) === null || _b === void 0 ? void 0 : _b.scores
                : scoresData === null || scoresData === void 0 ? void 0 : scoresData.location,
        });
    }, [isLoading, scoresData]);
    return (React.createElement(NeighborhoodHighlightsContext.Provider, { value: contextValue }, children));
};
export { useNeighborhoodHighlights, NeighborhoodHighlightsProvider };
//# sourceMappingURL=context.js.map