import React from "react";
import { useTranslation } from "react-i18next";
import * as RadixDialog from "@radix-ui/react-dialog";
import { XCircle as XCircleIcon } from "@phosphor-icons/react";
import { useRootElement } from "../context";
import * as styles from "./styles";
export const Dialog = ({ onReset, onApply, children, }) => {
    const { t } = useTranslation("neighborhoodMap");
    const { isFiltersDialogOpen, setIsFiltersDialogOpen } = useRootElement();
    const handleOnReset = () => {
        onReset();
        setIsFiltersDialogOpen(false);
    };
    const handleOnApply = () => {
        onApply();
        setIsFiltersDialogOpen(false);
    };
    const handleCloseDialog = () => {
        setIsFiltersDialogOpen(false);
    };
    return (React.createElement(RadixDialog.Root, { open: isFiltersDialogOpen },
        React.createElement(RadixDialog.Portal, null,
            React.createElement(RadixDialog.Overlay, { className: styles.overlay }),
            React.createElement(RadixDialog.Content, { className: styles.content },
                React.createElement(RadixDialog.Title, { className: styles.title }, t("filters.popup.title")),
                React.createElement(RadixDialog.Close, { className: styles.close, onClick: handleCloseDialog },
                    React.createElement(XCircleIcon, { className: styles.closeIcon })),
                React.createElement("div", { className: styles.filters },
                    React.createElement(RadixDialog.Description, { className: styles.description }, t("filters.popup.description")),
                    React.createElement("div", { className: styles.filterList }, children),
                    React.createElement("div", { className: styles.footer },
                        React.createElement("button", { className: styles.resetButton, onClick: handleOnReset }, t("filters.popup.cta.reset")),
                        React.createElement("button", { className: styles.saveButton, onClick: handleOnApply }, t("filters.popup.cta.apply"))))))));
};
//# sourceMappingURL=index.js.map