// https://visgl.github.io/react-map-gl/
import React, { useEffect, useState, useRef } from "react";
import Map, { NavigationControl, Source, Layer, } from "react-map-gl/maplibre";
import { bbox, multiPoint, point } from "@turf/turf";
import errorTracker from "~/utils/errorTracker";
import { useRootElement } from "../../context";
const maptilerThemes = {
    day: "d140f7e5-abd5-4020-b713-f281d7b1f57d",
    night: "a6156f3f-46f3-4143-b90a-3f80eed1b2c8",
};
/**
 * TODO remove Type of POI logic from the map component. This map component
 * should not care about Local Logic data. Its purpose is to be generic and show "Markers".
 */
export const MapGL = ({ bounds, children }) => {
    const { theme = "day", lat, lng, zoom, cooperativeGestures, geometries, } = useRootElement();
    const [isMapLoaded, setIsMapLoaded] = useState(false);
    const [center, setCenter] = useState({ lat, lng });
    const mapRef = useRef(null);
    useEffect(() => {
        var _a;
        if (!isMapLoaded || !lat || !lng)
            return;
        if (lat === center.lat && lng === center.lng)
            return;
        errorTracker.addBreadCrumb("MapGL", "Centering map", { lat, lng });
        (_a = mapRef === null || mapRef === void 0 ? void 0 : mapRef.current) === null || _a === void 0 ? void 0 : _a.setCenter({ lng, lat });
        setCenter({ lng, lat });
    }, [isMapLoaded, lat, lng]);
    useEffect(() => {
        var _a;
        if (!isMapLoaded)
            return;
        let mapBounds;
        const neighborhood = geometries === null || geometries === void 0 ? void 0 : geometries.find((geometry) => geometry.key === "neighborhood");
        if (bounds && bounds.length > 0) {
            const points = bounds
                .map((bound) => point([bound.lat, bound.lng]))
                .flat();
            const multiPointBounds = multiPoint(points.map(({ geometry: poiGeometry }) => [
                poiGeometry.coordinates[1],
                poiGeometry.coordinates[0],
            ]));
            const [minLat, minLng, maxLat, maxLng] = bbox(multiPointBounds);
            mapBounds = [
                [minLat, minLng],
                [maxLat, maxLng],
            ];
        }
        else if (neighborhood === null || neighborhood === void 0 ? void 0 : neighborhood.geoJson) {
            const [minLat, minLng, maxLat, maxLng] = bbox(neighborhood.geoJson);
            mapBounds = [
                [minLat, minLng],
                [maxLat, maxLng],
            ];
        }
        // @ts-expect-error mapBounds is not initialized
        if (!mapBounds) {
            return;
        }
        errorTracker.addBreadCrumb("MapGL", "Setting map bounds");
        (_a = mapRef === null || mapRef === void 0 ? void 0 : mapRef.current) === null || _a === void 0 ? void 0 : _a.fitBounds(mapBounds, {
            duration: 1000,
            padding: 100,
            maxZoom: zoom,
        });
    }, [isMapLoaded, geometries, bounds]);
    const handleOnLoad = () => {
        errorTracker.addBreadCrumb("MapGL", "handleOnLoad");
        setIsMapLoaded(true);
    };
    const handleOnError = (error) => {
        errorTracker.addBreadCrumb("MapGL", "handleOnError", {
            error,
        });
    };
    return (React.createElement(Map, { ref: mapRef, initialViewState: {
            latitude: center.lat,
            longitude: center.lng,
            zoom,
        }, attributionControl: false, cooperativeGestures: cooperativeGestures, mapStyle: `https://api.maptiler.com/maps/${maptilerThemes[theme]}/style.json?key=${import.meta.env.VITE_MAPTILER_KEY}`, onRender: handleOnLoad, onError: handleOnError }, geometries === null || geometries === void 0 ? void 0 :
        geometries.map((geometry) => (React.createElement("div", { key: geometry.key }, geometry.geoJson && (React.createElement(Source, { key: geometry.key, type: "geojson", data: geometry.geoJson },
            React.createElement(Layer, { type: "fill",
                paint: {
                    "fill-color": geometry.color,
                    "fill-opacity": 0.25,
                } }),
            React.createElement(Layer, { type: "line",
                paint: {
                    "line-color": geometry.color,
                    "line-width": 2,
                } })))))),
        React.createElement(NavigationControl, { position: "bottom-right" }),
        children));
};
export default MapGL;
//# sourceMappingURL=index.js.map