import React, { useMemo } from "react";
import { Marker } from "react-map-gl/maplibre";
import errorTracker from "~/utils/errorTracker";
import { Record as RecordIcon } from "@phosphor-icons/react";
import * as styles from "../styles";
export const MapGLMarker = ({ lat, lng, icon, onClick }) => {
    /**
     * We need to cache the icon because changes in markers are not immediate. If we don't,
     * then the new icon will briefly display on the old markers until the new markers are
     * populated.
     */
    const MarkerIcon = useMemo(() => (typeof icon !== "undefined" ? icon : RecordIcon), []);
    const handleOpenPopup = () => {
        if (!onClick) {
            return;
        }
        errorTracker.addBreadCrumb("MapGLMarker", "handleOpenPopup", { lat, lng });
        onClick();
    };
    return (React.createElement(Marker, { latitude: lat, longitude: lng, anchor: "bottom", onClick: (e) => {
            e.originalEvent.stopPropagation();
            handleOpenPopup();
        } },
        React.createElement("div", { className: styles.container },
            React.createElement(MarkerIcon, { className: styles.icon }),
            React.createElement("svg", { width: "20", height: "28", viewBox: "0 0 20 28", fill: "none", className: styles.background },
                React.createElement("path", { d: "M20 10C20 15.5228 12 27.5 10 27.5C8 27.5 0 15.5228 0 10C0 4.47715 4.47715 0 10 0C15.5228 0 20 4.47715 20 10Z", fill: "inherit" })))));
};
//# sourceMappingURL=index.js.map