import React, { useMemo } from "react";
import { useTranslation } from "react-i18next";
import { Popup } from "react-map-gl/maplibre";
import { Record as RecordIcon } from "@phosphor-icons/react";
import { primitiveUtils } from "@local-logic/core/utils";
import * as styles from "../styles";
import "./popup.css";
export const MapGLPopup = ({ marker, icon, onClose, onLinkClick, }) => {
    var _a;
    const { t } = useTranslation(["common"]);
    const Icon = useMemo(() => (typeof icon !== "undefined" ? icon : RecordIcon), [icon]);
    if (!marker) {
        return null;
    }
    const formatAttribute = (attribute) => {
        if (!attribute)
            return undefined;
        if (typeof attribute === "string") {
            return attribute;
        }
        const upperAtt = attribute.map((value) => primitiveUtils.string.capitalize(value));
        return upperAtt.join(", ");
    };
    const handleOnLinkClick = (url) => () => {
        if (typeof onLinkClick !== "undefined") {
            onLinkClick(url);
        }
    };
    return (React.createElement(Popup, { anchor: "left", latitude: marker.lat, longitude: marker.lng, closeButton: false, closeOnClick: true, onClose: onClose, className: "maplibre-popup" },
        React.createElement("div", { className: styles.container },
            React.createElement("span", { className: styles.iconContainer },
                React.createElement(Icon, { className: styles.icon })),
            marker.url ? (React.createElement("a", { className: styles.title, "data-has-url": marker.url !== undefined, href: marker.url, onClick: handleOnLinkClick(marker.url), target: "_blank", rel: "noreferrer" }, marker.name)) : (React.createElement("h3", { className: styles.title }, marker.name)),
            React.createElement("p", { className: styles.description }, marker.address),
            Object.hasOwn(marker, "school_attributes") && (React.createElement("div", null, Object.entries(marker.school_attributes || {}).map(([key, schoolAttribute]) => (React.createElement("p", { className: styles.schoolAttributeInfo, key: key }, `${t(`common:map.marker.schoolAttributes.${key}`)}: ${formatAttribute(schoolAttribute)}`))))),
            "school_board_attributes" in marker &&
                ((_a = marker.school_board_attributes) === null || _a === void 0 ? void 0 : _a.name) && (React.createElement("p", null, `${t(`common:map.marker.district`)}: ${marker.school_board_attributes.name}`)))));
};
//# sourceMappingURL=index.js.map