import React, { useState, useEffect, useMemo, useRef } from "react";
import { useStateManagerContext } from "~/context/stateManager";
import { useTranslation } from "react-i18next";
import { CaretDown as CaretDownIcon } from "@phosphor-icons/react";
import { useNeighborhoodMap } from "~/sdks/NeighborhoodMap/context";
import { radiusOptions } from "~/sdks/NeighborhoodMap/constants";
import * as styles from "./styles";
export const RadiusDropdown = () => {
    var _a, _b;
    const { t } = useTranslation(["neighborhoodMap", "common"]);
    const ref = useRef(null);
    const { sdkState } = useStateManagerContext();
    const { activePoiCategory, radius, onRadiusChange } = useNeighborhoodMap();
    const [isOpen, setIsOpen] = useState(false);
    useEffect(() => {
        const handleClickOutside = (event) => {
            if (ref.current && !ref.current.contains(event.target)) {
                setIsOpen(false);
            }
        };
        // Bind the event listener
        document.addEventListener("mousedown", handleClickOutside);
        return () => {
            // Unbind the event listener on clean up
            document.removeEventListener("mousedown", handleClickOutside);
        };
    }, [ref]);
    const options = useMemo(() => { var _a; return radiusOptions[((_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.distanceUnit) || "metric"]; }, [(_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.distanceUnit]);
    const distanceUnit = useMemo(() => {
        var _a;
        return t(`common:distance.${((_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.distanceUnit) === "metric" ? "kilometer" : "mile"}`);
    }, [(_b = sdkState.options) === null || _b === void 0 ? void 0 : _b.distanceUnit]);
    const handleOnOpenChange = (newIsOpen) => {
        setIsOpen(newIsOpen);
    };
    const handleOnSelect = (option) => () => {
        onRadiusChange(option);
        setIsOpen(false);
    };
    if (!activePoiCategory || radius === undefined || !sdkState.options) {
        return null; // Don't render if no category is selected or other conditions are not met
    }
    return (React.createElement("div", { ref: ref },
        React.createElement("button", { className: styles.trigger, onClick: () => handleOnOpenChange(!isOpen) },
            t("filters.radius.title"),
            "\u00A0",
            React.createElement("span", { className: styles.highlight }, t("filters.radius.value", { value: radius, unit: distanceUnit })),
            React.createElement(CaretDownIcon, { className: styles.icon, "data-is-open": isOpen })),
        isOpen && (React.createElement("div", { className: styles.content }, options.map((radiusOption) => (React.createElement("div", { key: `radius-option-${radiusOption}`, onClick: handleOnSelect(radiusOption), className: styles.option }, `${radiusOption} ${distanceUnit}`)))))));
};
//# sourceMappingURL=index.js.map