import React, { useMemo } from "react";
import "~/assets/styles/old-tailwind.css";
import "~/sdks/NeighborhoodMap/styles.css";
import { TrackingProvider, initializeAnalytics, } from "@local-logic/core/tracking";
import { ValidateOptions } from "~/components/ValidateOptions";
import { LocalLogicProvider } from "~/context/LocalLogicProvider";
import { useStateManagerContext } from "~/context/stateManager";
import useIsMobile from "~/hooks/useIsMobile";
import { ProductNames } from "~/types";
import { ANALYTICS_SETTINGS } from "~/constants/analytics";
import { mapUtils } from "@local-logic/core/utils";
import { Content } from "./components/Content";
import { Footer } from "./components/Footer";
import { NeighborhoodMapProvider } from "./context";
import { schema } from "./schema";
import * as styles from "./styles";
initializeAnalytics(ANALYTICS_SETTINGS.neighborhoodWrap.key);
const NeighborhoodMap = () => {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j;
    const { sdkState } = useStateManagerContext();
    const isMobile = useIsMobile();
    const locale = ((_a = sdkState.globalOptions) === null || _a === void 0 ? void 0 : _a.locale) || "en";
    const clientId = useMemo(() => {
        var _a, _b;
        const clientKey = (_b = (_a = sdkState.apiKey) === null || _a === void 0 ? void 0 : _a.split(".")) !== null && _b !== void 0 ? _b : "";
        return clientKey[0].slice(3);
    }, [sdkState.apiKey]);
    const location = useMemo(() => {
        var _a, _b, _c, _d, _e;
        if ((_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.geographyId) {
            return Object.assign(Object.assign({}, mapUtils.decodeGeogId((_b = sdkState.options) === null || _b === void 0 ? void 0 : _b.geographyId)), { geographyId: (_c = sdkState.options) === null || _c === void 0 ? void 0 : _c.geographyId });
        }
        return {
            lat: (_d = sdkState.options) === null || _d === void 0 ? void 0 : _d.lat,
            lng: (_e = sdkState.options) === null || _e === void 0 ? void 0 : _e.lng,
        };
    }, [
        (_b = sdkState.options) === null || _b === void 0 ? void 0 : _b.lat,
        (_c = sdkState.options) === null || _c === void 0 ? void 0 : _c.lng,
        (_d = sdkState.options) === null || _d === void 0 ? void 0 : _d.geographyId,
    ]);
    return (React.createElement(ValidateOptions, { sdk: "Neighborhood Map", schema: schema, options: sdkState.options },
        React.createElement(LocalLogicProvider, { environment: (_f = (_e = sdkState.globalOptions) === null || _e === void 0 ? void 0 : _e.environment) === null || _f === void 0 ? void 0 : _f.api, apiKey: sdkState.apiKey, appearance: (_g = sdkState.globalOptions) === null || _g === void 0 ? void 0 : _g.appearance, locale: (_h = sdkState.globalOptions) === null || _h === void 0 ? void 0 : _h.locale, product: ProductNames.NEIGHBORHOOD_MAP },
            React.createElement(TrackingProvider, { trackingPipelineSettings: {
                    apiKey: sdkState.apiKey || "",
                }, analyticsSettings: ANALYTICS_SETTINGS.neighborhoodWrap, meta: {
                    clientId,
                    productName: ProductNames.NEIGHBORHOOD_MAP,
                    productVersion: FULL_APP_VERSION,
                }, attributes: {
                    location,
                    host_url: document.referrer,
                    locale,
                    isMobile,
                }, flags: {
                    isDebugMode: import.meta.env.VITE_TRACKING_PIPELINE_DEBUG === "true",
                } },
                React.createElement(NeighborhoodMapProvider, null,
                    React.createElement("div", { className: styles.container },
                        React.createElement(Content, null),
                        !((_j = sdkState.options) === null || _j === void 0 ? void 0 : _j.hideAttribution) && React.createElement(Footer, null)))))));
};
export default NeighborhoodMap;
//# sourceMappingURL=index.js.map