import React, { useMemo } from "react";
import { GridGraph } from "~/components/Graphs/GridGraph";
import { useNeighborhoodMarketTrends } from "~/sdks/NeighborhoodMarketTrends/context";
import { useRootElement } from "../context";
export const ActiveListings = ({ yAxisTitle, isIncrease, }) => {
    const { isLoading, marketActivity } = useNeighborhoodMarketTrends();
    const { increaseColor, decreaseColor } = useRootElement();
    const intervals = useMemo(() => {
        var _a;
        if (isLoading || !marketActivity) {
            return [];
        }
        const filteredIntervals = Object.entries((_a = marketActivity.market_activity_by_property_type) === null || _a === void 0 ? void 0 : _a.all_residential_properties.intervals).filter(([key]) => key.match(/^\d{4}-\d{2}$/));
        return filteredIntervals;
    }, [marketActivity, isLoading]);
    const series = useMemo(() => {
        if (intervals.length < 1)
            return [];
        return intervals
            .map(([_, value]) => { var _a, _b, _c; return (_c = (_b = (_a = value.market_activity) === null || _a === void 0 ? void 0 : _a.stats_at_period_end) === null || _b === void 0 ? void 0 : _b.active_listings_count) !== null && _c !== void 0 ? _c : 0; })
            .reverse();
    }, [intervals]);
    const categories = useMemo(() => {
        if (!intervals)
            return [];
        return intervals.map(([key, _]) => key).reverse();
    }, [intervals]);
    const roundedMaxListingCount = useMemo(() => {
        const maxListingCount = Math.max(...series);
        const minListingCount = Math.min(...series);
        return (Math.ceil((maxListingCount + 0.2 * (maxListingCount - minListingCount)) / 100) * 100);
    }, [series]);
    if (!marketActivity) {
        return null;
    }
    return (React.createElement("div", null,
        React.createElement(GridGraph, { series: [
                {
                    name: "Active Listings",
                    data: series,
                },
            ], categories: categories, type: "homes", yaxis: {
                title: {
                    text: yAxisTitle,
                },
                max: roundedMaxListingCount,
            }, markerColor: isIncrease ? increaseColor : decreaseColor })));
};
//# sourceMappingURL=index.js.map