import React, { useContext, useMemo } from "react";
import { useTracking } from "@local-logic/core/tracking";
import useEffectOnce from "~/hooks/useEffectOnce";
import { useStateManagerContext } from "~/context/stateManager";
import { useGeoLocationInfo } from "~/hooks/useGeoLocationInfo";
import { useMarketActivity } from "~/features/clientLibrary/useMarketActivity";
import { TrackingPipelineEvents, AnalyticsEvents, } from "./types";
const NeighborhoodMarketTrendsContext = React.createContext({});
const useNeighborhoodMarketTrends = () => useContext(NeighborhoodMarketTrendsContext);
const NeighborhoodMarketTrendsProvider = ({ children, }) => {
    var _a, _b, _c, _d;
    const { sdkState } = useStateManagerContext();
    const locale = ((_a = sdkState.globalOptions) === null || _a === void 0 ? void 0 : _a.locale) || "en";
    const tracking = useTracking();
    const pastTwelveMonths = useMemo(() => {
        const months = [];
        const currentDate = new Date();
        // Loop through the past 12 months
        for (let index = 0; index <= 12; index += 1) {
            const year = currentDate.getFullYear();
            const month = currentDate.getMonth(); // 0-based, January is 0, December is 11
            // Format the month as yyyy-mm
            const formattedDate = `${year}-${String(month + 1).padStart(2, "0")}`;
            months.push(formattedDate);
            // Decrement the month
            currentDate.setMonth(currentDate.getMonth() - 1);
        }
        return months.reverse(); //
    }, []);
    useEffectOnce(() => {
        tracking.postEvent({
            eventType: TrackingPipelineEvents.SDK_VIEWED,
        });
        tracking.trackAnalyticsEvent({
            eventName: AnalyticsEvents.SDK_VIEWED,
        });
    });
    const { isLoading: isGeoLocationInfoLoading, locationInfo } = useGeoLocationInfo({
        lat: (_b = sdkState.options) === null || _b === void 0 ? void 0 : _b.lat,
        lng: (_c = sdkState.options) === null || _c === void 0 ? void 0 : _c.lng,
        geographyId: (_d = sdkState.options) === null || _d === void 0 ? void 0 : _d.geographyId,
        locale,
    });
    const { data: marketActivity, isFetching: isMarketActivityFetching } = useMarketActivity({
        geogID: locationInfo === null || locationInfo === void 0 ? void 0 : locationInfo.geogID,
        propertyTypes: ["all_residential_properties"],
        intervals: ["30d", "31-60d", "12m", "13-24m", ...pastTwelveMonths],
    });
    const isLoading = useMemo(() => isGeoLocationInfoLoading || isMarketActivityFetching, [isGeoLocationInfoLoading, isMarketActivityFetching]);
    const contextValue = useMemo(() => {
        var _a;
        return ({
            isLoading,
            marketActivity: marketActivity !== null && marketActivity !== void 0 ? marketActivity : null,
            appearance: (_a = sdkState === null || sdkState === void 0 ? void 0 : sdkState.options) === null || _a === void 0 ? void 0 : _a.appearance,
        });
    }, [marketActivity, isLoading]);
    return (React.createElement(NeighborhoodMarketTrendsContext.Provider, { value: contextValue }, children));
};
export { useNeighborhoodMarketTrends, NeighborhoodMarketTrendsProvider };
//# sourceMappingURL=context.js.map