import React, { useMemo } from "react";
import { useTranslation } from "react-i18next";
import { useTracking } from "@local-logic/core/tracking";
import { useNeighborhoodMatch } from "~/sdks/NeighborhoodMatch/context";
import { TrackingPipelineEvents, AnalyticsEvents, } from "~/sdks/NeighborhoodMatch/types";
import { NoDataContent } from "~/components/NoDataContent";
import { LoadingSpinner } from "@local-logic/core/ui";
import * as ScoreCardList from "~/components/ScoreCardList";
import { Description } from "../Description";
import { PaginationButton } from "../PaginationButton";
import * as CardList from "../CardList";
import * as styles from "./styles";
const affordabilityToTag = {
    lessAffordable: "negative",
    comparable: "neutral",
    moreAffordable: "positive",
};
export function Content() {
    const { t } = useTranslation(["neighborhoodMatch", "common"]);
    const tracking = useTracking();
    const { isLoading, isFetched, similarNeighborhoods, locationInfo, hideAffordabilityTags, } = useNeighborhoodMatch();
    const affordabilityIndexPresentInNeighborhood = useMemo(() => similarNeighborhoods === null || similarNeighborhoods === void 0 ? void 0 : similarNeighborhoods.some((neighborhood) => typeof (neighborhood === null || neighborhood === void 0 ? void 0 : neighborhood.affordabilityComparison) !== "undefined"), [similarNeighborhoods]);
    const handleCardClickEvent = (position) => () => {
        tracking.postEvent({
            eventType: TrackingPipelineEvents.NEIGHBORHOOD_CARD_CLICKED,
            eventAttributes: [
                {
                    label: "position_in_set",
                    data: position,
                },
            ],
        });
        tracking.trackAnalyticsEvent({
            eventName: AnalyticsEvents.NEIGHBORHOOD_CARD_CLICKED,
            eventAttributes: {
                ll_position_in_set: position,
            },
        });
    };
    return (React.createElement(React.Fragment, null,
        !isFetched && isLoading && (React.createElement("div", { className: styles.loadingContent },
            React.createElement(LoadingSpinner, { image: true }))),
        isFetched && similarNeighborhoods.length === 0 && (React.createElement(NoDataContent, { text: t("noData") })),
        isFetched && similarNeighborhoods.length > 0 && (React.createElement(React.Fragment, null,
            React.createElement(Description, { neighborhoodName: locationInfo === null || locationInfo === void 0 ? void 0 : locationInfo.microLocation }),
            React.createElement("div", { className: styles.descriptionSpacer }),
            React.createElement(CardList.Root, null, similarNeighborhoods.map((neighborhood, index) => (React.createElement(CardList.Card, { key: `similar-neighborhood-card-${neighborhood.id}`, onClick: handleCardClickEvent(index), url: neighborhood.redirect_url, imageSrc: neighborhood.thumbnail_url, tagType: neighborhood.affordabilityComparison
                    ? affordabilityToTag[neighborhood.affordabilityComparison]
                    : undefined, expanded: affordabilityIndexPresentInNeighborhood, "data-cy": "similar-neighborhood-card", "data-cy-id": `similar-neighborhood-card-${neighborhood.id}` },
                !hideAffordabilityTags &&
                    neighborhood.affordabilityComparison && (React.createElement(CardList.Tag, { text: t(`tags.${neighborhood.affordabilityComparison}`), type: affordabilityToTag[neighborhood.affordabilityComparison], "data-cy": "neighborhood-card-tag" })),
                React.createElement("div", { className: styles.cardDataContent },
                    React.createElement(CardList.Title, { "data-alt": neighborhood.name }, neighborhood.name),
                    React.createElement("div", { className: styles.neighborhoodNameSpacer }),
                    neighborhood.scores && (React.createElement(ScoreCardList.Root, null, Object.entries(neighborhood.scores).map(([key, value]) => value >= 0 && (React.createElement(ScoreCardList.Card, { key: `similar-neighborhood-${neighborhood.id}-scores-${key}`, title: t(`common:scores.${key}.titleDeprecated`), scoreKey: key, value: value })))))))))),
            React.createElement("div", { className: styles.footer },
                React.createElement(PaginationButton, null))))));
}
//# sourceMappingURL=index.js.map