import React from "react";
import { useTranslation } from "react-i18next";
import { useTracking } from "@local-logic/core/tracking";
import { useNeighborhoodMatch } from "~/sdks/NeighborhoodMatch/context";
import { useResponsiveBreakpoints } from "~/hooks/useResponsiveBreakpoints";
import { TrackingPipelineEvents, AnalyticsEvents, } from "~/sdks/NeighborhoodMatch/types";
import * as styles from "./styles";
export const PaginationButton = () => {
    const { t } = useTranslation("neighborhoodMatch");
    const tracking = useTracking();
    const { limit, minimumLimit, hasMore, viewLess, viewMore } = useNeighborhoodMatch();
    const breakpoints = useResponsiveBreakpoints();
    const handleClick = () => {
        if (hasMore) {
            tracking.postEvent({
                eventType: TrackingPipelineEvents.PAGINATION_CLICKED,
                eventAttributes: [
                    {
                        label: "pagination_action_type",
                        data: "view_more",
                    },
                ],
            });
            tracking.trackAnalyticsEvent({
                eventName: AnalyticsEvents.PAGINATION_CLICKED,
                eventAttributes: {
                    ll_pagination_action_type: "view_more",
                },
            });
            viewMore();
        }
        if (!hasMore && limit > minimumLimit) {
            tracking.postEvent({
                eventType: TrackingPipelineEvents.PAGINATION_CLICKED,
                eventAttributes: [
                    {
                        label: "pagination_action_type",
                        data: "view_less",
                    },
                ],
            });
            tracking.trackAnalyticsEvent({
                eventName: AnalyticsEvents.PAGINATION_CLICKED,
                eventAttributes: {
                    ll_pagination_action_type: "view_less",
                },
            });
            viewLess();
        }
    };
    if (!(breakpoints === null || breakpoints === void 0 ? void 0 : breakpoints.lg) || (!hasMore && limit === minimumLimit)) {
        return null;
    }
    return (React.createElement("button", { className: styles.container, onClick: handleClick, "data-cy": "pagination-button" },
        hasMore && t("pagination.next"),
        !hasMore && limit > minimumLimit && t("pagination.previous")));
};
//# sourceMappingURL=index.js.map