import React, { useContext, useMemo } from "react";
import { useTracking } from "@local-logic/core/tracking";
import { useGeoLocationInfo } from "~/hooks/useGeoLocationInfo";
import { useStateManagerContext } from "~/context/stateManager";
import { usePropertyValueDrivers } from "~/features/clientLibrary/usePropertyValueDrivers";
import useEffectOnce from "~/hooks/useEffectOnce";
import { allowedValueDrivers, allowedDriverLowQualifiers } from "./constants";
import { TrackingPipelineEvents, AnalyticsEvents, } from "./types";
const NeighborhoodPropertyValueDriversContext = React.createContext({});
const useNeighborhoodPropertyValueDrivers = () => useContext(NeighborhoodPropertyValueDriversContext);
const NeighborhoodPropertyValueDriversProvider = ({ children, }) => {
    var _a, _b, _c, _d;
    const { sdkState } = useStateManagerContext();
    const tracking = useTracking();
    const locale = ((_a = sdkState.globalOptions) === null || _a === void 0 ? void 0 : _a.locale) || "en";
    useEffectOnce(() => {
        tracking.postEvent({
            eventType: TrackingPipelineEvents.SDK_VIEWED,
        });
        tracking.trackAnalyticsEvent({
            eventName: AnalyticsEvents.SDK_VIEWED,
        });
    });
    const { isLoading: isGeoLocationInfoLoading, locationInfo } = useGeoLocationInfo({
        lat: (_b = sdkState.options) === null || _b === void 0 ? void 0 : _b.lat,
        lng: (_c = sdkState.options) === null || _c === void 0 ? void 0 : _c.lng,
        geographyId: (_d = sdkState.options) === null || _d === void 0 ? void 0 : _d.geographyId,
        locale,
    });
    const { data: propertyValueDrivers, isFetching: isPropertyValueDriversFetching, } = usePropertyValueDrivers({
        geogID: locationInfo === null || locationInfo === void 0 ? void 0 : locationInfo.geogID,
    });
    /**
     * Top 4, but only those allowed (translations are not provided for the others)
     */
    const filteredPropertyValueDrivers = useMemo(() => propertyValueDrivers === null || propertyValueDrivers === void 0 ? void 0 : propertyValueDrivers.filter((valueDriver) => (valueDriver.value_qualifier === "low" &&
        allowedDriverLowQualifiers.includes(valueDriver.name)) ||
        (valueDriver.value_qualifier !== "low" &&
            allowedValueDrivers.includes(valueDriver.name))).sort((a, b) => (b.value || 0) - (a.value || 0)).slice(0, 4), [propertyValueDrivers]);
    const isLoading = useMemo(() => isGeoLocationInfoLoading || isPropertyValueDriversFetching, [isGeoLocationInfoLoading, isPropertyValueDriversFetching]);
    const contextValue = useMemo(() => ({
        isLoading,
        geogID: locationInfo === null || locationInfo === void 0 ? void 0 : locationInfo.geogID,
        propertyValueDrivers: filteredPropertyValueDrivers,
    }), [isLoading, locationInfo === null || locationInfo === void 0 ? void 0 : locationInfo.geogID, propertyValueDrivers]);
    return (React.createElement(NeighborhoodPropertyValueDriversContext.Provider, { value: contextValue }, children));
};
export { useNeighborhoodPropertyValueDrivers, NeighborhoodPropertyValueDriversProvider, };
//# sourceMappingURL=context.js.map