import React, { useEffect, useMemo, useState } from "react";
import { useTranslation } from "react-i18next";
import { useTracking } from "@local-logic/core/tracking";
import useIsMobile from "~/hooks/useIsMobile";
import { useStateManagerContext } from "~/context/stateManager";
import { useNeighborhoodSchools } from "~/sdks/NeighborhoodSchools/context";
import { AnalyticsEvents, TrackingPipelineEvents, } from "~/sdks/NeighborhoodSchools/types";
import { Backpack as BackpackIcon, GraduationCap as GraduationCapIcon, } from "@phosphor-icons/react";
import { Header } from "../Header";
import { Filter } from "../Filter";
import { SchoolsTable } from "../SchoolsTable";
import * as styles from "./styles";
import { SchoolsList } from "../SchoolsList";
import { Footer } from "../Footer";
export const Content = () => {
    var _a;
    const { t } = useTranslation("neighborhoodSchools");
    const tracking = useTracking();
    const { sdkState } = useStateManagerContext();
    const { schoolsData, schoolLevels, schoolTypes } = useNeighborhoodSchools();
    const [filterLevel, setFilterLevel] = useState(schoolLevels[0]);
    const [filterType, setFilterType] = useState(schoolTypes[0]);
    const isMobile = useIsMobile();
    useEffect(() => {
        if (!(filterType === null || filterType === void 0 ? void 0 : filterType.includes("types"))) {
            tracking.postEvent({
                eventType: TrackingPipelineEvents.FILTER_BY_TYPE,
                eventAttributes: [
                    {
                        label: "filter_by_type",
                        data: filterType,
                    },
                ],
            });
            tracking.trackAnalyticsEvent({
                eventName: AnalyticsEvents.FILTER_BY_TYPE,
                eventAttributes: {
                    filter_by_type: filterType,
                },
            });
        }
        if (!(filterLevel === null || filterLevel === void 0 ? void 0 : filterLevel.includes("levels")) && !(filterLevel === null || filterLevel === void 0 ? void 0 : filterLevel.includes("niveaux"))) {
            tracking.postEvent({
                eventType: TrackingPipelineEvents.FILTER_BY_LEVEL,
                eventAttributes: [
                    {
                        label: "filter_by_level",
                        data: filterLevel,
                    },
                ],
            });
            tracking.trackAnalyticsEvent({
                eventName: AnalyticsEvents.FILTER_BY_LEVEL,
                eventAttributes: {
                    filter_by_level: filterLevel,
                },
            });
        }
    }, [filterLevel, filterType]);
    const filteredSchools = useMemo(() => {
        let filtered = schoolsData;
        if (!(filterLevel === null || filterLevel === void 0 ? void 0 : filterLevel.includes("levels")) && !(filterLevel === null || filterLevel === void 0 ? void 0 : filterLevel.includes("niveaux"))) {
            filtered = filtered === null || filtered === void 0 ? void 0 : filtered.filter((school) => { var _a, _b; return (_b = (_a = school.school_attributes) === null || _a === void 0 ? void 0 : _a.levels) === null || _b === void 0 ? void 0 : _b.includes(filterLevel); });
        }
        if (!(filterType === null || filterType === void 0 ? void 0 : filterType.includes("types"))) {
            if (filterType === "magnet") {
                filtered = filtered === null || filtered === void 0 ? void 0 : filtered.filter((school) => { var _a, _b; return (_b = (_a = school.school_attributes) === null || _a === void 0 ? void 0 : _a.programs) === null || _b === void 0 ? void 0 : _b.includes("magnet"); });
            }
            else {
                filtered = filtered === null || filtered === void 0 ? void 0 : filtered.filter((school) => { var _a, _b; return (_b = (_a = school.school_attributes) === null || _a === void 0 ? void 0 : _a.types) === null || _b === void 0 ? void 0 : _b.includes(filterType); });
            }
        }
        return filtered;
    }, [schoolsData, filterLevel, filterType]);
    return (React.createElement(React.Fragment, null,
        React.createElement(Header, null),
        React.createElement("div", { className: styles.filters },
            React.createElement(Filter, { options: schoolTypes, icon: BackpackIcon, title: t("headers.type"), activeFilter: filterType, handleFilterChange: (type) => setFilterType(type) }),
            React.createElement(Filter, { options: schoolLevels, icon: GraduationCapIcon, title: t("headers.levels"), activeFilter: filterLevel, handleFilterChange: (level) => setFilterLevel(level) })),
        isMobile ? (React.createElement(SchoolsList, { schools: filteredSchools })) : (React.createElement(SchoolsTable, { schools: filteredSchools })),
        React.createElement(Footer, { hideAttribution: (_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.hideAttribution })));
};
//# sourceMappingURL=index.js.map