import React from "react";
import { useTranslation } from "react-i18next";
import { LoadingSpinner } from "@local-logic/core/ui";
import useEmblaCarousel from "embla-carousel-react";
import { NoDataContent } from "~/components/NoDataContent";
import { useNeighborhoodSchools } from "~/sdks/NeighborhoodSchools/context";
import { DotButton, useDotButton } from "./EmblaCarouselDotButton";
import "./embla.css";
import * as styles from "./styles";
import { SchoolName } from "../SchoolName";
export const SchoolsList = ({ schools }) => {
    const { t } = useTranslation("neighborhoodSchools");
    const { isLoading } = useNeighborhoodSchools();
    const [emblaRef, emblaApi] = useEmblaCarousel();
    const { selectedIndex, scrollSnaps, onDotButtonClick } = useDotButton(emblaApi);
    return (React.createElement(React.Fragment, null,
        isLoading && (React.createElement("div", { className: styles.loadingContent },
            React.createElement(LoadingSpinner, { image: true }))),
        !isLoading && schools && schools.length > 0 && (React.createElement("section", { className: "embla" },
            React.createElement("div", { className: "embla__viewport", ref: emblaRef },
                React.createElement("div", { className: `embla__container ${styles.container}` }, schools.map((school) => {
                    var _a, _b, _c, _d;
                    return (React.createElement("div", { className: "embla__slide", key: school.name },
                        React.createElement("div", { className: styles.slide },
                            React.createElement(SchoolName, { school: school }),
                            React.createElement("p", { className: styles.header }, t("headers.type")), (_b = (_a = school.school_attributes) === null || _a === void 0 ? void 0 : _a.types) === null || _b === void 0 ? void 0 :
                            _b.map((type) => (React.createElement("p", { key: `${school.name}-${type}`, className: styles.badge, "data-variant": "dark" }, type))),
                            React.createElement("p", { className: styles.header }, t("headers.levels")), (_d = (_c = school.school_attributes) === null || _c === void 0 ? void 0 : _c.levels) === null || _d === void 0 ? void 0 :
                            _d.map((level) => (React.createElement("p", { key: `${school.name}-${level}`, className: styles.badge, "data-variant": "light" }, level))),
                            React.createElement("p", { className: styles.header }, t("headers.location")),
                            React.createElement("p", { className: styles.address }, school.address))));
                }))),
            React.createElement("div", { className: styles.controls },
                React.createElement("div", { className: "embla__dots" }, scrollSnaps.map((_, index) => (React.createElement(DotButton, { key: index, onClick: () => onDotButtonClick(index), className: `embla__dot ${styles.dot}`, "data-selected": index === selectedIndex }))))))),
        !isLoading && !schools && React.createElement(NoDataContent, { text: t("noData") })));
};
//# sourceMappingURL=index.js.map