import React, { useContext, useMemo } from "react";
import { useTranslation } from "react-i18next";
import { useTracking } from "@local-logic/core/tracking";
import useEffectOnce from "~/hooks/useEffectOnce";
import { useStateManagerContext } from "~/context/stateManager";
import { useGeoLocationInfo } from "~/hooks/useGeoLocationInfo";
import { useSchools } from "~/hooks/useSchools";
import { useLocation } from "~/hooks/useLocation";
import { TrackingPipelineEvents, AnalyticsEvents, } from "./types";
const NeighborhoodSchoolsContext = React.createContext({});
const baseHeaders = {
    CAN: ["name", "type", "languages", "levels", "location"],
    USA: ["name", "type", "levels", "location"],
};
const useNeighborhoodSchools = () => useContext(NeighborhoodSchoolsContext);
const NeighborhoodSchoolsProvider = ({ children, }) => {
    var _a, _b, _c, _d, _e, _f, _g, _h;
    const { sdkState } = useStateManagerContext();
    const locale = ((_a = sdkState.globalOptions) === null || _a === void 0 ? void 0 : _a.locale) || "en";
    const { t } = useTranslation("neighborhoodSchools");
    const tracking = useTracking();
    useEffectOnce(() => {
        tracking.postEvent({
            eventType: TrackingPipelineEvents.SDK_VIEWED,
        });
        tracking.trackAnalyticsEvent({
            eventName: AnalyticsEvents.SDK_VIEWED,
        });
    });
    const { isLoading: isGeoLocationInfoLoading, locationInfo } = useGeoLocationInfo({
        lat: (_b = sdkState.options) === null || _b === void 0 ? void 0 : _b.lat,
        lng: (_c = sdkState.options) === null || _c === void 0 ? void 0 : _c.lng,
        geographyId: (_d = sdkState.options) === null || _d === void 0 ? void 0 : _d.geographyId,
        locale,
    });
    const { isLoading: isSchoolsLoading, data: schoolsData } = useSchools({
        lat: (_e = locationInfo === null || locationInfo === void 0 ? void 0 : locationInfo.coordinates) === null || _e === void 0 ? void 0 : _e.lat,
        lng: (_f = locationInfo === null || locationInfo === void 0 ? void 0 : locationInfo.coordinates) === null || _f === void 0 ? void 0 : _f.lng,
        include: ["schools"],
        radius: 2000,
        limit: 5,
    });
    const { isLoading: isLocationLoading, data: location } = useLocation({
        lat: (_g = locationInfo === null || locationInfo === void 0 ? void 0 : locationInfo.coordinates) === null || _g === void 0 ? void 0 : _g.lat,
        lng: (_h = locationInfo === null || locationInfo === void 0 ? void 0 : locationInfo.coordinates) === null || _h === void 0 ? void 0 : _h.lng,
    });
    const headers = useMemo(() => {
        if (isLocationLoading) {
            // defaulting to USA, to avoid an empty column
            return baseHeaders.USA;
        }
        return baseHeaders[location.country];
    }, [isLocationLoading, location]);
    const formattedSchoolsData = useMemo(() => {
        if (!schoolsData)
            return undefined;
        const schoolsNames = [];
        const merged = [
            ...schoolsData.primary_schools,
            ...schoolsData.high_schools,
        ];
        const singleSchools = merged.filter((school) => {
            if (schoolsNames.indexOf(school.name) !== -1) {
                return false;
            }
            schoolsNames.push(school.name);
            return school;
        });
        return singleSchools;
    }, [schoolsData]);
    const programs = formattedSchoolsData === null || formattedSchoolsData === void 0 ? void 0 : formattedSchoolsData.filter((school) => { var _a, _b; return (_b = (_a = school.school_attributes) === null || _a === void 0 ? void 0 : _a.programs) === null || _b === void 0 ? void 0 : _b.includes("magnet"); });
    const types = formattedSchoolsData === null || formattedSchoolsData === void 0 ? void 0 : formattedSchoolsData.map((school) => { var _a; return (_a = school.school_attributes) === null || _a === void 0 ? void 0 : _a.types; }).flat();
    const levels = formattedSchoolsData === null || formattedSchoolsData === void 0 ? void 0 : formattedSchoolsData.map((school) => { var _a; return (_a = school.school_attributes) === null || _a === void 0 ? void 0 : _a.levels; }).flat();
    const isLoading = useMemo(() => isGeoLocationInfoLoading || isSchoolsLoading, [isGeoLocationInfoLoading || isSchoolsLoading]);
    const schoolTypes = [`${t("headers.typesFilter")}`, ...new Set(types)];
    if (programs && (programs === null || programs === void 0 ? void 0 : programs.length) > 0) {
        schoolTypes.push("magnet");
    }
    const contextValue = useMemo(() => ({
        isLoading,
        locationInfo,
        schoolsData: formattedSchoolsData,
        headers,
        schoolTypes,
        schoolLevels: [`${t("headers.levelsFilter")}`, ...new Set(levels)],
    }), [isLoading, locationInfo, sdkState, formattedSchoolsData]);
    return (React.createElement(NeighborhoodSchoolsContext.Provider, { value: contextValue }, children));
};
export { useNeighborhoodSchools, NeighborhoodSchoolsProvider };
//# sourceMappingURL=context.js.map