var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { useQuery } from "@tanstack/react-query";
import errorTracker from "~/utils/errorTracker";
import { useStateManagerContext } from "~/context/stateManager";
import { transformNeighborhood } from "~/utils/transformNeighborhood";
const ENVIRONMENTS = {
    dev: "https://api-qa.locallogic.co/neighborhood-management-v1",
    qa: "https://api-qa.locallogic.co/neighborhood-management-v1",
    prod: "https://api.locallogic.co/neighborhood-management-v1",
};
export function useNeighborhoods({ search, pageSize = 10, }) {
    var _a, _b, _c;
    const { sdkState } = useStateManagerContext();
    const baseURL = ENVIRONMENTS[((_b = (_a = sdkState.globalOptions) === null || _a === void 0 ? void 0 : _a.environment) === null || _b === void 0 ? void 0 : _b.api) || "prod"];
    const fetchNeighborhoods = () => __awaiter(this, void 0, void 0, function* () {
        var _a, _b;
        const params = {
            include: "configurations",
            page_size: `${pageSize}`,
        };
        if (search) {
            params.search = search;
        }
        return fetch(`${baseURL}/sdk/neighborhoods/${(_a = sdkState === null || sdkState === void 0 ? void 0 : sdkState.globalOptions) === null || _a === void 0 ? void 0 : _a.externalId}?${new URLSearchParams(params)}`, {
            headers: {
                Accept: "application/json",
                Authorization: `${((_b = sdkState.apiKey) === null || _b === void 0 ? void 0 : _b.substring(0, 3)) !== "V3 " ? "V3 " : ""}${sdkState.apiKey}`,
                "x-ll-sdk-name": "neighborhood-showcase",
            },
            method: "GET",
        })
            .then((response) => {
            if ([204, 404].includes(response.status)) {
                return null;
            }
            if (response.status >= 300) {
                throw new Error(`Request failed with status ${response.status}`);
            }
            return response.json();
        })
            .then((response) => {
            const neighborhoods = response.neighborhoods || [];
            return neighborhoods.map((neighborhood) => {
                var _a;
                return transformNeighborhood(((_a = sdkState.globalOptions) === null || _a === void 0 ? void 0 : _a.locale) || "en", neighborhood, response.configurations[neighborhood.geog_id]);
            });
        })
            .catch((error) => {
            errorTracker.captureException(error);
        });
    });
    return useQuery({
        queryKey: ["neighborhoods", search],
        queryFn: fetchNeighborhoods,
        enabled: !!((_c = sdkState === null || sdkState === void 0 ? void 0 : sdkState.globalOptions) === null || _c === void 0 ? void 0 : _c.externalId) && !!search,
    });
}
//# sourceMappingURL=useNeighborhoods.js.map